(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     42218,        815]*)
(*NotebookOutlinePosition[     46137,        912]*)
(*  CellTagsIndexPosition[     46029,        905]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["AddEdge", "ObjectName",
  CellTags->{"b:0", "LocalInteractions:0"}],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["AddEdge[",
    FontFamily->"Courier"],
  StyleBox["model",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          StyleBox[
            RowBox[{
              SubscriptBox[
                StyleBox[
                  RowBox[{"i", 
                    StyleBox["ndex",
                      FontSlant->"Italic"]}]], "1"], ",", 
              SubscriptBox[
                StyleBox[
                  RowBox[{"i", 
                    StyleBox["ndex",
                      FontSlant->"Italic"]}]], "2"]}],
            FontSlant->"Italic"], "}"}], TraditionalForm]]],
  StyleBox["]",
    FontFamily->"Courier"],
  " adds the edge specified by {",
  Cell[BoxData[
      FormBox[
        StyleBox[\(index\_1, index\_2\),
          FontSlant->"Italic"], TraditionalForm]]],
  "} to ",
  StyleBox["model",
    FontSlant->"Italic"],
  "."
}], "Usage",
  CellTags->{"b:0", "LocalInteractions:0"}],

Cell["\<\
\[FilledSmallSquare] AddEdge takes the following options:\
\>", \
"Notes",
  CellTags->{"b:0", "LocalInteractions:0"}],

Cell[BoxData[GridBox[{
        {"Weight", "None", \(the\ weight\ of\ the\ edge\)},
        {"Undirected", 
          "True", \(whether\ the\ edge\ is\ undirected\ or\ directed\)},
        {"Neighborhoods", \({Interaction, 
            Update}\), \(neighborhoods\ to\ which\ the\ edge\ should\ be\ \
added\)}
        }]], "3ColumnTable",
  CellTags->{"b:0", "LocalInteractions:0"}],

Cell["\<\
\[FilledSmallSquare] The weight of the edge is a real number \
between 0 and 1.\
\>", "Notes",
  CellTags->{"b:0", "LocalInteractions:0"}],

Cell[CellGroupData[{

Cell["Example", "ExampleSection",
  CellTags->{"b:0", "LocalInteractions:0"}],

Cell[BoxData[
    \(<< LocalInteractions`LocalInteractions`\)], "Input",
  CellLabel->"In[1]:=",
  CellTags->{"b:0", "LocalInteractions:0"}],

Cell[BoxData[
    \(\(m = 
        LocalInteractionModel[\[IndentingNewLine]InteractionNeighborhood \
\[Rule] Cycle[10], \[IndentingNewLine]InitialStrategyDistribution \[Rule] 
            Table[Random[
                Integer, {1, 2}], {10}]\[IndentingNewLine]];\)\)], "Input",
  CellLabel->"In[2]:=",
  CellTags->{"b:0", "LocalInteractions:0"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[AddEdge]\)], "Input",
  CellLabel->"In[3]:=",
  CellTags->{"b:0", "LocalInteractions:0"}],

Cell[BoxData[
    \({Weight \[Rule] None, Undirected \[Rule] True, 
      Neighborhoods \[Rule] {Interaction, Update}}\)], "Output",
  CellLabel->"Out[3]=",
  CellTags->{"b:0", "LocalInteractions:0"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowLabeledGraph[m];\)\)], "Input",
  CellLabel->"In[4]:=",
  CellTags->{"b:0", "LocalInteractions:0"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.909091 0.0126467 0.951424 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 0 r
.005 w
[ ] 0 setdash
.86773 .77962 m
.64046 .95243 L
s
.86773 .77962 m
.95455 .5 L
s
.64046 .95243 m
.35954 .95243 L
s
.35954 .95243 m
.13227 .77962 L
s
.13227 .77962 m
.04545 .5 L
s
.04545 .5 m
.13227 .22038 L
s
.13227 .22038 m
.35954 .04757 L
s
.35954 .04757 m
.64046 .04757 L
s
.64046 .04757 m
.86773 .22038 L
s
.86773 .22038 m
.95455 .5 L
s
0 1 0 r
.025 w
.86773 .77962 Mdot
0 0 0 r
[(1)] .84773 .75962 1 0 Mshowa
1 0 0 r
.64046 .95243 Mdot
0 0 0 r
[(2)] .62046 .93243 1 0 Mshowa
0 1 0 r
.35954 .95243 Mdot
0 0 0 r
[(3)] .33954 .93243 1 0 Mshowa
0 1 0 r
.13227 .77962 Mdot
0 0 0 r
[(4)] .11227 .75962 1 0 Mshowa
1 0 0 r
.04545 .5 Mdot
0 0 0 r
[(5)] .02545 .48 1 0 Mshowa
0 1 0 r
.13227 .22038 Mdot
0 0 0 r
[(6)] .11227 .20038 1 0 Mshowa
1 0 0 r
.35954 .04757 Mdot
0 0 0 r
[(7)] .33954 .02757 1 0 Mshowa
0 1 0 r
.64046 .04757 Mdot
0 0 0 r
[(8)] .62046 .02757 1 0 Mshowa
0 1 0 r
.86773 .22038 Mdot
0 0 0 r
[(9)] .84773 .20038 1 0 Mshowa
1 0 0 r
.95455 .5 Mdot
0 0 0 r
[(10)] .93455 .48 1 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[4]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00GOooool00ol0003oooooooooo`1=ooooo`?o0000L?ooool005gooooo00?o0000oooooooo
ool0C?ooool01Ol0003ooooooooooooooooo000006oooooo001Nooooo`03o`000?oooooooooo04_o
oooo00Go0000ooooooooooooooooo`00001_ooooo`00G_ooool00ol0003oooooooooo`1<ooooo`?o
0000L?ooool005oooooo00?o0000ooooooooool0B_ooool01Ol0003ooooooooooooooooo000006oo
oooo001Kooooo`05o`000?ooooooooooooooool000001_ooool3ool004?ooooo00Go0000oooooooo
ooooooooo`000005ooooo`?o0?l0Ioooool005_ooooo1Ol00005ooooo`Goo`00@oooool3o`0000Go
oooo1Ol0o`1Vooooo`00I?ooool7ool004Wooooo1ol0o`1Uooooo`00I?ooool7ool004Wo00001ol0
o`1Uooooo`00I?ooool7ool004Wooooo1ol0o`1Uooooo`00I?ooool00ol0003oo`00ool00003ool0
04_ooooo1Ol0o`000ol0003oooooooooo`1Sooooo`00H_ooool2o`0000;ooooo0ooo001=ooooo`?o
0?l00_ooool2o`0006?ooooo001Qooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
H?ooool0063ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`1Oooooo`00G_ooool2
o`0005oooooo0_l0001Oooooo`00GOooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
05cooooo001Looooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0Foooool005[ooooo
0_l0001Wooooo`;o0000Foooool005Wooooo00?o0000ooooooooool0JOooool00ol0003ooooooooo
o`1Hooooo`00F?ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo05Oooooo001Foooo
o`;o0000Koooool2o`0005Oooooo001Eooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0E?ooool005Cooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`1Cooooo`00Dooo
ool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo05;ooooo001Aooooo`;o0000NOooool2
o`0005;ooooo001@ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0Coooool004oo
oooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`1>ooooo`00COooool2o`00087ooooo
0_l0001>ooooo`00C?ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo04_ooooo001;
ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0B_ooool004Wooooo0_l00029oooo
o`;o0000B_ooool004Sooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`17ooooo`00
Aoooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo04Kooooo0015ooooo`;o0000TOoo
ool2o`0004Kooooo0014ooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool0@oooool0
04?ooooo00?o0000ooooooooool0UOooool00ol0003oooooooooo`12ooooo`00@Oooool2o`0009Wo
oooo0_l00012ooooo`00@?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo03oooooo
000oooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0?_ooool003gooooo0_l0002Q
ooooo`;o0000?_ooool003cooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`0koooo
o`00>oooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo03[ooooo000iooooo`;o0000
ZOooool2o`0003[ooooo000hooooo`03o`000?oooooooooo0:_ooooo00?o0000ooooooooool0=ooo
ool003Oooooo00?o0000ooooooooool0[Oooool00ol0003oooooooooo`0fooooo`00=Oooool2o`00
0;7ooooo0_l0000fooooo`00=?ooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo03?o
oooo000cooooo`03o`000?oooooooooo0;Gooooo00?o0000ooooooooool0<_ooool003;ooooo00?o
0000ooooooooool0]oooool00ol0003oooooooooo`0aooooo`00<?ooool2o`000;_ooooo0_l0000a
ooooo`006oooool3o`00017ooooo00?o0000ooooooooool0_?ooool2o`00033ooooo000Jooooo`05
o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`2oooooo`03o`000?oooooooooo
02gooooo000Jooooo`05o`000?ooooooooooooooool000003Oooool2o`000<?ooooo0_l0000]oooo
o`006_ooool4o`0000gooooo00?o0000ooooooooool0`?ooool4o`000003ooooool0003ooooo02_o
oooo000Jooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0`?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool0:Oooool001_ooooo00?o0000ooooooooool0
1_ooool3o`3o0003ooooool0003o00000<?ooooo00Go0000ooooooooooooooooo`000003ooooo`;o
00000ol0o`0Vooooo`007?ooool2o`0000Gooooo1Ol0o`36ooooo`?o00001Oooool5o`3o02Gooooo
000Rooooo`Oo0?l0c?ooool7o`3o02Cooooo000Rooooo`Oo0?l0c?ooool7o`3o02Cooooo000Roooo
o`Oo0?l0c?ooool7o`3o02Cooooo000Sooooo`Go0?l0c_ooool5o`3o02Gooooo000Tooooo`?o0?l0
d?ooool3o`3o0003o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooooooo0=?ooooo00?o
0000ooooooooool08oooool002Cooooo00?o0000ooooooooool0doooool00ol0003oooooooooo`0S
ooooo`008oooool00ol0003oooooooooo`3Eooooo`03o`000?oooooooooo02;ooooo000Sooooo`03
o`000?oooooooooo0=Gooooo00?o0000ooooooooool08_ooool002?ooooo00?o0000ooooooooool0
eOooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`3Gooooo`03o`000?oo
oooooooo027ooooo000Rooooo`03o`000?oooooooooo0=Oooooo00?o0000ooooooooool08Oooool0
02;ooooo00?o0000ooooooooool0eoooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003o
ooooooooo`3Gooooo`03o`000?oooooooooo027ooooo000Qooooo`03o`000?oooooooooo0=Wooooo
00?o0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool0fOooool00ol0003ooooooooo
o`0Pooooo`008Oooool00ol0003oooooooooo`3Iooooo`03o`000?oooooooooo023ooooo000Poooo
o`03o`000?oooooooooo0=_ooooo00?o0000ooooooooool07oooool0023ooooo00?o0000oooooooo
ool0foooool00ol0003oooooooooo`0Oooooo`008?ooool00ol0003oooooooooo`3Kooooo`03o`00
0?oooooooooo01oooooo000Oooooo`03o`000?oooooooooo0=gooooo00?o0000ooooooooool07_oo
ool001oooooo00?o0000ooooooooool0gOooool00ol0003oooooooooo`0Nooooo`007oooool00ol0
003oooooooooo`3Mooooo`03o`000?oooooooooo01kooooo000Oooooo`03o`000?oooooooooo0=go
oooo00?o0000ooooooooool07_ooool001kooooo00?o0000ooooooooool0goooool00ol0003ooooo
ooooo`0Mooooo`007_ooool00ol0003oooooooooo`3Oooooo`03o`000?oooooooooo01gooooo000N
ooooo`03o`000?oooooooooo0=oooooo00?o0000ooooooooool07Oooool001gooooo00?o0000oooo
ooooool0hOooool00ol0003oooooooooo`0Looooo`007Oooool00ol0003oooooooooo`3Qooooo`03
o`000?oooooooooo01cooooo000Mooooo`03o`000?oooooooooo0>7ooooo00?o0000ooooooooool0
7?ooool001cooooo00?o0000ooooooooool0hoooool00ol0003oooooooooo`0Kooooo`007?ooool0
0ol0003oooooooooo`3Sooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo
0>?ooooo00?o0000ooooooooool06oooool001cooooo00?o0000ooooooooool0hoooool00ol0003o
ooooooooo`0Kooooo`006oooool00ol0003oooooooooo`3Uooooo`03o`000?oooooooooo01[ooooo
000Kooooo`03o`000?oooooooooo0>Gooooo00?o0000ooooooooool06_ooool001_ooooo00?o0000
ooooooooool0iOooool00ol0003oooooooooo`0Jooooo`006_ooool00ol0003oooooooooo`3Woooo
o`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo0>Oooooo00?o0000oooooooo
ool06Oooool001[ooooo00?o0000ooooooooool0ioooool00ol0003oooooooooo`0Iooooo`006Ooo
ool00ol0003oooooooooo`3Yooooo`03o`000?oooooooooo01Sooooo000Iooooo`03o`000?oooooo
oooo0>Wooooo00?o0000ooooooooool06?ooool001Wooooo00?o0000ooooooooool0jOooool00ol0
003oooooooooo`0Hooooo`006Oooool00ol0003oooooooooo`3Yooooo`03o`000?oooooooooo01So
oooo000Hooooo`03o`000?oooooooooo0>_ooooo00?o0000ooooooooool05oooool001Sooooo00?o
0000ooooooooool0joooool00ol0003oooooooooo`0Gooooo`006?ooool00ol0003oooooooooo`3[
ooooo`03o`000?oooooooooo01Oooooo000Gooooo`03o`000?oooooooooo0>gooooo00?o0000oooo
ooooool05_ooool001Oooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`0Fooooo`00
5oooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo01Kooooo000Fooooo`03o`000?oo
oooooooo0>oooooo00?o0000ooooooooool05Oooool001Kooooo00?o0000ooooooooool0koooool0
0ol0003oooooooooo`0Eooooo`005_ooool00ol0003oooooooooo`3_ooooo`03o`000?oooooooooo
01Gooooo000Fooooo`03o`000?oooooooooo0>oooooo00?o0000ooooooooool05Oooool001Gooooo
00?o0000ooooooooool0lOooool00ol0003oooooooooo`0Dooooo`005Oooool00ol0003ooooooooo
o`3aooooo`03o`000?oooooooooo01Cooooo000Eooooo`03o`000?oooooooooo0?7ooooo00?o0000
ooooooooool05?ooool001Cooooo00?o0000ooooooooool0loooool00ol0003oooooooooo`0Coooo
o`005?ooool00ol0003oooooooooo`3cooooo`03o`000?oooooooooo01?ooooo000Dooooo`03o`00
0?oooooooooo0??ooooo00?o0000ooooooooool04oooool001?ooooo00?o0000ooooooooool0mOoo
ool00ol0003oooooooooo`0Booooo`004oooool00ol0003oooooooooo`3eooooo`03o`000?oooooo
oooo01;ooooo000Cooooo`03o`000?oooooooooo0?Gooooo00?o0000ooooooooool04_ooool001?o
oooo00?o0000ooooooooool0mOooool00ol0003oooooooooo`0Booooo`004_ooool00ol0003ooooo
ooooo`3gooooo`03o`000?oooooooooo017ooooo000Booooo`03o`000?oooooooooo0?Oooooo00?o
0000ooooooooool04Oooool001;ooooo00?o0000ooooooooool0moooool00ol0003oooooooooo`0A
ooooo`004Oooool00ol0003oooooooooo`3iooooo`03o`000?oooooooooo013ooooo000Aooooo`03
o`000?oooooooooo0?Wooooo00?o0000ooooooooool04?ooool0017ooooo00?o0000ooooooooool0
nOooool00ol0003oooooooooo`0@ooooo`004?ooool00ol0003oooooooooo`3kooooo`03o`000?oo
oooooooo00oooooo000@ooooo`03o`000?oooooooooo0?_ooooo00?o0000ooooooooool03oooool0
013ooooo00?o0000ooooooooool0noooool00ol0003oooooooooo`0?ooooo`000_ooool3o`0000_o
oooo00?o0000ooooooooool0k_ooool3o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo00oo
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
l?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool03_ooool000Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3`ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0>ooooo`00
1Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?3ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00kooooo00000ooooooo0000
o`000002o`0000Wooooo00?o0000ooooooooool0lOooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooooooool03Oooool00003ooooool0003ooooo00Sooooo
0ooo00000ol0003oooooooooo`3`ooooo`;o00001?ooool01?l0003oooooooooool00005ooooo`?o
o`003Oooool00003ooooool0003o000000?o00001?ooool5ool00??ooooo00?o0000ooooooooool0
0oooool2o`0000Gooooo1Ooo000<ooooo`002Oooool7ool00?kooooo1ooo000;ooooo`002Oooool7
ool00?kooooo1ooo000;ooooo`002Oooool7ool00?kooooo1ooo000;ooooo`002_ooool5ool00?oo
oooo0Oooool5ool000cooooo000;ooooo`?oo`0000?o0000ooooooooool0ooooool3ool000gooooo
000>ooooo`03o`000?oooooooooo0?oooooo00?o0000ooooooooool03Oooool000kooooo00?o0000
ooooooooool0ooooool00ol0003oooooooooo`0=ooooo`003oooool00ol0003oooooooooo`3moooo
o`03o`000?oooooooooo00kooooo000?ooooo`03o`000?oooooooooo0?gooooo00?o0000oooooooo
ool03_ooool000oooooo00?o0000ooooooooool0oOooool00ol0003oooooooooo`0>ooooo`004?oo
ool00ol0003oooooooooo`3kooooo`03o`000?oooooooooo00oooooo000@ooooo`03o`000?oooooo
oooo0?_ooooo00?o0000ooooooooool03oooool0013ooooo00?o0000ooooooooool0noooool00ol0
003oooooooooo`0?ooooo`004?ooool00ol0003oooooooooo`3kooooo`03o`000?oooooooooo00oo
oooo000Aooooo`03o`000?oooooooooo0?Wooooo00?o0000ooooooooool04?ooool0017ooooo00?o
0000ooooooooool0nOooool00ol0003oooooooooo`0@ooooo`004Oooool00ol0003oooooooooo`3i
ooooo`03o`000?oooooooooo013ooooo000Booooo`03o`000?oooooooooo0?Oooooo00?o0000oooo
ooooool04Oooool001;ooooo00?o0000ooooooooool0moooool00ol0003oooooooooo`0Aooooo`00
4_ooool00ol0003oooooooooo`3gooooo`03o`000?oooooooooo017ooooo000Cooooo`03o`000?oo
oooooooo0?Gooooo00?o0000ooooooooool04_ooool001?ooooo00?o0000ooooooooool0mOooool0
0ol0003oooooooooo`0Booooo`004oooool00ol0003oooooooooo`3eooooo`03o`000?oooooooooo
01;ooooo000Cooooo`03o`000?oooooooooo0?Gooooo00?o0000ooooooooool04_ooool001Cooooo
00?o0000ooooooooool0loooool00ol0003oooooooooo`0Cooooo`005?ooool00ol0003ooooooooo
o`3cooooo`03o`000?oooooooooo01?ooooo000Dooooo`03o`000?oooooooooo0??ooooo00?o0000
ooooooooool04oooool001Gooooo00?o0000ooooooooool0lOooool00ol0003oooooooooo`0Doooo
o`005Oooool00ol0003oooooooooo`3aooooo`03o`000?oooooooooo01Cooooo000Eooooo`03o`00
0?oooooooooo0?7ooooo00?o0000ooooooooool05?ooool001Kooooo00?o0000ooooooooool0kooo
ool00ol0003oooooooooo`0Eooooo`005_ooool00ol0003oooooooooo`3_ooooo`03o`000?oooooo
oooo01Gooooo000Fooooo`03o`000?oooooooooo0>oooooo00?o0000ooooooooool05Oooool001Ko
oooo00?o0000ooooooooool0koooool00ol0003oooooooooo`0Eooooo`005oooool00ol0003ooooo
ooooo`3]ooooo`03o`000?oooooooooo01Kooooo000Gooooo`03o`000?oooooooooo0>gooooo00?o
0000ooooooooool05_ooool001Oooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`0F
ooooo`006?ooool00ol0003oooooooooo`3[ooooo`03o`000?oooooooooo01Oooooo000Hooooo`03
o`000?oooooooooo0>_ooooo00?o0000ooooooooool05oooool001Sooooo00?o0000ooooooooool0
joooool00ol0003oooooooooo`0Gooooo`006Oooool00ol0003oooooooooo`3Yooooo`03o`000?oo
oooooooo01Sooooo000Iooooo`03o`000?oooooooooo0>Wooooo00?o0000ooooooooool06?ooool0
01Wooooo00?o0000ooooooooool0jOooool00ol0003oooooooooo`0Hooooo`006Oooool00ol0003o
ooooooooo`3Yooooo`03o`000?oooooooooo01Sooooo000Jooooo`03o`000?oooooooooo0>Oooooo
00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0ioooool00ol0003ooooooooo
o`0Iooooo`006_ooool00ol0003oooooooooo`3Wooooo`03o`000?oooooooooo01Wooooo000Koooo
o`03o`000?oooooooooo0>Gooooo00?o0000ooooooooool06_ooool001_ooooo00?o0000oooooooo
ool0iOooool00ol0003oooooooooo`0Jooooo`006oooool00ol0003oooooooooo`3Uooooo`03o`00
0?oooooooooo01[ooooo000Looooo`03o`000?oooooooooo0>?ooooo00?o0000ooooooooool06ooo
ool001cooooo00?o0000ooooooooool0hoooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0
003oooooooooo`3Sooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo0>?o
oooo00?o0000ooooooooool06oooool001gooooo00?o0000ooooooooool0hOooool00ol0003ooooo
ooooo`0Looooo`007Oooool00ol0003oooooooooo`3Qooooo`03o`000?oooooooooo01cooooo000M
ooooo`03o`000?oooooooooo0>7ooooo00?o0000ooooooooool07?ooool001kooooo00?o0000oooo
ooooool0goooool00ol0003oooooooooo`0Mooooo`007_ooool00ol0003oooooooooo`3Oooooo`03
o`000?oooooooooo01gooooo000Nooooo`03o`000?oooooooooo0=oooooo00?o0000ooooooooool0
7Oooool001oooooo00?o0000ooooooooool0gOooool00ol0003oooooooooo`0Nooooo`007oooool0
0ol0003oooooooooo`3Mooooo`03o`000?oooooooooo01kooooo000Oooooo`03o`000?oooooooooo
0=gooooo00?o0000ooooooooool07_ooool001oooooo00?o0000ooooooooool0gOooool00ol0003o
ooooooooo`0Nooooo`008?ooool00ol0003oooooooooo`3Kooooo`03o`000?oooooooooo01oooooo
000Pooooo`03o`000?oooooooooo0=_ooooo00?o0000ooooooooool07oooool0023ooooo00?o0000
ooooooooool0foooool00ol0003oooooooooo`0Oooooo`008Oooool00ol0003oooooooooo`3Ioooo
o`03o`000?oooooooooo023ooooo000Qooooo`03o`000?oooooooooo0=Wooooo00?o0000oooooooo
ool08?ooool0027ooooo00?o0000ooooooooool0fOooool00ol0003oooooooooo`0Pooooo`008_oo
ool00ol0003oooooooooo`3Gooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooo
oooo0=Oooooo00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool0eoooool00ol0
003oooooooooo`0Qooooo`007?ooool3o`0000?ooooo00?o0000ooooooooool0bOooool3o`0000_o
oooo00?o0000ooooooooool08Oooool001gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`39ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool001[ooooo1Ol0
0004ooooo`03o`000?oooooooooo0<Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Rooooo`006_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo0<Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`006oooool00ol0003oooooo`000006
ooooo`03o`000?oooooooooo0<Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0S
ooooo`007?ooool2o`0000Kooooo0ol0o`37ooooo`;o00001oooool3o`3o0003o`000?oooooooooo
02?ooooo000Mooooo`03o`000?oooooooooo00?ooooo1Ol0o`37ooooo`03o`000?oooooooooo00Co
oooo1Ol0o`0Uooooo`008_ooool7o`3o0<cooooo1ol0o`0Tooooo`008_ooool7o`3o0<cooooo1ol0
o`0Tooooo`008_ooool7o`3o0<cooooo1ol0o`0Tooooo`008oooool5o`3o0003o`000?oooooooooo
0<_ooooo1Ol0o`0Uooooo`009?ooool3o`3o00;ooooo0_l00039ooooo`;o000000Coooooo`3o0?l0
o`3o0?l09_ooool002_ooooo00?o0000ooooooooool0aOooool00ol0003oooooooooo`0Zooooo`00
;?ooool00ol0003oooooooooo`33ooooo`03o`000?oooooooooo02_ooooo000]ooooo`;o0000`Ooo
ool2o`0002kooooo000_ooooo`03o`000?oooooooooo0;gooooo00?o0000ooooooooool0;_ooool0
033ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`0_ooooo`00<Oooool2o`000;Wo
oooo0_l0000booooo`00<oooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo03;ooooo
000dooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool0<oooool003Gooooo0_l0002a
ooooo`;o0000=_ooool003Oooooo00?o0000ooooooooool0[Oooool00ol0003oooooooooo`0foooo
o`00>?ooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo03Oooooo000iooooo`03o`00
0?oooooooooo0:Wooooo00?o0000ooooooooool0>?ooool003[ooooo0_l0002Wooooo`;o0000>ooo
ool003cooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`0kooooo`00?Oooool00ol0
003oooooooooo`2Qooooo`03o`000?oooooooooo03cooooo000nooooo`;o0000Woooool2o`0003oo
oooo0010ooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool0?oooool0047ooooo00?o
0000ooooooooool0VOooool00ol0003oooooooooo`10ooooo`00@_ooool2o`0009Oooooo0_l00013
ooooo`00A?ooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo04?ooooo0015ooooo`03
o`000?oooooooooo097ooooo00?o0000ooooooooool0A?ooool004Kooooo0_l0002?ooooo`;o0000
Aoooool004Sooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`17ooooo`00BOooool0
0ol0003oooooooooo`29ooooo`03o`000?oooooooooo04Sooooo001:ooooo`;o0000Qoooool2o`00
04_ooooo001<ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0Boooool004gooooo
00?o0000ooooooooool0POooool00ol0003oooooooooo`1<ooooo`00C_ooool2o`0007oooooo0_l0
001?ooooo`00D?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo04oooooo001Aoooo
o`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0D?ooool005;ooooo0_l0001gooooo`;o
0000Doooool005Cooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`1Cooooo`00EOoo
ool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo05Cooooo001Fooooo`;o0000Koooool2
o`0005Oooooo001Hooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0Eoooool005Wo
oooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`1Hooooo`00F_ooool00ol0003ooooo
ooooo`1Wooooo`03o`000?oooooooooo05Wooooo001Kooooo`;o0000IOooool2o`0005cooooo001L
ooooo`?o0000COooool5o`00013ooooo00?o0000ooooooooool0G?ooool005_ooooo00?o0000oooo
ooooool00_l0001=ooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooooooool0GOooool0
05oooooo0_l0001=ooooo`03o`000?oooooooooo00gooooo0_l0001Pooooo`00GOooool2o`0000;o
oooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo063o
oooo001Oooooo`04o`000?ooooooooooo`0004Wooooo00Go0000ooooooooooooooooo`00000;oooo
o`03o`000?oooooooooo067ooooo001Kooooo`05o`000?ooooooooooooooool000000oooool2o`00
0004ooooool0o`3o0?l0o`3o04?ooooo00Go0000ooooooooooooooooo`000005ooooo`?oo`0000?o
ooooo`000?l00000I?ooool005cooooo0ol00006ooooo`Go0?l0@oooool3o`0000Gooooo1Ooo001V
ooooo`00I?ooool7o`3o04Wooooo1ooo001Uooooo`00I?ooool7o`3o04Wo00001ooo001Uooooo`00
I?ooool7o`3o04Wooooo1ooo001Uooooo`00IOooool5o`3o04_ooooo1Ooo001Vooooo`00I_ooool3
o`3o04gooooo0ooo001Wooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0500054, -0.0132976, \
0.00383279, 0.00366225}},
  CellTags->{"b:0", "LocalInteractions:0"}]
}, Open  ]],

Cell[BoxData[
    \(AddEdge[m, {1, 5}]\)], "Input",
  CellLabel->"In[5]:=",
  CellTags->{"b:0", "LocalInteractions:0"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExtractGraph[m] // ShowGraph\)], "Input",
  CellLabel->"In[6]:=",
  CellTags->{"b:0", "LocalInteractions:0"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.909091 0.0126467 0.951424 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 0 r
.005 w
[ ] 0 setdash
.86773 .77962 m
.64046 .95243 L
s
.86773 .77962 m
.95455 .5 L
s
.64046 .95243 m
.35954 .95243 L
s
.35954 .95243 m
.13227 .77962 L
s
.13227 .77962 m
.04545 .5 L
s
.04545 .5 m
.13227 .22038 L
s
.13227 .22038 m
.35954 .04757 L
s
.35954 .04757 m
.64046 .04757 L
s
.64046 .04757 m
.86773 .22038 L
s
.86773 .22038 m
.95455 .5 L
s
0 1 0 r
.025 w
.86773 .77962 Mdot
1 0 0 r
.64046 .95243 Mdot
0 1 0 r
.35954 .95243 Mdot
.13227 .77962 Mdot
1 0 0 r
.04545 .5 Mdot
0 1 0 r
.13227 .22038 Mdot
1 0 0 r
.35954 .04757 Mdot
0 1 0 r
.64046 .04757 Mdot
.86773 .22038 Mdot
1 0 0 r
.95455 .5 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00I_ooool3ool004gooooo0ol0o`1Wooooo`00IOooool5ool004_ooooo1Ol0o`1Vooooo`00
I?ooool7ool004Wooooo1ol0o`1Uooooo`00I?ooool7ool004Wo00001ol0o`1Uooooo`00I?ooool7
ool004Wooooo1ol0o`1Uooooo`00I?ooool00ol0003oo`00ool00003ool004_ooooo1Ol0o`000ol0
003oooooooooo`1Sooooo`00H_ooool2o`0000;ooooo0ooo001=ooooo`?o0?l00_ooool2o`0006?o
oooo001Qooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0H?ooool0063ooooo00?o
0000ooooooooool0Foooool00ol0003oooooooooo`1Oooooo`00G_ooool2o`0005oooooo0_l0001O
ooooo`00GOooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo05cooooo001Looooo`03
o`000?oooooooooo06?ooooo00?o0000ooooooooool0Foooool005[ooooo0_l0001Wooooo`;o0000
Foooool005Wooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`1Hooooo`00F?ooool0
0ol0003oooooooooo`1[ooooo`03o`000?oooooooooo05Oooooo001Fooooo`;o0000Koooool2o`00
05Oooooo001Eooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0E?ooool005Cooooo
00?o0000ooooooooool0Loooool00ol0003oooooooooo`1Cooooo`00Doooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo05;ooooo001Aooooo`;o0000NOooool2o`0005;ooooo001@oooo
o`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0Coooool004oooooo00?o0000oooooooo
ool0OOooool00ol0003oooooooooo`1>ooooo`00COooool2o`00087ooooo0_l0001>ooooo`00C?oo
ool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo04_ooooo001;ooooo`03o`000?oooooo
oooo08Gooooo00?o0000ooooooooool0B_ooool004Wooooo0_l00029ooooo`;o0000B_ooool004So
oooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`17ooooo`00Aoooool00ol0003ooooo
ooooo`2=ooooo`03o`000?oooooooooo04Kooooo0015ooooo`;o0000TOooool2o`0004Kooooo0014
ooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool0@oooool004?ooooo00?o0000oooo
ooooool0UOooool00ol0003oooooooooo`12ooooo`00@Oooool2o`0009Wooooo0_l00012ooooo`00
@?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo03oooooo000oooooo`03o`000?oo
oooooooo09gooooo00?o0000ooooooooool0?_ooool003gooooo0_l0002Qooooo`;o0000?_ooool0
03cooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`0kooooo`00>oooool00ol0003o
ooooooooo`2Uooooo`03o`000?oooooooooo03[ooooo000iooooo`;o0000ZOooool2o`0003[ooooo
000hooooo`03o`000?oooooooooo0:_ooooo00?o0000ooooooooool0=oooool003Oooooo00?o0000
ooooooooool0[Oooool00ol0003oooooooooo`0fooooo`00=Oooool2o`000;7ooooo0_l0000foooo
o`00=?ooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo03?ooooo000cooooo`03o`00
0?oooooooooo0;Gooooo00?o0000ooooooooool0<_ooool003;ooooo00?o0000ooooooooool0]ooo
ool00ol0003oooooooooo`0aooooo`00<?ooool2o`000;_ooooo0_l0000aooooo`00;oooool00ol0
003oooooooooo`2mooooo`03o`000?oooooooooo02kooooo000^ooooo`03o`000?oooooooooo0;oo
oooo00?o0000ooooooooool0;Oooool002cooooo0_l00033ooooo`;o0000;Oooool002_ooooo00?o
0000ooooooooool0aOooool00ol0003oooooooooo`0Zooooo`00:_ooool00ol0003oooooooooo`37
ooooo`03o`000?oooooooooo02Wooooo000Tooooo`?o0?l000?oooooo`000?l00000boooool2o`00
00?o0?l09_ooool002?ooooo1Ol0o`3>ooooo`Go0?l09Oooool002;ooooo1ol0o`3<ooooo`Oo0?l0
9?ooool002;ooooo1ol0o`3<ooooo`Oo0?l09?ooool002;ooooo1ol0o`3<ooooo`Oo0?l09?ooool0
02?ooooo1Ol0o`3>ooooo`Go0?l09Oooool002Cooooo0ol0o`3@ooooo`?o0?l000?o0000oooooooo
ool08oooool002Cooooo00?o0000ooooooooool0doooool00ol0003oooooooooo`0Sooooo`009?oo
ool00ol0003oooooooooo`3Cooooo`03o`000?oooooooooo02?ooooo000Sooooo`03o`000?oooooo
oooo0=Gooooo00?o0000ooooooooool08_ooool002?ooooo00?o0000ooooooooool0eOooool00ol0
003oooooooooo`0Rooooo`008oooool00ol0003oooooooooo`3Eooooo`03o`000?oooooooooo02;o
oooo000Rooooo`03o`000?oooooooooo0=Oooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool0eoooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`3G
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo0=Oooooo00?o0000oooo
ooooool08Oooool0027ooooo00?o0000ooooooooool0fOooool00ol0003oooooooooo`0Pooooo`00
8Oooool00ol0003oooooooooo`3Iooooo`03o`000?oooooooooo023ooooo000Qooooo`03o`000?oo
oooooooo0=Wooooo00?o0000ooooooooool08?ooool0023ooooo00?o0000ooooooooool0foooool0
0ol0003oooooooooo`0Oooooo`008?ooool00ol0003oooooooooo`3Kooooo`03o`000?oooooooooo
01oooooo000Pooooo`03o`000?oooooooooo0=_ooooo00?o0000ooooooooool07oooool001oooooo
00?o0000ooooooooool0gOooool00ol0003oooooooooo`0Nooooo`007oooool00ol0003ooooooooo
o`3Mooooo`03o`000?oooooooooo01kooooo000Oooooo`03o`000?oooooooooo0=gooooo00?o0000
ooooooooool07_ooool001oooooo00?o0000ooooooooool0gOooool00ol0003oooooooooo`0Noooo
o`007_ooool00ol0003oooooooooo`3Oooooo`03o`000?oooooooooo01gooooo000Nooooo`03o`00
0?oooooooooo0=oooooo00?o0000ooooooooool07Oooool001kooooo00?o0000ooooooooool0gooo
ool00ol0003oooooooooo`0Mooooo`007Oooool00ol0003oooooooooo`3Qooooo`03o`000?oooooo
oooo01cooooo000Mooooo`03o`000?oooooooooo0>7ooooo00?o0000ooooooooool07?ooool001go
oooo00?o0000ooooooooool0hOooool00ol0003oooooooooo`0Looooo`007?ooool00ol0003ooooo
ooooo`3Sooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo0>?ooooo00?o
0000ooooooooool06oooool001cooooo00?o0000ooooooooool0hoooool00ol0003oooooooooo`0K
ooooo`007?ooool00ol0003oooooooooo`3Sooooo`03o`000?oooooooooo01_ooooo000Kooooo`03
o`000?oooooooooo0>Gooooo00?o0000ooooooooool06_ooool001_ooooo00?o0000ooooooooool0
iOooool00ol0003oooooooooo`0Jooooo`006oooool00ol0003oooooooooo`3Uooooo`03o`000?oo
oooooooo01[ooooo000Jooooo`03o`000?oooooooooo0>Oooooo00?o0000ooooooooool06Oooool0
01[ooooo00?o0000ooooooooool0ioooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003o
ooooooooo`3Wooooo`03o`000?oooooooooo01Wooooo000Iooooo`03o`000?oooooooooo0>Wooooo
00?o0000ooooooooool06?ooool001Wooooo00?o0000ooooooooool0jOooool00ol0003ooooooooo
o`0Hooooo`006Oooool00ol0003oooooooooo`3Yooooo`03o`000?oooooooooo01Sooooo000Ioooo
o`03o`000?oooooooooo0>Wooooo00?o0000ooooooooool06?ooool001Sooooo00?o0000oooooooo
ool0joooool00ol0003oooooooooo`0Gooooo`006?ooool00ol0003oooooooooo`3[ooooo`03o`00
0?oooooooooo01Oooooo000Hooooo`03o`000?oooooooooo0>_ooooo00?o0000ooooooooool05ooo
ool001Oooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`0Fooooo`005oooool00ol0
003oooooooooo`3]ooooo`03o`000?oooooooooo01Kooooo000Gooooo`03o`000?oooooooooo0>go
oooo00?o0000ooooooooool05_ooool001Kooooo00?o0000ooooooooool0koooool00ol0003ooooo
ooooo`0Eooooo`005_ooool00ol0003oooooooooo`3_ooooo`03o`000?oooooooooo01Gooooo000F
ooooo`03o`000?oooooooooo0>oooooo00?o0000ooooooooool05Oooool001Kooooo00?o0000oooo
ooooool0koooool00ol0003oooooooooo`0Eooooo`005Oooool00ol0003oooooooooo`3aooooo`03
o`000?oooooooooo01Cooooo000Eooooo`03o`000?oooooooooo0?7ooooo00?o0000ooooooooool0
5?ooool001Gooooo00?o0000ooooooooool0lOooool00ol0003oooooooooo`0Dooooo`005?ooool0
0ol0003oooooooooo`3cooooo`03o`000?oooooooooo01?ooooo000Dooooo`03o`000?oooooooooo
0??ooooo00?o0000ooooooooool04oooool001Cooooo00?o0000ooooooooool0loooool00ol0003o
ooooooooo`0Cooooo`004oooool00ol0003oooooooooo`3eooooo`03o`000?oooooooooo01;ooooo
000Cooooo`03o`000?oooooooooo0?Gooooo00?o0000ooooooooool04_ooool001?ooooo00?o0000
ooooooooool0mOooool00ol0003oooooooooo`0Booooo`004oooool00ol0003oooooooooo`3eoooo
o`03o`000?oooooooooo01;ooooo000Booooo`03o`000?oooooooooo0?Oooooo00?o0000oooooooo
ool04Oooool001;ooooo00?o0000ooooooooool0moooool00ol0003oooooooooo`0Aooooo`004_oo
ool00ol0003oooooooooo`3gooooo`03o`000?oooooooooo017ooooo000Aooooo`03o`000?oooooo
oooo0?Wooooo00?o0000ooooooooool04?ooool0017ooooo00?o0000ooooooooool0nOooool00ol0
003oooooooooo`0@ooooo`004Oooool00ol0003oooooooooo`3iooooo`03o`000?oooooooooo013o
oooo000@ooooo`03o`000?oooooooooo0?_ooooo00?o0000ooooooooool03oooool0013ooooo00?o
0000ooooooooool0noooool00ol0003oooooooooo`0?ooooo`004?ooool00ol0003oooooooooo`3k
ooooo`03o`000?oooooooooo00oooooo000@ooooo`03o`000?oooooooooo0?_ooooo00?o0000oooo
ooooool03oooool000oooooo00?o0000ooooooooool0oOooool00ol0003oooooooooo`0>ooooo`00
3oooool00ol0003oooooooooo`3mooooo`03o`000?oooooooooo00kooooo000?ooooo`03o`000?oo
oooooooo0?gooooo00?o0000ooooooooool03_ooool000kooooo00?o0000ooooooooool0ooooool0
0ol0003oooooooooo`0=ooooo`002oooool3ool00003o`000?oooooooooo0?oooooo0ooo000=oooo
o`002_ooool5ool00?oooooo0Oooool5ool000cooooo0009ooooo`Ooo`00o_ooool7ool000_ooooo
0009ooooo`Ooo`00o_ooool7ool000_ooooo0009ooooo`Ooo`00o_ooool7ool000_ooooo000:oooo
o`Goo`00ooooool1ooooo`Goo`003?ooool000_ooooo0ooo00000ol0003oooooooooo`3oooooo`?o
o`003Oooool000kooooo00?o0000ooooooooool0ooooool00ol0003oooooooooo`0=ooooo`003_oo
ool00ol0003oooooooooo`3oooooo`03o`000?oooooooooo00gooooo000?ooooo`03o`000?oooooo
oooo0?gooooo00?o0000ooooooooool03_ooool000oooooo00?o0000ooooooooool0oOooool00ol0
003oooooooooo`0>ooooo`003oooool00ol0003oooooooooo`3mooooo`03o`000?oooooooooo00ko
oooo000@ooooo`03o`000?oooooooooo0?_ooooo00?o0000ooooooooool03oooool0013ooooo00?o
0000ooooooooool0noooool00ol0003oooooooooo`0?ooooo`004?ooool00ol0003oooooooooo`3k
ooooo`03o`000?oooooooooo00oooooo000@ooooo`03o`000?oooooooooo0?_ooooo00?o0000oooo
ooooool03oooool0017ooooo00?o0000ooooooooool0nOooool00ol0003oooooooooo`0@ooooo`00
4Oooool00ol0003oooooooooo`3iooooo`03o`000?oooooooooo013ooooo000Aooooo`03o`000?oo
oooooooo0?Wooooo00?o0000ooooooooool04?ooool001;ooooo00?o0000ooooooooool0moooool0
0ol0003oooooooooo`0Aooooo`004_ooool00ol0003oooooooooo`3gooooo`03o`000?oooooooooo
017ooooo000Booooo`03o`000?oooooooooo0?Oooooo00?o0000ooooooooool04Oooool001?ooooo
00?o0000ooooooooool0mOooool00ol0003oooooooooo`0Booooo`004oooool00ol0003ooooooooo
o`3eooooo`03o`000?oooooooooo01;ooooo000Cooooo`03o`000?oooooooooo0?Gooooo00?o0000
ooooooooool04_ooool001?ooooo00?o0000ooooooooool0mOooool00ol0003oooooooooo`0Boooo
o`005?ooool00ol0003oooooooooo`3cooooo`03o`000?oooooooooo01?ooooo000Dooooo`03o`00
0?oooooooooo0??ooooo00?o0000ooooooooool04oooool001Cooooo00?o0000ooooooooool0looo
ool00ol0003oooooooooo`0Cooooo`005Oooool00ol0003oooooooooo`3aooooo`03o`000?oooooo
oooo01Cooooo000Eooooo`03o`000?oooooooooo0?7ooooo00?o0000ooooooooool05?ooool001Go
oooo00?o0000ooooooooool0lOooool00ol0003oooooooooo`0Dooooo`005_ooool00ol0003ooooo
ooooo`3_ooooo`03o`000?oooooooooo01Gooooo000Fooooo`03o`000?oooooooooo0>oooooo00?o
0000ooooooooool05Oooool001Kooooo00?o0000ooooooooool0koooool00ol0003oooooooooo`0E
ooooo`005_ooool00ol0003oooooooooo`3_ooooo`03o`000?oooooooooo01Gooooo000Gooooo`03
o`000?oooooooooo0>gooooo00?o0000ooooooooool05_ooool001Oooooo00?o0000ooooooooool0
kOooool00ol0003oooooooooo`0Fooooo`005oooool00ol0003oooooooooo`3]ooooo`03o`000?oo
oooooooo01Kooooo000Hooooo`03o`000?oooooooooo0>_ooooo00?o0000ooooooooool05oooool0
01Sooooo00?o0000ooooooooool0joooool00ol0003oooooooooo`0Gooooo`006?ooool00ol0003o
ooooooooo`3[ooooo`03o`000?oooooooooo01Oooooo000Iooooo`03o`000?oooooooooo0>Wooooo
00?o0000ooooooooool06?ooool001Wooooo00?o0000ooooooooool0jOooool00ol0003ooooooooo
o`0Hooooo`006Oooool00ol0003oooooooooo`3Yooooo`03o`000?oooooooooo01Sooooo000Ioooo
o`03o`000?oooooooooo0>Wooooo00?o0000ooooooooool06?ooool001[ooooo00?o0000oooooooo
ool0ioooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`3Wooooo`03o`00
0?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo0>Oooooo00?o0000ooooooooool06Ooo
ool001_ooooo00?o0000ooooooooool0iOooool00ol0003oooooooooo`0Jooooo`006oooool00ol0
003oooooooooo`3Uooooo`03o`000?oooooooooo01[ooooo000Kooooo`03o`000?oooooooooo0>Go
oooo00?o0000ooooooooool06_ooool001cooooo00?o0000ooooooooool0hoooool00ol0003ooooo
ooooo`0Kooooo`007?ooool00ol0003oooooooooo`3Sooooo`03o`000?oooooooooo01_ooooo000L
ooooo`03o`000?oooooooooo0>?ooooo00?o0000ooooooooool06oooool001cooooo00?o0000oooo
ooooool0hoooool00ol0003oooooooooo`0Kooooo`007Oooool00ol0003oooooooooo`3Qooooo`03
o`000?oooooooooo01cooooo000Mooooo`03o`000?oooooooooo0>7ooooo00?o0000ooooooooool0
7?ooool001gooooo00?o0000ooooooooool0hOooool00ol0003oooooooooo`0Looooo`007_ooool0
0ol0003oooooooooo`3Oooooo`03o`000?oooooooooo01gooooo000Nooooo`03o`000?oooooooooo
0=oooooo00?o0000ooooooooool07Oooool001kooooo00?o0000ooooooooool0goooool00ol0003o
ooooooooo`0Mooooo`007oooool00ol0003oooooooooo`3Mooooo`03o`000?oooooooooo01kooooo
000Oooooo`03o`000?oooooooooo0=gooooo00?o0000ooooooooool07_ooool001oooooo00?o0000
ooooooooool0gOooool00ol0003oooooooooo`0Nooooo`007oooool00ol0003oooooooooo`3Moooo
o`03o`000?oooooooooo01kooooo000Pooooo`03o`000?oooooooooo0=_ooooo00?o0000oooooooo
ool07oooool0023ooooo00?o0000ooooooooool0foooool00ol0003oooooooooo`0Oooooo`008?oo
ool00ol0003oooooooooo`3Kooooo`03o`000?oooooooooo01oooooo000Qooooo`03o`000?oooooo
oooo0=Wooooo00?o0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool0fOooool00ol0
003oooooooooo`0Pooooo`008Oooool00ol0003oooooooooo`3Iooooo`03o`000?oooooooooo023o
oooo000Rooooo`03o`000?oooooooooo0=Oooooo00?o0000ooooooooool08Oooool002;ooooo00?o
0000ooooooooool0eoooool00ol0003oooooooooo`0Qooooo`008_ooool00ol0003oooooooooo`3G
ooooo`03o`000?oooooooooo027ooooo000Rooooo`03o`000?oooooooooo0=Oooooo00?o0000oooo
ooooool08Oooool002?ooooo00?o0000ooooooooool0eOooool00ol0003oooooooooo`0Rooooo`00
8oooool00ol0003oooooooooo`3Eooooo`03o`000?oooooooooo02;ooooo000Sooooo`03o`000?oo
oooooooo0=Gooooo00?o0000ooooooooool08_ooool002Cooooo00?o0000ooooooooool0doooool0
0ol0003oooooooooo`0Sooooo`009?ooool3o`3o0=3ooooo0ol0o`000ol0003oooooooooo`0Soooo
o`008oooool5o`3o0<kooooo1Ol0o`0Uooooo`008_ooool7o`3o0<cooooo1ol0o`0Tooooo`008_oo
ool7o`3o0<cooooo1ol0o`0Tooooo`008_ooool7o`3o0<cooooo1ol0o`0Tooooo`008oooool5o`3o
0003o`000?oooooooooo0<_ooooo1Ol0o`0Uooooo`009?ooool3o`3o00;ooooo0_l00039ooooo`;o
000000Coooooo`3o0?l0o`3o0?l09_ooool002_ooooo00?o0000ooooooooool0aOooool00ol0003o
ooooooooo`0Zooooo`00;?ooool00ol0003oooooooooo`33ooooo`03o`000?oooooooooo02_ooooo
000]ooooo`;o0000`Oooool2o`0002kooooo000_ooooo`03o`000?oooooooooo0;gooooo00?o0000
ooooooooool0;_ooool0033ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`0_oooo
o`00<Oooool2o`000;Wooooo0_l0000booooo`00<oooool00ol0003oooooooooo`2eooooo`03o`00
0?oooooooooo03;ooooo000dooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool0<ooo
ool003Gooooo0_l0002aooooo`;o0000=_ooool003Oooooo00?o0000ooooooooool0[Oooool00ol0
003oooooooooo`0fooooo`00>?ooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo03Oo
oooo000iooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool0>?ooool003[ooooo0_l0
002Wooooo`;o0000>oooool003cooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`0k
ooooo`00?Oooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo03cooooo000nooooo`;o
0000Woooool2o`0003oooooo0010ooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool0
?oooool0047ooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`10ooooo`00@_ooool2
o`0009Oooooo0_l00013ooooo`00A?ooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo
04?ooooo0015ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0A?ooool004Kooooo
0_l0002?ooooo`;o0000Aoooool004Sooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`17ooooo`00BOooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo04Sooooo001:oooo
o`;o0000Qoooool2o`0004_ooooo001<ooooo`03o`000?oooooooooo08?ooooo00?o0000oooooooo
ool0Boooool004gooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`1<ooooo`00C_oo
ool2o`0007oooooo0_l0001?ooooo`00D?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooo
oooo04oooooo001Aooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0D?ooool005;o
oooo0_l0001gooooo`;o0000Doooool005Cooooo00?o0000ooooooooool0Loooool00ol0003ooooo
ooooo`1Cooooo`00EOooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo05Cooooo001F
ooooo`;o0000Koooool2o`0005Oooooo001Hooooo`03o`000?oooooooooo06_ooooo00?o0000oooo
ooooool0Eoooool005Wooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`1Hooooo`00
F_ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo05Wooooo001Kooooo`;o0000IOoo
ool2o`0005cooooo001Mooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0G?ooool0
05kooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1Mooooo`00Goooool2o`0005go
oooo0_l0001Pooooo`00HOooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo063ooooo
001Rooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0HOooool006?ooooo0_l00000
1?oooooo0?l0o`3o0?l0o`1=ooooo`?oo`0000?oooooo`000?l00000I?ooool006Gooooo1Ol0o`1;
ooooo`Goo`00I_ooool006Cooooo1ol0o`19ooooo`Ooo`00IOooool006Cooooo1ol0o`19o`0000Oo
o`00IOooool006Cooooo1ol0o`19ooooo`Ooo`00IOooool006Gooooo1Ol0o`1;ooooo`Goo`00I_oo
ool006Kooooo0ol0o`1=ooooo`?oo`00Ioooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0500054, -0.0132976, \
0.00383279, 0.00366225}},
  CellTags->{"b:0", "LocalInteractions:0"}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[6]=",
  CellTags->{"b:0", "LocalInteractions:0"}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 701}},
WindowSize->{645, 567},
WindowMargins->{{Automatic, 22}, {Automatic, 50}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "b:0"->{
    Cell[1776, 53, 73, 1, 38, "ObjectName",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[1852, 56, 985, 35, 32, "Usage",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[2840, 93, 128, 4, 24, "Notes",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[2971, 99, 380, 8, 91, "3ColumnTable",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[3354, 109, 148, 4, 24, "Notes",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[3527, 117, 77, 1, 38, "ExampleSection",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[3607, 120, 140, 3, 26, "Input",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[3750, 125, 346, 7, 90, "Input",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[4121, 136, 117, 3, 26, "Input",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[4241, 141, 200, 4, 25, "Output",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[4478, 150, 125, 3, 26, "Input",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[4606, 155, 19583, 338, 294, 1585, 110, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[24204, 496, 119, 3, 26, "Input",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[24348, 503, 129, 3, 26, "Input",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[24480, 508, 17497, 295, 294, 1184, 88, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[41980, 805, 198, 5, 25, "Output",
      CellTags->{"b:0", "LocalInteractions:0"}]},
  "LocalInteractions:0"->{
    Cell[1776, 53, 73, 1, 38, "ObjectName",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[1852, 56, 985, 35, 32, "Usage",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[2840, 93, 128, 4, 24, "Notes",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[2971, 99, 380, 8, 91, "3ColumnTable",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[3354, 109, 148, 4, 24, "Notes",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[3527, 117, 77, 1, 38, "ExampleSection",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[3607, 120, 140, 3, 26, "Input",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[3750, 125, 346, 7, 90, "Input",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[4121, 136, 117, 3, 26, "Input",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[4241, 141, 200, 4, 25, "Output",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[4478, 150, 125, 3, 26, "Input",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[4606, 155, 19583, 338, 294, 1585, 110, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[24204, 496, 119, 3, 26, "Input",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[24348, 503, 129, 3, 26, "Input",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[24480, 508, 17497, 295, 294, 1184, 88, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"b:0", "LocalInteractions:0"}],
    Cell[41980, 805, 198, 5, 25, "Output",
      CellTags->{"b:0", "LocalInteractions:0"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"b:0", 42837, 831},
  {"LocalInteractions:0", 44434, 866}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 73, 1, 38, "ObjectName",
  CellTags->{"b:0", "LocalInteractions:0"}],
Cell[1852, 56, 985, 35, 32, "Usage",
  CellTags->{"b:0", "LocalInteractions:0"}],
Cell[2840, 93, 128, 4, 24, "Notes",
  CellTags->{"b:0", "LocalInteractions:0"}],
Cell[2971, 99, 380, 8, 91, "3ColumnTable",
  CellTags->{"b:0", "LocalInteractions:0"}],
Cell[3354, 109, 148, 4, 24, "Notes",
  CellTags->{"b:0", "LocalInteractions:0"}],

Cell[CellGroupData[{
Cell[3527, 117, 77, 1, 38, "ExampleSection",
  CellTags->{"b:0", "LocalInteractions:0"}],
Cell[3607, 120, 140, 3, 26, "Input",
  CellTags->{"b:0", "LocalInteractions:0"}],
Cell[3750, 125, 346, 7, 90, "Input",
  CellTags->{"b:0", "LocalInteractions:0"}],

Cell[CellGroupData[{
Cell[4121, 136, 117, 3, 26, "Input",
  CellTags->{"b:0", "LocalInteractions:0"}],
Cell[4241, 141, 200, 4, 25, "Output",
  CellTags->{"b:0", "LocalInteractions:0"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4478, 150, 125, 3, 26, "Input",
  CellTags->{"b:0", "LocalInteractions:0"}],
Cell[4606, 155, 19583, 338, 294, 1585, 110, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->{"b:0", "LocalInteractions:0"}]
}, Open  ]],
Cell[24204, 496, 119, 3, 26, "Input",
  CellTags->{"b:0", "LocalInteractions:0"}],

Cell[CellGroupData[{
Cell[24348, 503, 129, 3, 26, "Input",
  CellTags->{"b:0", "LocalInteractions:0"}],
Cell[24480, 508, 17497, 295, 294, 1184, 88, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->{"b:0", "LocalInteractions:0"}],
Cell[41980, 805, 198, 5, 25, "Output",
  CellTags->{"b:0", "LocalInteractions:0"}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

