(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     98663,       1507]*)
(*NotebookOutlinePosition[    351965,      10340]*)
(*  CellTagsIndexPosition[    351876,      10334]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ExtractGraph", "ObjectName",
  CellTags->"LocalInteractions:14"],

Cell[TextData[{
  "\[Bullet] ExtractGraph[ ",
  StyleBox["model",
    FontSlant->"Italic"],
  " ] gives the ",
  StyleBox["Combinatorica",
    FontSlant->"Italic"],
  " graph representing the current state of the model."
}], "Usage",
  CellTags->"LocalInteractions:14"],

Cell["\<\
\[FilledSmallSquare] Each vertex in the underlying graph is colored \
according to the current strategy held by the corresponding agent.\
\>", \
"Notes",
  CellTags->"LocalInteractions:14"],

Cell[TextData[{
  "\[FilledSmallSquare] The graph conforms to the options specified for ",
  StyleBox["NeighborhoodsToDraw",
    FontFamily->"Courier"],
  ",",
  StyleBox[" InteractionNeighborhoodColor",
    FontFamily->"Courier"],
  ",",
  StyleBox[" UpdateNeighborhoodColor",
    FontFamily->"Courier"],
  ",",
  StyleBox[" ",
    FontFamily->"Courier"],
  "and",
  StyleBox[" NeighborhoodStyle",
    FontFamily->"Courier"],
  " in the ",
  StyleBox["LocalInteractionModel",
    FontFamily->"Courier"],
  " command which created the model."
}], "Notes",
  CellTags->"LocalInteractions:14"],

Cell["\<\
\[FilledSmallSquare] See also: LocalInteractionModel.\
\>", "Notes",
  CellTags->"LocalInteractions:14"],

Cell[CellGroupData[{

Cell["Example", "ExampleSection",
  CellTags->"LocalInteractions:14"],

Cell[BoxData[
    \(\(m = 
        LocalInteractionModel[\[IndentingNewLine]NeighborhoodsToDraw \[Rule] \
{Interaction, Update}, \[IndentingNewLine]InteractionNeighborhood \[Rule] 
            RandomGraph[10, 
              0.3], \[IndentingNewLine]UpdateNeighborhood \[Rule] 
            RandomGraph[10, 
              0.3], \[IndentingNewLine]InitialStrategyDistribution \[Rule] 
            Table[Random[
                Integer, {1, 
                  2}], {10}], \[IndentingNewLine]InteractionNeighborhoodColor \
\[Rule] Green, \[IndentingNewLine]UpdateNeighborhoodColor \[Rule] 
            Yellow\[IndentingNewLine]];\)\)], "Input",
  CellLabel->"In[6]:=",
  CellTags->"LocalInteractions:14"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ExtractGraph[m] // ShowGraph;\)\)], "Input",
  CellLabel->"In[7]:=",
  CellTags->"LocalInteractions:14"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.909091 0.0126467 0.951424 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 1 0 r
.005 w
[ ] 0 setdash
.86773 .77962 m
.13227 .77962 L
s
.86773 .77962 m
.04545 .5 L
s
.86773 .77962 m
.13227 .22038 L
s
.86773 .77962 m
.64046 .04757 L
s
.86773 .77962 m
.90223 .63678 L
.95455 .5 L
s
1 1 0 r
.86773 .77962 m
.92005 .64284 L
.95455 .5 L
s
.86773 .77962 m
.91114 .63981 L
.95455 .5 L
s
0 1 0 r
.64046 .95243 m
.35954 .95243 L
s
.64046 .95243 m
.95455 .5 L
s
.35954 .95243 m
.04545 .5 L
s
1 1 0 r
.35954 .95243 m
.22259 .59433 L
.13227 .22038 L
s
.35954 .95243 m
.26922 .57848 L
.13227 .22038 L
s
.35954 .95243 m
.33072 .5 L
.35954 .04757 L
s
.35954 .95243 m
.38836 .5 L
.35954 .04757 L
s
0 1 0 r
.35954 .95243 m
.59032 .56868 L
.86773 .22038 L
s
1 1 0 r
.35954 .95243 m
.63695 .60413 L
.86773 .22038 L
s
.35954 .95243 m
.61364 .58641 L
.86773 .22038 L
s
0 1 0 r
.35954 .95243 m
.64263 .70546 L
.95455 .5 L
s
1 1 0 r
.35954 .95243 m
.67145 .74697 L
.95455 .5 L
s
.35954 .95243 m
.65704 .72621 L
.95455 .5 L
s
.13227 .77962 m
.07995 .64284 L
.04545 .5 L
s
.13227 .77962 m
.09777 .63678 L
.04545 .5 L
s
.13227 .77962 m
.11445 .5 L
.13227 .22038 L
s
.13227 .77962 m
.15008 .5 L
.13227 .22038 L
s
.13227 .77962 m
.22259 .40567 L
.35954 .04757 L
s
.13227 .77962 m
.26922 .42152 L
.35954 .04757 L
s
0 1 0 r
.13227 .77962 m
.64046 .04757 L
s
1 1 0 r
.13227 .77962 m
.5345 .61112 L
.95455 .5 L
s
.13227 .77962 m
.55231 .66849 L
.95455 .5 L
s
0 1 0 r
.04545 .5 m
.13227 .22038 L
s
1 1 0 r
.04545 .5 m
.5 .53171 L
.95455 .5 L
s
.04545 .5 m
.5 .46829 L
.95455 .5 L
s
0 1 0 r
.13227 .22038 m
.38086 .11625 L
.64046 .04757 L
s
1 1 0 r
.13227 .22038 m
.39187 .15171 L
.64046 .04757 L
s
.13227 .22038 m
.38636 .13398 L
.64046 .04757 L
s
.35954 .04757 m
.5 .05737 L
.64046 .04757 L
s
.35954 .04757 m
.5 .03777 L
.64046 .04757 L
s
0 1 0 r
.64046 .04757 m
.74859 .14191 L
.86773 .22038 L
s
1 1 0 r
.64046 .04757 m
.7596 .12605 L
.86773 .22038 L
s
.64046 .04757 m
.7541 .13398 L
.86773 .22038 L
s
0 1 0 r
.86773 .22038 m
.95455 .5 L
s
1 0 0 r
.025 w
.86773 .77962 Mdot
.64046 .95243 Mdot
0 1 0 r
.35954 .95243 Mdot
1 0 0 r
.13227 .77962 Mdot
0 1 0 r
.04545 .5 Mdot
.13227 .22038 Mdot
1 0 0 r
.35954 .04757 Mdot
0 1 0 r
.64046 .04757 Mdot
1 0 0 r
.86773 .22038 Mdot
0 1 0 r
.95455 .5 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[7]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00I_ooool3ool001oooooo3oooo`0Oooooo`?o0?l0Ioooool006Gooooo1Ooo000Aooooo`go
ool03oooool=oooo017ooooo1Ol0o`1Vooooo`00I?ooool7ool000?ooooo3Oooo`0Yooooo`goool0
0oooool7o`3o06Gooooo001Tooooo`Ooo`001?ooo`11ooooo`Coool01ol0o`1Uooooo`00I?ooool7
ool000Cooooo3Oooo`0Wooooo`goool000Coooooo`3o0?l0o`3oool01ol0o`1Uooooo`00IOooool5
ool001;ooooo3Oooo`0=ooooo`goool02oooool2o`3o00?oool00_ooool5o`3o00;oool0I?ooool0
06Kooooo0ooo000Pooooo`goool05?ooool3o`3o00Coool01?ooool4o`3o00;ooooo0_ooo`1Soooo
o`00I_ooool2oooo03kooooo1?l0o`05oooo00Kooooo00Co0?l0oooooooooooo0?l00oooool00ol0
o`3oool0oooo001Qooooo`00IOooool3oooo03_ooooo0ol0o`000oooooooool0oooo0003oooo00So
oooo00Go0?l0ooooooooooooooooo`3o0004ooooo`03o`3o0?ooo`3oool0063ooooo001Uooooo`?o
ool0=oooool4o`3o0005ooooooooo`3oool0oooo0?ooool00_ooo`09ooooo`03o`3o0?oooooooooo
00?ooooo00?o0?l0ooooooooool00_ooool01?l0o`3oool0oooo0?ooo`1Nooooo`00I?ooool2oooo
0003ooooooooo`3ooooo03;ooooo1?l0o`02ooooo`?oool000Cooooooooo0?ooo`3oool02_ooool0
0ol0o`3oooooooooo`04ooooo`03o`3o0?oooooooooo00?ooooo0_l0o`02oooo05gooooo001Toooo
o`Coool0<?ooool3o`3o00?ooooo0oooo`02ooooo`;oool03Oooool00ol0o`3oooooooooo`04oooo
o`03o`3o0?oooooooooo00Gooooo00Co0?l0oooo0?ooo`3oool0Foooool006Cooooo0oooo`000ooo
ooooool0ooooo`0Zooooo`Co0?l00oooool3oooo00?ooooo0_ooo`0>ooooo`03o`3o0?oooooooooo
00Kooooo00?o0?l0ooooooooool01Oooool01?l0o`3oool0oooo0?ooo`1Jooooo`00Hoooool01_oo
o`3ooooooooo0?ooo`3ooooooooo02Oooooo1?l0o`04ooooo`?oool00oooool3oooo00oooooo00?o
0?l0ooooooooool01oooool00ol0o`3oooooooooo`06ooooo`03o`3o0?ooooooool000;oool0F?oo
ool006?ooooo0_ooo`001?ooooooool0ooooooooo`0Sooooo`Co0?l01Oooool3oooo00Cooooo0_oo
o`0Booooo`03o`3o0?oooooooooo00Oooooo00?o0?l0ooooooooool01oooool01?l0o`3ooooooooo
0?ooool2oooo05Kooooo001Sooooo`;oool000Cooooooooo0?ooooooool08?ooool3o`3o00Kooooo
0oooo`04ooooo`?oool04oooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooooooo00Oooooo
00Ko0?l0ooooooooo`3oool0ooooooooo`1Eooooo`00H_ooool01oooo`3ooooooooo0?ooooooool0
ooooooooo`007?ooool4o`3o00Oooooo0_ooo`05ooooo`;oool05Oooool00ol0o`3oooooooooo`0:
ooooo`03o`3o0?oooooooooo00Sooooo0_l0o`000oooooooool0ooooo`02oooo05?ooooo001Roooo
o`07oooo0?ooooooool0ooooooooo`3ooooooooo000Hooooo`Co0?l02?ooool3oooo00Gooooo0_oo
o`0Gooooo`03o`3o0?oooooooooo00[ooooo00?o0?l0ooooooooool02_ooool00ol0o`3ooooooooo
0002ooooo`03oooo0?oooooooooo053ooooo001Qooooo`03oooo0?ooooooool000;ooooo00?oool0
ooooooooo`005Oooool3o`3o00Wooooo0oooo`05ooooo`?oool06?ooool00ol0o`3oooooooooo`0<
ooooo`03o`3o0?oooooooooo00[ooooo00?o0?l0ooooooooo`000_ooool2oooo053ooooo001Qoooo
o`03oooo0?ooooooool000;ooooo00?oool0ooooooooo`004Oooool4o`3o00Wooooo0oooo`06oooo
o`;oool06_ooool00ol0o`3oooooooooo`0=ooooo`03o`3o0?oooooooooo00_ooooo00Co0?l0oooo
ooooo`3oool00_ooool00oooo`3oooooooooo`1=ooooo`00HOooool00oooo`3ooooooooo0002oooo
o`03oooo0?ooooooool000gooooo1?l0o`0:ooooo`?oool01oooool2oooo01cooooo00?o0?l0oooo
ooooool03Oooool00ol0o`3oooooooooo`0<ooooo`04o`3o0?oooooooooooooo00;ooooo0_ooo`1=
ooooo`00H?ooool01?ooo`3oooooooooooooo`02ooooo`03oooo0?ooooooool000[ooooo0ol0o`0;
ooooo`?oool01oooool3oooo01gooooo00?o0?l0ooooooooool03oooool00ol0o`3oooooooooo`0<
ooooo`04o`3o0?oooooooooooooo00?ooooo00?oool0ooooooooool0B_ooool0063ooooo00Coool0
ooooooooooooool00_ooool00oooo`3ooooooooo0006ooooo`Co0?l02oooool3oooo00Sooooo0_oo
o`0Oooooo`03o`3o0?oooooooooo013ooooo00?o0?l0ooooooooool03Oooool00ol0o`3ooooooooo
o`02oooo00;ooooo0_ooo`1:ooooo`00Goooool01?ooo`3oooooooooooooo`03ooooo`03oooo0?oo
ooooool000?ooooo0ol0o`0<ooooo`?oool02?ooool3oooo023ooooo00?o0?l0ooooooooool04Ooo
ool00ol0o`3oooooooooo`0>ooooo`;o0?l00_ooool01Oooo`3oooooooooooooooooool004Wooooo
001Oooooo`04oooo0?oooooooooooooo00?ooooo00?oool0ooooooooo`000ol0o`0<ooooo`?oool0
2Oooool2oooo02?ooooo00?o0?l0ooooooooool04Oooool00ol0o`3oooooooooo`0@ooooo`04o`3o
0?oooooooooooooo00?ooooo0_ooo`17ooooo`00Goooool01?ooo`3oooooooooooooo`03ooooo`03
oooo0?l0o`3o0?l000cooooo0oooo`0:ooooo`;oool09?ooool00ol0o`3oooooooooo`0Cooooo`03
o`3o0?oooooooooo013ooooo00?o0?l0ooooooooool00_ooo`03ooooo`03oooo0?oooooooooo04Co
oooo001Nooooo`05oooo0?ooooooooooooooooooo`000_ooool2o`3o0003ooooooooo`3ooooo00So
oooo0oooo`0:ooooo`?oool09Oooool00ol0o`3oooooooooo`0Dooooo`03o`3o0?oooooooooo017o
oooo00Go0?l0oooooooooooooooooooo0003ooooo`;oool0A?ooool005kooooo00Coool0oooooooo
ooooool00ol0o`001?ooo`3oooooooooooooo`06ooooo`?oool02oooool2oooo02Sooooo00?o0?l0
ooooooooool05?ooool00ol0o`3oooooooooo`0Booooo`05o`3o0?ooooooooooooooooooo`001?oo
ool00oooo`3oooooooooo`11ooooo`00GOooool00oooo`3oooooooooo`02o`3o00?ooooo00Goool0
oooooooooooooooooooo0003ooooo`;oool03?ooool2oooo02Wooooo00?o0?l0ooooooooool05_oo
ool00ol0o`3oooooooooo`0Booooo`04o`3o0?ooooooooooooooo`;oool00oooool00oooo`3ooooo
ooooo`10ooooo`00GOooool3o`3o0003ooooooooo`3ooooo00;ooooo00Coool0oooooooooooooooo
1?ooo`0;ooooo`?oool0:_ooool00ol0o`3oooooooooo`0Gooooo`03o`3o0?oooooooooo01?ooooo
00?o0?l0ooooooooool00_ooool01Oooo`3oooooooooooooooooool0047ooooo001Kooooo`;o0?l0
00Goool0oooooooooooooooooooo0003ooooo`03oooo0?ooooooool000;oool03?ooool2oooo02go
oooo00?o0?l0ooooooooool05oooool00ol0o`3oooooooooo`0Dooooo`;o0?l00oooool01Oooo`3o
ooooooooooooooooool0043ooooo001Iooooo`;o0?l000?ooooooooo0?ooool00_ooool01?ooo`3o
ooooooooooooool3oooo00;ooooo00?oool0ooooooooool02?ooool2oooo02kooooo00?o0?l0oooo
ooooool06Oooool00ol0o`3oooooooooo`0Eooooo`04o`3o0?ooooooooooooooo`;oool00_ooool0
0oooo`3oooooooooo`0mooooo`00E_ooool3o`3o00?ooooo00Coool0oooooooooooooooo1?ooo`00
0oooooooool0ooooo`02ooooo`03oooo0?oooooooooo00Gooooo0oooo`0_ooooo`03o`3o0?oooooo
oooo01[ooooo00?o0?l0ooooooooool05_ooool2o`3o00?ooooo00Coool0ooooooooooooool0?_oo
ool005Cooooo0_l0o`06ooooo`03oooo0?ooooooool000;oool01?ooool01Oooo`3ooooooooooooo
ooooool000Cooooo0oooo`0aooooo`03o`3o0?oooooooooo01_ooooo00?o0?l0ooooooooool06?oo
ool01Ol0o`3oooooooooooooooooool000;ooooo0_ooo`0looooo`00DOooool3o`3o00Oooooo0ooo
o`02ooooo`03oooo0?oooooooooo00;ooooo00Coool0oooooooooooooooo1Oooo`0dooooo`03o`3o
0?oooooooooo01cooooo00?o0?l0ooooooooool06?ooool2o`3o00;ooooo0_ooo`02ooooo`03oooo
0?oooooooooo03Wooooo001?ooooo`;o0?l01oooool4oooo00?ooooo00?oool0ooooooooool00ooo
ool00oooo`3ooooooooo0002oooo03Oooooo00?o0?l0ooooooooool07Oooool00ol0o`3ooooooooo
o`0Jooooo`05o`3o0?ooooooooooooooooooo`000_ooool00oooo`3oooooooooo`0hooooo`00COoo
ool2o`3o00Kooooo0oooo`02ooooo`03oooo0?oooooooooo00;ooooo00Coool0oooooooooooooooo
1?ooo`02ooooo`03oooo0?oooooooooo03Cooooo00?o0?l0ooooooooool07_ooool00ol0o`3ooooo
ooooo`0Kooooo`;o0?l00_ooool01?ooo`3oooooooooooooo`0iooooo`00B_ooool3o`3o00Gooooo
0oooo`05ooooo`03oooo0?oooooooooo00;ooooo1?ooo`02ooooo`05oooo0?oooooooooooooooooo
o`00=_ooool00ol0o`3oooooooooo`0Oooooo`03o`3o0?oooooooooo01cooooo00?o0?l0oooooooo
ool00_ooo`000oooooooool0ooooo`0gooooo`00B?ooool2o`3o00Gooooo0oooo`08ooooo`Koool0
1Oooool01Oooo`3oooooooooooooooooool003Gooooo00?o0?l0ooooooooool08?ooool00ol0o`3o
ooooooooo`0Mooooo`;o0?l00_ooool00oooo`3ooooooooo000gooooo`00AOooool3o`3o00Cooooo
0oooo`09ooooo`?oool00oooool00oooo`3oooooooooo`04ooooo`05oooo0?oooooooooooooooooo
o`00=?ooool00ol0o`3oooooooooo`0Qooooo`03o`3o0?oooooooooo01oooooo00Go0?l0oooooooo
ooooool0ooooo`02oooo03Gooooo0013ooooo`;o0?l01?ooool3oooo00Sooooo1?ooo`000ooooooo
ool0ooooo`03ooooo`03oooo0?oooooooooo00?ooooo00?oool0ooooooooool00_ooool00oooo`3o
ooooooooo`0booooo`03o`3o0?oooooooooo027ooooo00?o0?l0ooooooooool08?ooool2o`3o0005
ooooooooo`3oool0ooooooooo`00=?ooool0047ooooo0_l0o`04ooooo`;oool01oooool4oooo00Co
oooo00?oool0ooooooooool00oooool00oooo`3oooooooooo`03ooooo`03oooo0?oooooooooo00;o
oooo00?oool0ooooooooool0<Oooool00ol0o`3oooooooooo`0Sooooo`03o`3o0?oooooooooo027o
oooo0_l0o`001?ooooooool0ooooooooo`0cooooo`00?_ooool3o`3o00?ooooo0oooo`05ooooo`Co
ool02?ooool00oooo`3oooooooooo`03ooooo`03oooo0?oooooooooo00?ooooo00?oool0oooooooo
ool00_ooool00oooo`3oooooooooo`0`ooooo`03o`3o0?oooooooooo02Cooooo00?o0?l0oooooooo
ool08oooool01Ol0o`3ooooooooo0?ooooooool003;ooooo000looooo`;o0?l00oooool3oooo00Go
oooo0oooo`0<ooooo`03oooo0?oooooooooo00;ooooo00?oool0ooooooooool01?ooool00oooo`3o
ooooooooo`02ooooo`03oooo0?oooooooooo033ooooo00?o0?l0ooooooooool09?ooool00ol0o`3o
ooooooooo`0Tooooo`;o0?l000?oool0ooooooooo`00<Oooool003Wooooo0ol0o`02ooooo`?oool0
1?ooool4oooo00kooooo00?oool0ooooooooool00oooool00oooo`3oooooooooo`04ooooo`03oooo
0?oooooooooo00;ooooo00?oool0ooooooooool0;oooool00ol0o`3oooooooooo`0Vooooo`03o`3o
0?oooooooooo02Gooooo00Co0?l0oooo0?ooo`3oool0<?ooool003Oooooo0_l0o`02ooooo`?oool0
0oooool4oooo01;ooooo00?oool0ooooooooool00oooool00oooo`3oooooooooo`04ooooo`03oooo
0?oooooooooo00?ooooo00?oool0ooooooooool0;Oooool00ol0o`3oooooooooo`0Wooooo`03o`3o
0?oooooooooo02Kooooo0_l0o`02oooo02oooooo000eooooo`;o0?l000Cooooooooo0?ooo`3oool0
0_ooool4oooo01Gooooo00?oool0ooooooooool01?ooool00oooo`3oooooooooo`04ooooo`03oooo
0?oooooooooo00?ooooo00?oool0ooooooooool0;?ooool00ol0o`3oooooooooo`0Xooooo`03o`3o
0?oooooooooo02Sooooo00Co0?l0oooo0?ooo`3oool0;Oooool003;ooooo0ol0o`03oooo00;ooooo
0oooo`0Iooooo`03oooo0?oooooooooo00?ooooo00?oool0ooooooooool01Oooool00oooo`3ooooo
ooooo`03ooooo`03oooo0?oooooooooo02cooooo00?o0?l0ooooooooool0:Oooool00ol0o`3ooooo
ooooo`0Xooooo`04o`3o0?ooo`3oool0oooo02cooooo000`ooooo`;o0?l00oooo`000oooooooool0
oooo0002oooo01cooooo00?oool0ooooooooool00oooool00oooo`3oooooooooo`05ooooo`03oooo
0?oooooooooo00?ooooo00?oool0ooooooooool0:oooool00ol0o`3oooooooooo`0Zooooo`03o`3o
0?oooooooooo02[ooooo00?o0?l0oooo0?ooo`00:oooool002gooooo0_l0o`07oooo01oooooo00?o
ool0ooooooooool01?ooool00oooo`3oooooooooo`05ooooo`03oooo0?oooooooooo00?ooooo00?o
ool0ooooooooool0:_ooool00ol0o`3oooooooooo`0[ooooo`03o`3o0?oooooooooo02_ooooo00?o
0?l0oooo0?ooo`00:_ooool002Cooooo0ol0o`04ooooo`03o`3o0?ooo`3oool000Coool08oooool0
0oooo`3oooooooooo`04ooooo`03oooo0?oooooooooo00Gooooo00?oool0ooooooooool00oooool0
0oooo`3oooooooooo`0Zooooo`03o`3o0?oooooooooo02cooooo00?o0?l0ooooooooool0;?ooool2
oooo00?oo`009_ooool002?ooooo1Ol0o`000oooooooool0oooo0003oooo02Oooooo00?oool0oooo
ooooool00oooool00oooo`3oooooooooo`06ooooo`03oooo0?oooooooooo00?ooooo00?oool0oooo
ooooool0:Oooool00ol0o`3oooooooooo`0]ooooo`03o`3o0?oooooooooo02gooooo1Ooo000Uoooo
o`008_ooool7o`3o00;oool0:Oooool00oooo`3oooooooooo`04ooooo`03oooo0?oooooooooo00Ko
oooo00?oool0ooooooooool00oooool00oooo`3oooooooooo`0Xooooo`03o`3o0?oooooooooo02ko
oooo00?o0?l0ooooooooool0;?ooool7ool002Cooooo000Rooooo`Oo0?l0:oooool00oooo`3ooooo
ooooo`04ooooo`03oooo0?oooooooooo00Kooooo00?oool0ooooooooool00oooool00oooo`3ooooo
ooooo`0Xooooo`03o`3o0?oooooooooo02oooooo00?o0?l0ooooooooool0:oooool7ool002Cooooo
000Rooooo`Oo0?l0:_ooool00oooo`3oooooooooo`05ooooo`03oooo0?oooooooooo00Kooooo00?o
ool0ooooooooool00oooool00oooo`3oooooooooo`0Wooooo`03o`3o0?oooooooooo033ooooo00?o
0?l0ooooooooool0:oooool7ool002Cooooo000Sooooo`Ko0?l0:_ooool00oooo`3oooooooooo`04
ooooo`03oooo0?oooooooooo00Kooooo00?oool0ooooooooool01?ooool00oooo`3oooooooooo`0V
ooooo`03o`3o0?oooooooooo037ooooo00?o0?l0ooooooooool0;?ooool5ool002Gooooo000Toooo
o`?o0?l00_ooool2o`3o02Sooooo00?oool0ooooooooool01?ooool00oooo`3oooooooooo`06oooo
o`03oooo0?oooooooooo00Cooooo00?oool0ooooooooool09Oooool00ol0o`3oooooooooo`0coooo
o`03o`3o0?oooooooooo02cooooo0ooo00000ol0o`3oooooooooo`0Sooooo`009?ooool00ol0o`3o
ool0oooo0004ooooo`03o`3o0?oooooooooo02Cooooo00?oool0ooooooooool01Oooool00oooo`3o
ooooooooo`06ooooo`03oooo0?oooooooooo00Cooooo00?oool0ooooooooool09Oooool00ol0o`3o
ooooooooo`0cooooo`03o`3o0?oooooooooo02_ooooo00Go0?l0oooo0?ooooooooooo`3o000Uoooo
o`009?ooool01?l0o`3oool0oooo0?ooo`04ooooo`03o`3o0?oooooooooo02?ooooo00?oool0oooo
ooooool01Oooool00oooo`3oooooooooo`06ooooo`03oooo0?oooooooooo00Cooooo00?oool0oooo
ooooool09?ooool00ol0o`3oooooooooo`0dooooo`03o`3o0?oooooooooo02[ooooo00?o0?l0oooo
0?ooool00_ooool00ol0o`3oooooooooo`0Sooooo`008oooool00ol0o`3ooooooooo0002oooo00Go
oooo0_l0o`0Rooooo`03oooo0?oooooooooo00Kooooo00?oool0ooooooooool01_ooool00oooo`3o
ooooooooo`04ooooo`03oooo0?oooooooooo02?ooooo00?o0?l0ooooooooool0=Oooool00ol0o`3o
ooooooooo`0Zooooo`;oool01?ooool00ol0o`3oooooooooo`0Rooooo`008oooool01?l0o`3ooooo
oooo0?ooool2oooo00Kooooo00?o0?l0ooooooooool07oooool00oooo`3oooooooooo`05ooooo`03
oooo0?oooooooooo00Oooooo00?oool0ooooooooool01?ooool00oooo`3oooooooooo`0Sooooo`03
o`3o0?oooooooooo03Kooooo00?o0?l0ooooooooool0:?ooool2oooo00Gooooo00?o0?l0oooooooo
ool08_ooool002?ooooo00?o0?l0ooooooooo`000oooo`07ooooo`03o`3o0?oooooooooo01kooooo
00?oool0ooooooooool01Oooool00oooo`3oooooooooo`07ooooo`03oooo0?oooooooooo00Gooooo
00?oool0ooooooooool08Oooool00ol0o`3oooooooooo`0gooooo`03o`3o0?oooooooooo02Oooooo
00?o0?l0oooo0?ooool01Oooool00ol0o`3oooooooooo`0Rooooo`008_ooool01?l0o`3ooooooooo
0?ooool3oooo00Sooooo0_l0o`0Mooooo`03oooo0?oooooooooo00Kooooo00?oool0ooooooooool0
1oooool00oooo`3oooooooooo`05ooooo`03oooo0?oooooooooo023ooooo00?o0?l0ooooooooool0
>?ooool00ol0o`3oooooooooo`0Vooooo`03o`3o0?ooo`3oool000Oooooo00?o0?l0ooooooooool0
8Oooool002;ooooo00Co0?l0ooooooooo`3ooooo0_ooo`000oooooooool0ooooo`08ooooo`03o`3o
0?oooooooooo01[ooooo00?oool0ooooooooool01_ooool00oooo`3oooooooooo`07ooooo`03oooo
0?oooooooooo00Gooooo00?oool0ooooooooool08?ooool00ol0o`3oooooooooo`0iooooo`03o`3o
0?oooooooooo02Cooooo00?o0?l0oooo0?ooo`002?ooool00ol0o`3oooooooooo`0Qooooo`008_oo
ool01_l0o`3ooooooooo0?ooooooool0ooooo`;oool02_ooool00ol0o`3oooooooooo`0Iooooo`03
oooo0?oooooooooo00Gooooo00?oool0ooooooooool02?ooool00oooo`3oooooooooo`05ooooo`03
oooo0?oooooooooo01oooooo00?o0?l0ooooooooool0>_ooool00ol0o`3oooooooooo`0Tooooo`03
o`3o0?ooo`3oool000Sooooo00?o0?l0ooooooooool08Oooool002;ooooo00Ko0?l0ooooooooo`3o
oooooooo0?ooool2oooo00_ooooo0_l0o`0Hooooo`03oooo0?oooooooooo00Kooooo00?oool0oooo
ooooool02?ooool00oooo`3oooooooooo`05ooooo`03oooo0?oooooooooo01kooooo00?o0?l0oooo
ooooool0>oooool00ol0o`3oooooooooo`0Sooooo`03o`3o0?ooo`3oool000Wooooo00?o0?l0oooo
ooooool08Oooool0027ooooo00[o0?l0ooooooooooooool0ooooooooo`3ooooooooo0?ooooooool0
3?ooool00ol0o`3oooooooooo`0Eooooo`03oooo0?oooooooooo00Kooooo00?oool0ooooooooool0
2?ooool00oooo`3oooooooooo`05ooooo`03oooo0?oooooooooo01kooooo00?o0?l0ooooooooool0
??ooool00ol0o`3oooooooooo`0Qooooo`03o`3o0?ooo`3oool000_ooooo00?o0?l0ooooooooool0
8?ooool0027ooooo00[o0?l0ooooooooooooool0ooooooooo`3ooooooooo0?ooooooool03Oooool0
0ol0o`3oooooooooo`0Cooooo`03oooo0?oooooooooo00Oooooo00?oool0ooooooooool02?ooool0
0oooo`3oooooooooo`05ooooo`03oooo0?oooooooooo01gooooo00?o0?l0ooooooooool0?Oooool0
0ol0o`3oooooooooo`0Pooooo`04o`3o0?ooooooool0oooo00_ooooo00?o0?l0ooooooooool08?oo
ool0027ooooo00Ko0?l0ooooooooooooool0ooooooooo`02ooooo`03oooo0?ooooooool000gooooo
0_l0o`0Cooooo`03oooo0?oooooooooo00Kooooo00?oool0ooooooooool02Oooool00oooo`3ooooo
ooooo`05ooooo`03oooo0?oooooooooo01cooooo00?o0?l0ooooooooool0?_ooool00ol0o`3ooooo
ooooo`0Oooooo`04o`3o0?ooooooool0oooo00cooooo00?o0?l0ooooooooool08?ooool0023ooooo
00Oo0?l0oooooooooooooooooooo0?ooooooool000;ooooo00?oool0ooooooooo`003oooool00ol0
o`3oooooooooo`0@ooooo`03oooo0?oooooooooo00Kooooo00?oool0ooooooooool02?ooool00ooo
o`3oooooooooo`06ooooo`03oooo0?oooooooooo01_ooooo00?o0?l0ooooooooool0@?ooool00ol0
o`3oooooooooo`0Nooooo`04o`3o0?ooo`3ooooooooo00gooooo00?o0?l0ooooooooool07oooool0
023ooooo00Oo0?l0oooooooooooooooooooo0?ooooooool000;ooooo00?oool0ooooooooo`004?oo
ool00ol0o`3oooooooooo`0>ooooo`03oooo0?oooooooooo00Oooooo00?oool0ooooooooool02?oo
ool00oooo`3oooooooooo`06ooooo`03oooo0?oooooooooo01_ooooo00?o0?l0ooooooooool0@?oo
ool00ol0o`3oooooooooo`0Mooooo`04o`3o0?ooooooool0oooo00kooooo00?o0?l0ooooooooool0
7oooool0023ooooo00Oo0?l0oooooooooooooooooooo0?ooooooool000;ooooo00Coool0oooooooo
ooooool04?ooool2o`3o00kooooo00?oool0ooooooooool01oooool00oooo`3oooooooooo`08oooo
o`03oooo0?oooooooooo00Kooooo00?oool0ooooooooool06_ooool00ol0o`3oooooooooo`11oooo
o`03o`3o0?oooooooooo01cooooo00Co0?l0ooooooooo`3oool03oooool00ol0o`3oooooooooo`0O
ooooo`007oooool00ol0o`3oooooooooo`02ooooo`03oooo0?ooooooool000;ooooo00Coool0oooo
ooooooooool04_ooool00ol0o`3oooooooooo`0:ooooo`03oooo0?oooooooooo00Oooooo00?oool0
ooooooooool02Oooool00oooo`3oooooooooo`06ooooo`03oooo0?oooooooooo01Wooooo00?o0?l0
ooooooooool0@oooool00ol0o`3oooooooooo`0Jooooo`05o`3o0?ooooooool0ooooooooo`004?oo
ool00ol0o`3oooooooooo`0Nooooo`007oooool00ol0o`3oooooooooo`02ooooo`03oooo0?oooooo
ool000?ooooo00Coool0ooooooooooooool04_ooool00ol0o`3oooooooooo`09ooooo`03oooo0?oo
oooooooo00Oooooo00?oool0ooooooooool02Oooool00oooo`3oooooooooo`06ooooo`03oooo0?oo
oooooooo01Wooooo00?o0?l0ooooooooool0@oooool00ol0o`3oooooooooo`0Iooooo`05o`3o0?oo
ooooool0ooooooooo`004Oooool00ol0o`3oooooooooo`0Nooooo`007oooool00ol0o`3ooooooooo
o`02ooooo`04oooo0?oooooooooooooo00;ooooo00Coool0ooooooooooooool04oooool00ol0o`3o
ooooooooo`08ooooo`03oooo0?oooooooooo00Oooooo00?oool0ooooooooool02Oooool00oooo`3o
ooooooooo`06ooooo`03oooo0?oooooooooo01Sooooo00?o0?l0ooooooooool0A?ooool00ol0o`3o
ooooooooo`0Iooooo`05o`3o0?ooooooool0ooooooooo`004Oooool00ol0o`3oooooooooo`0Noooo
o`007oooool00ol0o`3oooooooooo`02ooooo`04oooo0?oooooooooooooo00;ooooo00Coool0oooo
ooooooooool05?ooool2o`3o00Oooooo00?oool0ooooooooool02?ooool00oooo`3oooooooooo`09
ooooo`03oooo0?oooooooooo00Kooooo00?oool0ooooooooool05oooool00ol0o`3oooooooooo`15
ooooo`03o`3o0?oooooooooo01Sooooo00Go0?l0ooooooooo`3ooooooooo000Booooo`03o`3o0?oo
oooooooo01kooooo000Nooooo`03o`3o0?oooooooooo00?ooooo00Coool0ooooooooooooool00_oo
ool01Oooo`3oooooooooooooooooool001Gooooo00?o0?l0ooooooooool01?ooool00oooo`3ooooo
ooooo`07ooooo`03oooo0?oooooooooo00[ooooo00?oool0ooooooooool01_ooool00oooo`3ooooo
ooooo`0Gooooo`03o`3o0?oooooooooo04Kooooo00?o0?l0ooooooooool05_ooool01Ol0o`3ooooo
oooo0?ooooooool001Cooooo00?o0?l0ooooooooool07Oooool001kooooo00?o0?l0ooooooooool0
0oooool01?ooo`3oooooooooooooo`03ooooo`04oooo0?oooooooooooooo01Kooooo00?o0?l0oooo
ooooool00_ooool00oooo`3oooooooooo`08ooooo`03oooo0?oooooooooo00[ooooo00?oool0oooo
ooooool01oooool00oooo`3oooooooooo`0Eooooo`03o`3o0?oooooooooo04Oooooo00?o0?l0oooo
ooooool05Oooool01_l0o`3oooooooooooooo`3ooooooooo01Cooooo00?o0?l0ooooooooool07Ooo
ool001kooooo00?o0?l0ooooooooool00_ooool01Oooo`3oooooooooooooooooool000?ooooo00Go
ool0oooooooooooooooooooo000Fooooo`;o0?l00_ooool00oooo`3oooooooooo`08ooooo`03oooo
0?oooooooooo00[ooooo00?oool0ooooooooool01oooool00oooo`3oooooooooo`0Dooooo`03o`3o
0?oooooooooo04Sooooo00?o0?l0ooooooooool05?ooool01_l0o`3oooooooooooooo`3ooooooooo
01Gooooo00?o0?l0ooooooooool07Oooool001gooooo00?o0?l0ooooooooool00oooool01Oooo`3o
ooooooooooooooooool000?ooooo00Goool0oooooooooooooooooooo000Hooooo`03o`3o0?oooooo
ool000[ooooo00?oool0ooooooooool02_ooool00oooo`3oooooooooo`07ooooo`03oooo0?oooooo
oooo01Cooooo00?o0?l0ooooooooool0BOooool00ol0o`3oooooooooo`0Cooooo`05o`3o0?oooooo
ool0ooooooooo`005oooool00ol0o`3oooooooooo`0Looooo`007Oooool00ol0o`3oooooooooo`03
ooooo`05oooo0?ooooooooooooooooooo`000oooool01Oooo`3oooooooooooooooooool001Wooooo
00?oool0ooooooooool02?ooool00oooo`3oooooooooo`0;ooooo`03oooo0?oooooooooo00Oooooo
00?oool0ooooooooool04oooool00ol0o`3oooooooooo`1:ooooo`03o`3o0?oooooooooo01;ooooo
00Ko0?l0ooooooooooooool0ooooooooo`0Gooooo`03o`3o0?oooooooooo01cooooo000Mooooo`03
o`3o0?oooooooooo00?ooooo00Goool0oooooooooooooooooooo0004ooooo`05oooo0?oooooooooo
ooooooooo`006?ooool00oooo`3o0?l0o`3o0008ooooo`03oooo0?oooooooooo00_ooooo00?oool0
ooooooooool01oooool00oooo`3oooooooooo`0Booooo`03o`3o0?oooooooooo04_ooooo00?o0?l0
ooooooooool04Oooool01_l0o`3oooooooooooooo`3ooooooooo01Sooooo00?o0?l0ooooooooool0
7?ooool001cooooo00?o0?l0ooooooooool01?ooool01Oooo`3oooooooooooooooooool000Cooooo
00Goool0oooooooooooooooooooo000Hooooo`04oooo0?ooooooooooo`3o00Oooooo00?oool0oooo
ooooool02oooool00oooo`3oooooooooo`07ooooo`03oooo0?oooooooooo017ooooo00?o0?l0oooo
ooooool0COooool00ol0o`3oooooooooo`0?ooooo`04o`3o0?oooooooooooooo00;ooooo00?oool0
ooooooooool05oooool00ol0o`3oooooooooo`0Kooooo`007?ooool00ol0o`3oooooooooo`04oooo
o`05oooo0?ooooooooooooooooooo`001?ooool01Oooo`3oooooooooooooooooool001Oooooo00?o
ool0ooooooooool00_ooool00ol0o`3oooooooooo`04ooooo`03oooo0?oooooooooo00[ooooo00?o
ool0ooooooooool02?ooool00oooo`3oooooooooo`0Aooooo`03o`3o0?oooooooooo04gooooo00?o
0?l0ooooooooool03_ooool01?l0o`3oooooooooooooo`02ooooo`03oooo0?oooooooooo01Sooooo
00?o0?l0ooooooooool06oooool001cooooo00?o0?l0ooooooooool01?ooool01Oooo`3ooooooooo
ooooooooool000Cooooo00?oool0ooooooooool00_ooool00oooo`3oooooooooo`0Dooooo`03oooo
0?oooooooooo00?ooooo0_l0o`03ooooo`03oooo0?oooooooooo00_ooooo00?oool0ooooooooool0
2?ooool00oooo`3oooooooooo`0@ooooo`03o`3o0?oooooooooo04kooooo00?o0?l0ooooooooool0
3_ooool01_l0o`3oooooooooooooo`3ooooooooo01_ooooo00?o0?l0ooooooooool06oooool001co
oooo00?o0?l0ooooooooool01?ooool01Oooo`3oooooooooooooooooool000Gooooo00Goool0oooo
oooooooooooooooo000Eooooo`03oooo0?oooooooooo00Kooooo00Co0?l0ooooooooooooool03Ooo
ool00oooo`3oooooooooo`08ooooo`03oooo0?oooooooooo00oooooo00?o0?l0ooooooooool0D?oo
ool00ol0o`3oooooooooo`0<ooooo`04o`3o0?oooooooooooooo00;ooooo00?oool0ooooooooool0
6Oooool00ol0o`3oooooooooo`0Kooooo`006oooool00ol0o`3oooooooooo`05ooooo`05oooo0?oo
ooooooooooooooooo`001Oooool00oooo`3oooooooooo`02ooooo`03oooo0?oooooooooo01;ooooo
00?oool0ooooooooool01oooool00ol0o`3ooooooooo000=ooooo`03oooo0?oooooooooo00Sooooo
00?oool0ooooooooool03oooool00ol0o`3oooooooooo`1@ooooo`03o`3o0?oooooooooo00_ooooo
00Co0?l0ooooooooooooool00_ooool00oooo`3oooooooooo`0Kooooo`03o`3o0?oooooooooo01[o
oooo000Kooooo`03o`3o0?oooooooooo00Gooooo00?oool0ooooooooool00_ooool00oooo`3ooooo
ooooo`02ooooo`03oooo0?oooooooooo00;ooooo00?oool0ooooooooool04_ooool00oooo`3ooooo
ooooo`08ooooo`03o`3o0?ooo`3ooooo00cooooo00?oool0ooooooooool02?ooool00oooo`3ooooo
ooooo`0>ooooo`03o`3o0?oooooooooo057ooooo00?o0?l0ooooooooool02_ooool01Ol0o`3ooooo
ooooooooooooool000;ooooo00?oool0ooooooooool06oooool00ol0o`3oooooooooo`0Jooooo`00
6oooool00ol0o`3oooooooooo`05ooooo`03oooo0?oooooooooo00;ooooo00?oool0ooooooooool0
0_ooool00oooo`3oooooooooo`02ooooo`03oooo0?oooooooooo017ooooo00?oool0ooooooooool0
2Oooool00oooo`3oooooo`3o000<ooooo`03oooo0?oooooooooo00Sooooo00?oool0ooooooooool0
3Oooool00ol0o`3oooooooooo`1Cooooo`03o`3o0?oooooooooo00Sooooo00Go0?l0oooooooooooo
oooooooo0002ooooo`03oooo0?oooooooooo01cooooo00?o0?l0ooooooooool06_ooool001[ooooo
00?o0?l0ooooooooool01_ooool00oooo`3oooooooooo`02ooooo`03oooo0?oooooooooo00?ooooo
00?oool0ooooooooool00_ooool00oooo`3oooooooooo`0@ooooo`03oooo0?oooooooooo00Wooooo
00Coool0oooooooooooo0?l02oooool00oooo`3oooooooooo`08ooooo`03oooo0?oooooooooo00go
oooo00?o0?l0ooooooooool0Doooool00ol0o`3oooooooooo`08ooooo`04o`3o0?oooooooooooooo
00;ooooo00?oool0ooooooooool07_ooool00ol0o`3oooooooooo`0Iooooo`006_ooool00ol0o`3o
ooooooooo`06ooooo`03oooo0?oooooooooo00;ooooo00?oool0ooooooooool00oooool00oooo`3o
ooooooooo`02ooooo`03oooo0?oooooooooo00oooooo00?oool0ooooooooool02_ooool01?ooo`3o
ooooooooooooool2o`3o00Wooooo00?oool0ooooooooool02?ooool00oooo`3oooooooooo`0<oooo
o`03o`3o0?oooooooooo05Cooooo00?o0?l0ooooooooool01oooool01Ol0o`3ooooooooooooooooo
ool000;ooooo00?oool0ooooooooool07_ooool00ol0o`3oooooooooo`0Iooooo`006_ooool00ol0
o`3oooooooooo`06ooooo`03oooo0?oooooooooo00;ooooo00?oool0ooooooooool00oooool00ooo
o`3oooooooooo`03ooooo`03oooo0?oooooooooo00kooooo00?oool0ooooooooool02_ooool00ooo
o`3oooooooooo`03ooooo`03o`3o0?oooooooooo00Kooooo00?oool0ooooooooool02?ooool00ooo
o`3oooooooooo`0;ooooo`03o`3o0?oooooooooo05Kooooo00?o0?l0ooooooooool01Oooool01Ol0
o`3oooooooooooooooooool000;ooooo00?oool0ooooooooool07oooool00ol0o`3oooooooooo`0I
ooooo`006Oooool00ol0o`3oooooooooo`07ooooo`03oooo0?oooooooooo00;ooooo00?oool0oooo
ooooool00oooool00oooo`3oooooooooo`03ooooo`03oooo0?oooooooooo00kooooo00?oool0oooo
ooooool02Oooool00oooo`3oooooooooo`05ooooo`03o`3o0?oooooooooo00Gooooo00?oool0oooo
ooooool02?ooool00oooo`3oooooooooo`0:ooooo`03o`3o0?oooooooooo05Oooooo00?o0?l0oooo
ooooool01?ooool01Ol0o`3oooooooooooooooooool000?ooooo00?oool0ooooooooool08?ooool0
0ol0o`3oooooooooo`0Hooooo`006Oooool00ol0o`3oooooooooo`07ooooo`03oooo0?oooooooooo
00;ooooo00?oool0ooooooooool01?ooool00oooo`3oooooooooo`02ooooo`03oooo0?oooooooooo
00gooooo00?oool0ooooooooool02_ooool00oooo`3oooooooooo`06ooooo`;o0?l01Oooool00ooo
o`3oooooooooo`09ooooo`03oooo0?oooooooooo00Wooooo00?o0?l0ooooooooool0Eoooool00ol0
o`3oooooooooo`03ooooo`03o`3o0?oooooooooo00;ooooo00Coool0ooooooooooooool08oooool0
0ol0o`3oooooooooo`0Hooooo`006Oooool00ol0o`3oooooooooo`06ooooo`03oooo0?oooooooooo
00?ooooo00?oool0ooooooooool01?ooool00oooo`3oooooooooo`03ooooo`03oooo0?oooooooooo
00cooooo00?oool0ooooooooool02_ooool00oooo`3oooooooooo`08ooooo`03o`3o0?oooooooooo
00;ooooo00?oool0ooooooooool02Oooool00oooo`3oooooooooo`08ooooo`03o`3o0?oooooooooo
05Sooooo00?o0?l0ooooooooool00oooool01Ol0o`3oooooooooooooooooool000;ooooo00?oool0
ooooooooool08_ooool00ol0o`3oooooooooo`0Hooooo`006Oooool00ol0o`3oooooooooo`06oooo
o`03oooo0?oooooooooo00?ooooo00?oool0ooooooooool01?ooool00oooo`3oooooooooo`03oooo
o`03oooo0?oooooooooo00_ooooo00?oool0ooooooooool02oooool00oooo`3oooooooooo`09oooo
o`05o`3o0?ooooooooooooooooooo`002oooool00oooo`3oooooooooo`07ooooo`03o`3o0?oooooo
oooo05[ooooo00Go0?l0ooooooooooooooooo`3o0003ooooo`05oooo0?ooooooooooooooooooo`00
9?ooool00ol0o`3oooooooooo`0Hooooo`006?ooool00ol0o`3oooooooooo`07ooooo`03oooo0?oo
oooooooo00?ooooo00?oool0ooooooooool01?ooool00oooo`3oooooooooo`04ooooo`03oooo0?oo
oooooooo00[ooooo00?oool0ooooooooool02oooool00oooo`3oooooooooo`0:ooooo`;o0?l000?o
oooooooo0?ooool02_ooool00oooo`3oooooooooo`07ooooo`03o`3o0?oooooooooo05[ooooo00Co
0?l0oooooooooooo0?l00oooool01Oooo`3oooooooooooooooooool002Kooooo00?o0?l0oooooooo
ool05oooool001Sooooo00?o0?l0ooooooooool01oooool00oooo`3oooooooooo`03ooooo`03oooo
0?oooooooooo00Gooooo00?oool0ooooooooool00oooool00oooo`3oooooooooo`0:ooooo`03oooo
0?oooooooooo00[ooooo00?oool0ooooooooool03Oooool00ol0o`3oool0ooooo`0:ooooo`03oooo
0?oooooooooo00Kooooo00?o0?l0ooooooooool0Foooool00ol0o`3oooooo`3o0004ooooo`05oooo
0?ooooooooooooooooooo`009_ooool00ol0o`3oooooooooo`0Gooooo`006?ooool00ol0o`3ooooo
ooooo`07ooooo`03oooo0?oooooooooo00?ooooo00?oool0ooooooooool01Oooool00oooo`3ooooo
ooooo`03ooooo`03oooo0?oooooooooo00Wooooo00?oool0ooooooooool02oooool00oooo`3ooooo
ooooo`0=ooooo`03oooo0?l0o`3ooooo00[ooooo00?oool0ooooooooool01Oooool00ol0o`3ooooo
ooooo`1Mooooo`03o`3o0?oooooooooo00;ooooo00Goool0oooooooooooooooooooo000Wooooo`03
o`3o0?oooooooooo01Oooooo000Gooooo`03o`3o0?oooooooooo00Sooooo00?oool0ooooooooool0
0oooool00oooo`3oooooooooo`05ooooo`03oooo0?oooooooooo00Cooooo00?oool0ooooooooool0
2?ooool00oooo`3oooooooooo`0;ooooo`03oooo0?oooooooooo00gooooo00Coool0ooooool0o`3o
0?l02Oooool00oooo`3oooooooooo`05ooooo`03o`3o0?oooooooooo05gooooo00Go0?l0oooooooo
oooooooooooo0003ooooo`03oooo0?oooooooooo02Oooooo00?o0?l0ooooooooool05_ooool001Oo
oooo00?o0?l0ooooooooool02?ooool00oooo`3oooooooooo`03ooooo`03oooo0?oooooooooo00Go
oooo00?oool0ooooooooool01?ooool00oooo`3oooooooooo`08ooooo`03oooo0?oooooooooo00_o
oooo00?oool0ooooooooool03Oooool01Oooo`3ooooooooooooooooo0?l000Sooooo00?oool0oooo
ooooool01?ooool00ol0o`3oooooooooo`1Mooooo`;o0?l00oooool01Oooo`3ooooooooooooooooo
ool002Wooooo00?o0?l0ooooooooool05_ooool001Oooooo00?o0?l0ooooooooool02?ooool00ooo
o`3oooooooooo`04ooooo`03oooo0?oooooooooo00Gooooo00?oool0ooooooooool00oooool00ooo
o`3oooooooooo`07ooooo`03oooo0?oooooooooo00_ooooo00?oool0ooooooooool03_ooool00ooo
o`3oooooooooo`02ooooo`03o`3o0?oooooooooo00Gooooo00?oool0ooooooooool00oooool00ol0
o`3oooooooooo`1Mooooo`06o`3o0?ooooooooooo`3o0?ooooooool00oooool00oooo`3ooooooooo
o`0Xooooo`03o`3o0?oooooooooo01Kooooo000Fooooo`03o`3o0?oooooooooo00Wooooo00?oool0
ooooooooool01?ooool00oooo`3oooooooooo`05ooooo`03oooo0?oooooooooo00Cooooo00?oool0
ooooooooool01_ooool00oooo`3oooooooooo`0;ooooo`03oooo0?oooooooooo00kooooo00?oool0
ooooooooool00oooool2o`3o00Gooooo00?oool0ooooooooool00oooool00ol0o`3oooooooooo`1L
ooooo`06o`3o0?ooooooooooooooool0o`3oool00oooool00oooo`3oooooooooo`0Zooooo`03o`3o
0?oooooooooo01Gooooo000Fooooo`03o`3o0?oooooooooo00Wooooo00?oool0ooooooooool01?oo
ool00oooo`3oooooooooo`05ooooo`03oooo0?oooooooooo00Cooooo00?oool0ooooooooool01Ooo
ool00oooo`3oooooooooo`0<ooooo`03oooo0?oooooooooo00kooooo00?oool0ooooooooool01Ooo
ool00ol0o`3oooooooooo`02ooooo`03oooo0?oooooooooo00;ooooo00?o0?l0ooooooooool0G?oo
ool00ol0o`3oooooooooo`02ooooo`03o`3o0?ooo`3ooooo00;ooooo00?oool0ooooooooool0:_oo
ool00ol0o`3oooooooooo`0Eooooo`005_ooool00ol0o`3oooooooooo`09ooooo`03oooo0?oooooo
oooo00Cooooo00?oool0ooooooooool01Oooool00oooo`3oooooooooo`05ooooo`03oooo0?oooooo
oooo00Cooooo00?oool0ooooooooool03?ooool00oooo`3oooooooooo`0>ooooo`03oooo0?oooooo
oooo00Kooooo00Go0?l0oooooooooooooooooooo0003ooooo`03o`3o0?oooooooooo05gooooo00?o
0?l0ooooooooool00_ooool01Oooo`3o0?l0ooooooooooooool002gooooo00?o0?l0ooooooooool0
5Oooool001Kooooo00?o0?l0ooooooooool02Oooool00oooo`3oooooooooo`04ooooo`03oooo0?oo
oooooooo00Kooooo00?oool0ooooooooool01?ooool00oooo`3oooooooooo`04ooooo`03oooo0?oo
oooooooo00_ooooo00?oool0ooooooooool03oooool00oooo`3oooooooooo`07ooooo`;o0?l000Go
oooooooo0?ooooooooooo`3o001Oooooo`03o`3o0?oooooooooo00;ooooo00?oool0ooooool0o`00
0_ooool00oooo`3oooooooooo`0[ooooo`03o`3o0?oooooooooo01Gooooo000Eooooo`03o`3o0?oo
oooooooo00[ooooo00?oool0ooooooooool01?ooool00oooo`3oooooooooo`06ooooo`03oooo0?oo
oooooooo00Cooooo00?oool0ooooooooool00oooool00oooo`3oooooooooo`0<ooooo`03oooo0?oo
oooooooo00oooooo00?oool0ooooooooool02Oooool01Ol0o`3oool0oooooooooooo0?l005kooooo
00?o0?l0ooooooooool00_ooool01_ooo`3oooooooooool0o`3ooooooooo02oooooo00?o0?l0oooo
ooooool05?ooool001Gooooo00?o0?l0ooooooooool02_ooool00oooo`3oooooooooo`04ooooo`03
oooo0?oooooooooo00Kooooo00?oool0ooooooooool01Oooool00oooo`3oooooooooo`02ooooo`03
oooo0?oooooooooo00cooooo00?oool0ooooooooool03oooool00oooo`3oooooooooo`0:ooooo`03
oooo0?oooooo0?l005kooooo00?o0?l0ooooooooool00oooool01Oooo`3oooooooooooooooooool0
033ooooo00?o0?l0ooooooooool05?ooool001Gooooo00?o0?l0ooooooooool02_ooool00oooo`3o
ooooooooo`04ooooo`03oooo0?oooooooooo00Kooooo00?oool0ooooooooool01Oooool00oooo`3o
ooooooooo`02ooooo`03oooo0?oooooooooo00cooooo00?oool0ooooooooool03oooool00oooo`3o
ooooooooo`0:ooooo`03oooo0?l0o`3o0?l005gooooo00?o0?l0ooooooooool00oooool00oooo`3o
ooooooooo`02ooooo`03oooo0?oooooooooo02kooooo00?o0?l0ooooooooool05?ooool001Cooooo
00?o0?l0ooooooooool02oooool00oooo`3oooooooooo`04ooooo`03oooo0?oooooooooo00Kooooo
00?oool0ooooooooool01_ooool01?ooo`3oooooooooooooo`0>ooooo`03oooo0?oooooooooo013o
oooo00?oool0ooooooooool02_ooool01?ooo`3o0?l0ooooool0o`1Looooo`03o`3o0?oooooooooo
00;ooooo00?oool0ooooooooool00_ooool00oooo`3o0?l0ooooo`0`ooooo`03o`3o0?oooooooooo
01?ooooo000Dooooo`03o`3o0?oooooooooo00[ooooo00?oool0ooooooooool01Oooool00oooo`3o
ooooooooo`07ooooo`03oooo0?oooooooooo00Gooooo00Coool0ooooooooooooool03_ooool00ooo
o`3oooooooooo`0@ooooo`03oooo0?oooooooooo00[ooooo00Go0?l0oooo0?ooooooooooo`3o001J
ooooo`03o`3o0?oooooooooo00?ooooo00?oool0ooooooooool00_ooool00oooo`3o0?l0ooooo`0`
ooooo`03o`3o0?oooooooooo01?ooooo000Dooooo`03o`3o0?oooooooooo00[ooooo00?oool0oooo
ooooool01Oooool00oooo`3oooooooooo`07ooooo`03oooo0?oooooooooo00Gooooo00Coool0oooo
ooooooooool03_ooool00oooo`3oooooooooo`0@ooooo`03oooo0?oooooooooo00Wooooo00?o0?l0
ooooooooo`000oooool2o`3o05Oooooo00?o0?l0ooooooooool00oooool00oooo`3oooooooooo`02
ooooo`04oooo0?ooooooooooo`3o033ooooo00?o0?l0ooooooooool04oooool001?ooooo00?o0?l0
ooooooooool02oooool00oooo`3oooooooooo`05ooooo`03oooo0?oooooooooo00Oooooo00?oool0
ooooooooool01_ooool00oooo`3ooooooooo000=ooooo`03oooo0?oooooooooo013ooooo00?oool0
ooooooooool02_ooool00ol0o`3ooooooooo0005ooooo`03o`3o0?oooooooooo05?ooooo00?o0?l0
ooooooooool00oooool00oooo`3oooooooooo`02ooooo`05oooo0?ooooooooooooooool0o`00<Ooo
ool00ol0o`3oooooooooo`0Booooo`004oooool00ol0o`3oooooooooo`0;ooooo`03oooo0?oooooo
oooo00Gooooo00?oool0ooooooooool01oooool00oooo`3oooooooooo`06ooooo`;oool03_ooool0
0oooo`3oooooooooo`0@ooooo`03oooo0?oooooooooo00Wooooo00Co0?l0ooooooooooooool01_oo
ool00ol0o`3oooooooooo`1Aooooo`03o`3o0?oooooooooo00Cooooo00?oool0ooooooooool00_oo
ool01Oooo`3ooooooooooooooooo0?l0037ooooo00?o0?l0ooooooooool04_ooool001?ooooo00?o
0?l0ooooooooool02oooool00oooo`3oooooooooo`06ooooo`03oooo0?oooooooooo00Oooooo00?o
ool0ooooooooool01Oooool2oooo00kooooo00?oool0ooooooooool04?ooool00oooo`3ooooooooo
o`08ooooo`05o`3o0?ooooooooooooooooooo`001oooool00ol0o`3oooooooooo`1@ooooo`03o`3o
0?oooooooooo00?ooooo00?oool0ooooooooool00_ooool00oooo`3oooooooooo`03ooooo`03o`3o
0?oooooooooo02kooooo00?o0?l0ooooooooool04_ooool001?ooooo00?o0?l0ooooooooool02ooo
ool00oooo`3oooooooooo`06ooooo`03oooo0?oooooooooo00Oooooo00?oool0ooooooooool01_oo
ool00oooo`3oooooooooo`0;ooooo`03oooo0?oooooooooo017ooooo00?oool0ooooooooool01ooo
ool00ol0o`3oooooooooo`02ooooo`03oooo0?oooooooooo00Kooooo0_l0o`1?ooooo`03o`3o0?oo
oooooooo00?ooooo00?oool0ooooooooool00oooool00oooo`3oooooooooo`03ooooo`03o`3o0?oo
oooooooo02kooooo00?o0?l0ooooooooool04_ooool001;ooooo00?o0?l0ooooooooool03?ooool0
0oooo`3oooooooooo`06ooooo`03oooo0?oooooooooo00Oooooo00?oool0ooooooooool01_ooool0
0oooo`3oooooooooo`0;ooooo`03oooo0?oooooooooo017ooooo00?oool0ooooooooool01oooool0
0ol0o`3oooooooooo`02ooooo`03oooo0?oooooooooo00Sooooo00?o0?l0ooooooooool0Boooool0
0ol0o`3oooooooooo`04ooooo`03oooo0?oooooooooo00;ooooo00?oool0ooooooooool01?ooool0
0ol0o`3oooooooooo`0_ooooo`03o`3o0?oooooooooo017ooooo000Booooo`03o`3o0?oooooooooo
00cooooo00?oool0ooooooooool01_ooool00oooo`3oooooooooo`07ooooo`03oooo0?oooooooooo
00Gooooo00?oool0ooooooooo`002oooool00oooo`3oooooooooo`0Booooo`03oooo0?oooooooooo
00Kooooo00?o0?l0ooooooooool00oooool00oooo`3oooooooooo`09ooooo`03o`3o0?oooooooooo
04Wooooo00?o0?l0ooooooooool01?ooool00oooo`3oooooooooo`02ooooo`03oooo0?oooooooooo
00Kooooo00?o0?l0ooooooooool0;_ooool00ol0o`3oooooooooo`0Aooooo`004_ooool00ol0o`3o
ooooooooo`0<ooooo`03oooo0?oooooooooo00Kooooo00?oool0ooooooooool02?ooool00oooo`3o
ooooooooo`04ooooo`03oooo0?ooooooool000_ooooo00?oool0ooooooooool04_ooool00oooo`3o
ooooooooo`05ooooo`03o`3o0?oooooooooo00Cooooo00?oool0ooooooooool02_ooool2o`3o04So
oooo00?o0?l0ooooooooool01?ooool00oooo`3oooooooooo`03ooooo`03oooo0?oooooooooo00Ko
oooo00?o0?l0ooooooooool0;_ooool00ol0o`3oooooooooo`0Aooooo`004Oooool00ol0o`3ooooo
ooooo`0=ooooo`03oooo0?oooooooooo00Kooooo00?oool0ooooooooool02?ooool00oooo`3ooooo
ooooo`04ooooo`03oooo0?ooooooool000_ooooo00?oool0ooooooooool04_ooool00oooo`3ooooo
ooooo`05ooooo`03o`3o0?oooooooooo00Cooooo00?oool0ooooooooool03?ooool00ol0o`3ooooo
ooooo`15ooooo`03o`3o0?oooooooooo00?ooooo00?oool0ooooooooool00oooool00oooo`3ooooo
ooooo`07ooooo`03o`3o0?oooooooooo02oooooo00?o0?l0ooooooooool04?ooool0017ooooo00?o
0?l0ooooooooool03Oooool00oooo`3oooooooooo`06ooooo`03oooo0?oooooooooo00Sooooo00?o
ool0ooooooooool01?ooool01?ooo`3oooooooooooooo`09ooooo`03oooo0?oooooooooo01?ooooo
00?oool0ooooooooool01?ooool00ol0o`3oooooooooo`05ooooo`03oooo0?oooooooooo00gooooo
00?o0?l0ooooooooool0@oooool00ol0o`3oooooooooo`04ooooo`03oooo0?oooooooooo00;ooooo
00?oool0ooooooooool02Oooool00ol0o`3oooooooooo`0^ooooo`03o`3o0?oooooooooo013ooooo
000Aooooo`03o`3o0?oooooooooo00gooooo00?oool0ooooooooool01_ooool00oooo`3ooooooooo
o`08ooooo`03oooo0?oooooooooo00?ooooo00Goool0oooooooooooooooooooo0009ooooo`03oooo
0?oooooooooo01?ooooo00?oool0ooooooooool00oooool00ol0o`3oooooooooo`06ooooo`03oooo
0?oooooooooo00kooooo0_l0o`12ooooo`03o`3o0?oooooooooo00Cooooo00?oool0ooooooooool0
0oooool00oooo`3oooooooooo`09ooooo`03o`3o0?oooooooooo02kooooo00?o0?l0ooooooooool0
4?ooool0013ooooo00?o0?l0ooooooooool03_ooool00oooo`3oooooooooo`06ooooo`03oooo0?oo
oooooooo00Wooooo00?oool0ooooooooool00_ooool00oooo`3oooooooooo`02ooooo`03oooo0?oo
oooooooo00Kooooo00?oool0ooooooooool04oooool00oooo`3oooooooooo`03ooooo`03o`3o0?oo
oooooooo00Kooooo00?oool0ooooooooool04?ooool00ol0o`3oooooooooo`0nooooo`03o`3o0?oo
oooooooo00Cooooo00?oool0ooooooooool00oooool00oooo`3oooooooooo`0:ooooo`03o`3o0?oo
oooooooo02oooooo00?o0?l0ooooooooool03oooool0013ooooo00?o0?l0ooooooooool03_ooool0
0oooo`3oooooooooo`06ooooo`03oooo0?oooooooooo00Wooooo00?oool0ooooooooool00_ooool0
0oooo`3oooooooooo`02ooooo`03oooo0?oooooooooo00Gooooo00?oool0ooooooooool05?ooool0
0oooo`3oooooooooo`02ooooo`03o`3o0?oooooooooo00Oooooo00?oool0ooooooooool04Oooool0
0ol0o`3oooooooooo`0looooo`03o`3o0?oooooooooo00Gooooo00?oool0ooooooooool00oooool0
0oooo`3oooooooooo`0;ooooo`03o`3o0?oooooooooo02kooooo00?o0?l0ooooooooool03oooool0
013ooooo00?o0?l0ooooooooool03_ooool00oooo`3oooooooooo`06ooooo`03oooo0?oooooooooo
00Wooooo00?oool0ooooooooool00_ooool00oooo`3oooooooooo`02ooooo`03oooo0?oooooooooo
00Gooooo00?oool0ooooooooool05?ooool01Oooo`3ooooooooooooooooo0?l000[ooooo00?oool0
ooooooooool04_ooool2o`3o00?ooooo3oooo`0Zooooo`03o`3o0?oooooooooo00Cooooo00?oool0
ooooooooool00oooool00oooo`3oooooooooo`0<ooooo`03o`3o0?oooooooooo02kooooo00?o0?l0
ooooooooool03oooool0013ooooo00?o0?l0ooooooooool03_ooool00oooo`3oooooooooo`06oooo
o`03oooo0?oooooooooo00Wooooo00?oool0ooooooooool00_ooool00oooo`3oooooooooo`03oooo
o`03oooo0?oooooooooo00?ooooo00?oool0ooooooooool05Oooool01Oooo`3ooooooooooooooooo
0?l000[ooooo00?oool0ooooooooool02?ooool?oooo00oooooo3oooo`0Jooooo`03o`3o0?oooooo
oooo00Cooooo00?oool0ooooooooool00oooool00oooo`3oooooooooo`0=ooooo`03o`3o0?oooooo
oooo02kooooo00?o0?l0ooooooooool03oooool000oooooo00?o0?l0ooooooooool03_ooool00ooo
o`3oooooooooo`07ooooo`03oooo0?oooooooooo00[ooooo00Coool0ooooooooooooool01_ooool0
0oooo`3oooooooooo`03ooooo`03oooo0?oooooooooo01Gooooo00Coool0oooooooooooo0?l02?oo
ool>oooo00gooooo00?o0?l0ooooooooool07Oooool>oooo00_ooooo00?o0?l0ooooooooool01Ooo
ool00oooo`3oooooooooo`03ooooo`03oooo0?oooooooooo00kooooo00?o0?l0ooooooooool0;_oo
ool00ol0o`3oooooooooo`0>ooooo`003oooool00ol0o`3oooooooooo`0>ooooo`03oooo0?oooooo
oooo00Sooooo00?oool0ooooooooool02Oooool01?ooo`3oooooooooooooo`07ooooo`03oooo0?oo
oooooooo00;ooooo00?oool0ooooooooool04_ooool?oooo00Cooooo00?oool0ooooooooool05Ooo
ool2o`3o02_ooooo3oooo`03ooooo`03oooo0?oooooooooo00?ooooo00?oool0ooooooooool03ooo
ool00ol0o`3oooooooooo`0^ooooo`03o`3o0?oooooooooo00kooooo000?ooooo`03o`3o0?oooooo
oooo00kooooo00?oool0ooooooooool02?ooool00oooo`3oooooooooo`09ooooo`04oooo0?oooooo
oooooooo00Oooooo00Goool0oooooooooooooooooooo0007ooooo`koool00_ooool00oooo`3ooooo
o`3o000>ooooo`03oooo0?oooooooooo01Oooooo00?o0?l0ooooooooool0<Oooool00ol0o`3ooooo
ooooo`03ooooo`koool03Oooool00ol0o`3oooooooooo`0^ooooo`03o`3o0?oooooooooo00kooooo
000>ooooo`03o`3o0?oooooooooo00oooooo00?oool0ooooooooool02?ooool00oooo`3ooooooooo
o`09ooooo`04oooo0?oooooooooooooo00Gooooo3_ooo`0@ooooo`03oooo0?oooooo0?l000kooooo
00?oool0ooooooooool06?ooool00ol0o`3oooooooooo`0`ooooo`03o`3o0?oooooooooo00Gooooo
00?oool0ooooooooool00oooool00oooo`3oooooooooo`03ooooo`koool0<Oooool00ol0o`3ooooo
ooooo`0=ooooo`002oooool4o`3o017ooooo00?oool0ooooooooool02?ooool00oooo`3ooooooooo
o`03ooooo`ooool00oooool00oooo`3ooooooooo000Hooooo`03oooo0?l0o`3ooooo00kooooo00?o
ool0ooooooooool06Oooool2o`3o02oooooo00?o0?l0ooooooooool01Oooool00oooo`3ooooooooo
o`03ooooo`03oooo0?oooooooooo01;ooooo3oooo`0Rooooo`?o0?l03Oooool000[ooooo1Ol0o`0A
ooooo`03oooo0?oooooooooo00koool01oooool2oooo00Wooooo00?oool0ooooooooo`006?ooool0
0ol0o`3oooooooooo`0>ooooo`03oooo0?oooooooooo01_ooooo00?o0?l0ooooooooool0:oooool0
0ol0o`3oooooooooo`05ooooo`03oooo0?oooooooooo00Cooooo00?oool0ooooooooool04_ooool0
0ol0o`3oooooooooo`0<ooooo`koool04oooool5o`3o00cooooo0009ooooo`Oo0?l01?ooool?oooo
00Sooooo00?oool0ooooooooool02_ooool2oooo00Wooooo00?oool0ooooooooo`006?ooool00ol0
o`3oooooooooo`0>ooooo`03oooo0?oooooooooo01cooooo00?o0?l0ooooooooool0:Oooool00ol0
o`3oooooooooo`05ooooo`03oooo0?oooooooooo00Cooooo00?oool0ooooooooool04oooool00ol0
o`3oooooooooo`0Jooooo`ooool00oooool7o`3o00_ooooo0009ooooo`Oo0?l01Oooo`0;ooooo`03
oooo0?oooooooooo00Sooooo00?oool0ooooooooool02_ooool2oooo00[ooooo00?oool0oooooooo
ool05_ooool00ol0o`3oool0ooooo`0?ooooo`03oooo0?oooooooooo01gooooo0_l0o`0Xooooo`03
o`3o0?oooooooooo00Kooooo00?oool0ooooooooool01?ooool00oooo`3oooooooooo`0Dooooo`03
o`3o0?oooooooooo02Oooooo1?ooo`07o`3o00_ooooo0009ooooo`Wo0?l00oooool?oooo00Oooooo
00?oool0ooooooooool02_ooool2oooo00[ooooo00?oool0ooooooooool05Oooool00ol0o`3ooooo
oooo000@ooooo`03oooo0?oooooooooo01oooooo00?o0?l0ooooooooool09Oooool00ol0o`3ooooo
ooooo`05ooooo`03oooo0?oooooooooo00Cooooo00?oool0ooooooooool05Oooool00ol0o`3ooooo
ooooo`0Hooooo`ooool000Cooooooooo0?ooo`3oool01ol0o`0;ooooo`002_ooool5o`3o00?ooooo
0ol0o`0;ooooo`04oooo0?ooooooooooooooo`koool01_ooool2oooo00Wooooo00?oool0oooooooo
o`005_ooool00ol0o`3ooooooooo000@ooooo`03oooo0?oooooooooo023ooooo00?o0?l0oooooooo
ool08oooool00ol0o`3oooooooooo`05ooooo`03oooo0?oooooooooo00Cooooo00?oool0oooooooo
ool05_ooool00ol0o`3oooooooooo`0:ooooo`koool03Oooool5oooo0003o`3o0?ooo`3o0?l000Co
0?l03?ooool000_ooooo0ol0o`000oooo`3o0?l0ooooo`04ooooo`?o0?l02?ooool00oooo`3ooooo
ooooo`08ooooo`03oooo0?oooooooooo00Cooooo3oooo`02ooooo`03oooo0?ooooooool001Gooooo
00Co0?l0ooooooooooooool04?ooool00oooo`3oooooooooo`0Qooooo`;o0?l08_ooool00ol0o`3o
ooooooooo`06ooooo`03oooo0?oooooooooo00Cooooo00?oool0ooooooooool05?ooool?oooo01Oo
oooo1?ooo`001?ooooooool0oooo0?ooool2oooo0003ooooool0o`3o0?l000;o0?l03Oooool000ko
oooo00?oool0o`3o0?ooool01oooool3o`3o00Gooooo00?oool0ooooooooool02?ooool00oooo`3o
ooooooooo`0:ooooo`;oool01oooool>oooo00_ooooo00Go0?l0oooooooooooooooooooo000@oooo
o`03oooo0?oooooooooo02?ooooo00?o0?l0ooooooooool07_ooool00ol0o`3oooooooooo`06oooo
o`03oooo0?oooooooooo00Cooooo00?oool0ooooooooool01oooool>oooo00?ooooo00?o0?l0oooo
ooooool07?ooool4oooo00;ooooo0oooo`001?oooooo0?l0oooo0?ooo`02ooooo`03o`3o0?ooo`3o
oooo00kooooo000>ooooo`;oool000?o0?l0ooooooooool02?ooool3o`3o00;ooooo00?oool0oooo
ooooool02?ooool00oooo`3oooooooooo`09ooooo`04oooo0?oooooooooooooo00Oooooo00Goool0
oooooooooooooooooooo0008ooooo`koool000?ooooooooo0?ooool03oooool00oooo`3ooooooooo
o`0Tooooo`03o`3o0?oooooooooo01cooooo00?o0?l0ooooooooool01_ooool01?ooo`3ooooooooo
ooooool>oooo017ooooo00?o0?l0ooooooooool06?ooool4oooo00Cooooo0_ooo`03ooooo`03o`3o
0?ooo`3oool000;ooooo0_l0o`000oooo`3oooooooooo`0=ooooo`003_ooool2oooo0003ooooool0
o`3ooooo00_ooooo0_l0o`000oooo`3oooooooooo`08ooooo`03oooo0?oooooooooo00Wooooo00Co
ool0ooooooooooooool01oooool01Oooo`3oooooooooooooooooool001;ooooo00Co0?l0oooooooo
oooooooo3oooo`03ooooo`03oooo0?oooooooooo02Gooooo0_l0o`0Jooooo`ooool00oooool00ooo
o`3oooooooooo`0Jooooo`03o`3o0?oooooooooo01Cooooo0oooo`05ooooo`?oool00oooool01?l0
o`3oool0oooo0?ooo`02ooooo`04o`3o0?ooooooool0oooo00oooooo000>ooooo`05oooo0?oooooo
ool0ooooool0o`003Oooool01?ooo`3o0?l0o`3o0?l0o`07ooooo`03oooo0?oooooooooo00Wooooo
00Coool0ooooooooooooool01oooool00oooo`3oooooooooo`02ooooo`03oooo0?oooooooooo00ko
oooo00?o0?l0ooooooooool00oooool00oooo`3oooooooooo`0;ooooo`koool07oooool00ol0o`3o
ooooooooo`09ooooo`koool000?oooooo`3o0?ooool01oooool00oooo`3oooooooooo`04ooooo`03
oooo0?oooooooooo01_ooooo00?o0?l0ooooooooool04?ooool4oooo00Kooooo0_ooo`05ooooo`04
o`3o0?ooo`3oool0oooo00;ooooo00?o0?l0ooooool0o`000_ooo`0?ooooo`003oooool2oooo0003
ooooool0o`3ooooo00cooooo00Coool0oooooooooooooooo0ol0o`03ooooo`03oooo0?oooooooooo
00[ooooo00Coool0ooooooooooooool01_ooool00oooo`3oooooooooo`03ooooo`03oooo0?oooooo
oooo00gooooo00?o0?l0ooooooooool01Oooool00oooo`3oooooooooo`0=ooooo`03oooo0?oooooo
oooo00Sooooo3oooo`0=ooooo`ooool03_ooool00ol0o`3oooooooooo`06ooooo`03oooo0?oooooo
oooo00Gooooo00?oool0ooooooooool06oooool00ol0o`3oooooooooo`0<ooooo`Coool02?ooool2
oooo00Gooooo0_l0o`02oooo00Cooooo00Co0?l0ooooool0o`3oool04?ooool000oooooo0_ooo`02
ooooo`03o`3o0?oooooooooo00_ooooo00?oool0ooooooooool00oooool3o`3o0003oooo0?oooooo
oooo00Wooooo00?oool0ooooooooool00_ooool00oooo`3oooooooooo`03ooooo`03oooo0?oooooo
oooo00?ooooo00?oool0ooooooooool03Oooool00ol0o`3oooooooooo`05ooooo`03oooo0?oooooo
oooo00cooooo00?oool0ooooooooool06?ooool=oooo00Gooooo0_l0o`0Eooooo`03o`3o0?oooooo
oooo00Kooooo00?oool0ooooooooool01Oooool00oooo`3oooooooooo`0Mooooo`03o`3o0?oooooo
oooo00Oooooo1?ooo`09ooooo`?oool01_ooool01?l0o`3ooooooooo0?ooo`04ooooo`03o`3o0?oo
oooooooo00;oool04?ooool000oooooo00?oool0ooooooooo`000_ooool00ol0o`3oooooooooo`0:
ooooo`03oooo0?oooooooooo00Kooooo00?oool0o`3o0?l0o`002Oooool00oooo`3oooooooooo`02
ooooo`03oooo0?oooooooooo00;ooooo00?oool0ooooooooool01Oooool00oooo`3oooooooooo`0;
ooooo`03o`3o0?oooooooooo00Kooooo00?oool0ooooooooool03?ooool00oooo`3oooooooooo`0/
ooooo`03o`3o0?oooooooooo017ooooo00?o0?l0ooooooooool01oooool00oooo`3oooooooooo`04
ooooo`03oooo0?oooooooooo01kooooo00?o0?l0ooooooooool01?ooool3oooo00_ooooo0_ooo`07
ooooo`;o0?l00oooo`04ooooo`04o`3o0?ooooooooooo`3o00;oool04?ooool000oooooo00?oool0
ooooooooo`000_ooool00ol0o`3oooooooooo`0:ooooo`03oooo0?oooooooooo00Kooooo00?oool0
ooooooooool00ol0o`06ooooo`03oooo0?oooooooooo00;ooooo00?oool0ooooooooool00_ooool0
0oooo`3oooooooooo`05ooooo`03oooo0?oooooooooo00[ooooo00?o0?l0ooooooooool01oooool0
0oooo`3oooooooooo`0<ooooo`03oooo0?oooooooooo02gooooo00?o0?l0ooooooooool04?ooool0
0ol0o`3oooooooooo`06ooooo`03oooo0?oooooooooo00Gooooo00?oool0ooooooooool07_ooool0
0ol0o`3oooooooooo`04oooo00_ooooo0oooo`08ooooo`05o`3o0?ooooooool0ooooooooo`001Ooo
ool01?l0o`3oooooooooool0o`02oooo013ooooo000@ooooo`;oool00oooool00ol0o`3ooooooooo
o`09ooooo`03oooo0?oooooooooo00Kooooo00?oool0ooooooooool00oooool3o`3o00?ooooo00?o
ool0ooooooooool00_ooool00oooo`3oooooooooo`02ooooo`03oooo0?oooooooooo00Kooooo00?o
ool0ooooooooool02Oooool00ol0o`3oooooooooo`07ooooo`03oooo0?oooooooooo00cooooo00?o
ool0ooooooooool0;_ooool2o`3o00oooooo00?o0?l0ooooooooool01_ooool00oooo`3ooooooooo
o`05ooooo`03oooo0?oooooooooo01kooooo1?ooo`0=ooooo`;oool02Oooool2o`3o0004oooooooo
o`3ooooooooo00Gooooo00Ko0?l0ooooooooooooooooo`3o0?ooo`0Aooooo`004?ooool00oooo`3o
oooooooo0003ooooo`03o`3o0?oooooooooo00Sooooo00?oool0ooooooooool01_ooool00oooo`3o
ooooooooo`06ooooo`;o0?l000?oool0ooooooooool00oooool01Oooo`3oooooooooooooooooool0
00Wooooo00?oool0ooooooooool02?ooool00ol0o`3oooooooooo`08ooooo`03oooo0?oooooooooo
00cooooo00?oool0ooooooooool0<?ooool00ol0o`3oooooooooo`0;ooooo`03o`3o0?oooooooooo
00Oooooo00?oool0ooooooooool01Oooool00oooo`3oooooooooo`0Jooooo`Coool00_ooool00ol0
o`3oooooooooo`0:ooooo`;oool02_ooool01_l0o`3ooooooooo0?ooo`3ooooooooo00Gooooo00Go
0?l0ooooooooooooooooo`3o0002oooo017ooooo000@ooooo`03oooo0?ooooooool000?ooooo00?o
0?l0ooooooooool02?ooool00oooo`3oooooooooo`06ooooo`03oooo0?oooooooooo00Sooooo00Co
ool0o`3o0?l0o`3o0?l00oooool01?ooo`3oooooooooooooo`09ooooo`03oooo0?oooooooooo00Oo
oooo00?o0?l0ooooooooool02Oooool00oooo`3oooooooooo`0<ooooo`03oooo0?oooooooooo037o
oooo00?o0?l0ooooooooool02Oooool00ol0o`3oooooooooo`07ooooo`03oooo0?oooooooooo00Go
oooo00?oool0ooooooooool06?ooool3oooo00Kooooo00?o0?l0ooooooooool01oooool3oooo00[o
oooo0_l0o`000oooooooool0ooooo`02oooo00Kooooo00Go0?l0ooooooooooooooooo`3o0002oooo
017ooooo000@ooooo`04oooo0?oooooooooooooo00?ooooo00?o0?l0ooooooooool01oooool00ooo
o`3oooooooooo`06ooooo`03oooo0?oooooooooo00Sooooo00Coool0oooooooooooooooo0ol0o`00
0oooo`3ooooooooo000;ooooo`03oooo0?oooooooooo00Kooooo00?o0?l0ooooooooool02Oooool0
0oooo`3oooooooooo`0<ooooo`03oooo0?oooooooooo03;ooooo0_l0o`08ooooo`03o`3o0?oooooo
oooo00Oooooo00?oool0ooooooooool01Oooool00oooo`3oooooooooo`0Eooooo`Coool02Oooool0
0ol0o`3oooooooooo`05ooooo`;oool03?ooool01_l0o`3oooooooooooooo`3ooooooooo00Oooooo
00Ko0?l0ooooooooooooooooo`3o0?ooool2oooo017ooooo000@ooooo`04oooo0?oooooooooooooo
00Cooooo00?o0?l0ooooooooool01_ooool00oooo`3oooooooooo`06ooooo`03oooo0?oooooooooo
00Sooooo00?oool0ooooooooool01?ooool00oooo`3o0?l0oooo000;ooooo`03oooo0?oooooooooo
00Gooooo00?o0?l0ooooooooool02_ooool00oooo`3oooooooooo`0<ooooo`03oooo0?oooooooooo
03Cooooo00?o0?l0ooooooooool01Oooool00ol0o`3oooooooooo`07ooooo`03oooo0?oooooooooo
00Gooooo00?oool0ooooooooool04Oooool4oooo00kooooo00Co0?l0oooooooooooooooo0oooo`0<
ooooo`;o0?l000Gooooooooo0?ooo`3ooooooooo0007ooooo`03o`3o0?oooooooooo00;ooooo00Co
0?l0oooo0?ooooooool04Oooool0017ooooo00?oool0ooooooooo`001?ooool00ol0o`3ooooooooo
o`06ooooo`03oooo0?oooooooooo00Kooooo00?oool0ooooooooool01oooool00oooo`3ooooooooo
o`05ooooo`03oooo0?ooooooool000?o0?l02?ooool00oooo`3oooooooooo`04ooooo`03o`3o0?oo
oooooooo00_ooooo00?oool0ooooooooool03?ooool00oooo`3oooooooooo`0eooooo`03o`3o0?oo
oooooooo00?ooooo00?o0?l0ooooooooool01oooool00oooo`3oooooooooo`05ooooo`03oooo0?oo
oooooooo00kooooo1?ooo`0Booooo`04o`3o0?ooooooool0oooo00kooooo00Co0?l0oooooooooooo
ool00_ooool00oooo`3oooooooooo`06ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0oooo0?oo
o`004_ooool0017ooooo00Coool0ooooooooooooool01?ooool00ol0o`3oooooooooo`05ooooo`03
oooo0?oooooooooo00Kooooo00?oool0ooooooooool01oooool00oooo`3oooooooooo`06ooooo`03
oooo0?oooooooooo00;ooooo0ol0o`06ooooo`03oooo0?oooooooooo00;ooooo00?o0?l0oooooooo
ool03?ooool00oooo`3oooooooooo`0<ooooo`03oooo0?oooooooooo03Kooooo0_l0o`02ooooo`03
o`3o0?oooooooooo00Oooooo00?oool0ooooooooool01_ooool00oooo`3oooooooooo`0;ooooo`?o
ool05_ooool2oooo00kooooo0_l0o`02ooooo`04oooo0?oooooooooooooo00Sooooo00?o0?l0oooo
ooooool00_ooool01?l0o`3ooooooooo0?ooo`0Booooo`004Oooool01?ooo`3oooooooooooooo`05
ooooo`03o`3o0?oooooooooo00Cooooo00?oool0ooooooooool01_ooool00oooo`3oooooooooo`07
ooooo`03oooo0?oooooooooo00Kooooo00?oool0ooooooooool01Oooool3o`3o00?ooooo00?oool0
ooooooooool00_ooool00ol0o`3oooooooooo`0<ooooo`03oooo0?oooooooooo00cooooo00?oool0
ooooooooool0>?ooool2o`3o00[ooooo00?oool0ooooooooool01Oooool00oooo`3oooooooooo`08
ooooo`Coool05_ooool3oooo0003ooooool0o`3ooooo00cooooo00?o0?l0ooooooooool00_ooo`02
ooooo`03oooo0?oooooooooo00Kooooo00?o0?l0ooooooooool00oooool01?l0o`3oool0oooooooo
o`0Booooo`004Oooool01Oooo`3oooooooooooooooooool000Gooooo00?o0?l0ooooooooool00ooo
ool00oooo`3oooooooooo`06ooooo`03oooo0?oooooooooo00Oooooo00?oool0ooooooooool01Ooo
ool2oooo00[ooooo0_l0o`02ooooo`04oooo0?ooooooooooo`3o00oooooo00?oool0ooooooooool0
3?ooool00oooo`3oooooooooo`0hooooo`;o0?l02Oooool00oooo`3oooooooooo`05ooooo`03oooo
0?oooooooooo00Gooooo1?ooo`0Hooooo`;oool01?ooool00ol0o`3oooooooooo`09ooooo`;o0?l0
0_ooool01Oooo`3oooooooooooooooooool000Sooooo00?o0?l0ooooooooool00oooool01Ol0o`3o
oooooooo0?ooooooool001;ooooo000Booooo`04oooo0?oooooooooooooo00Gooooo00?o0?l0oooo
ooooool00oooool00oooo`3oooooooooo`05ooooo`03oooo0?oooooooooo00Oooooo00?oool0oooo
ooooool01_ooool2oooo00cooooo0_l0o`000oooo`3oooooo`3o000@ooooo`03oooo0?oooooooooo
00cooooo00?oool0ooooooooool0>?ooool00ol0o`3oooooo`3o0007ooooo`03oooo0?oooooooooo
00Kooooo00Coool0oooooooooooooooo1?ooo`0Iooooo`?oool01_ooool00ol0o`3oooooooooo`08
ooooo`05o`3o0?ooooooooooooooooooo`000_ooool2oooo00Wooooo00?o0?l0ooooooooool00ooo
ool01?l0o`3ooooooooo0?ooo`0Cooooo`004_ooool01?ooo`3oooooooooooooo`06ooooo`03o`3o
0?oooooooooo00;ooooo00?oool0ooooooooool01Oooool00oooo`3oooooooooo`07ooooo`03oooo
0?oooooooooo00Kooooo00?oool0ooooooooo`003Oooool01?ooo`3o0?l0o`3o0?l0o`0?ooooo`03
oooo0?oooooooooo00cooooo00?oool0ooooooooool0=oooool01?l0o`3oooooooooooooool2o`3o
00Cooooo00?oool0ooooooooool01_ooool00oooo`3ooooooooo0002oooo01_ooooo0_ooo`0:oooo
o`03o`3o0?oooooooooo00Gooooo0_l0o`03ooooo`04oooo0?oooooooooooooo00[ooooo00?o0?l0
ooooooooool01?ooool01?l0o`3ooooooooo0?ooo`0Cooooo`004_ooool01Oooo`3ooooooooooooo
ooooool000Kooooo00Go0?l0oooooooooooooooooooo0007ooooo`03oooo0?oooooooooo00Oooooo
00?oool0ooooooooool01Oooool01?ooo`3oooooooooooooo`0>ooooo`03o`3o0?oooooooooo00?o
0?l03Oooool00oooo`3oooooooooo`0;ooooo`03oooo0?oooooooooo03Kooooo00?o0?l0oooooooo
ool01?ooool01Ol0o`3oooooooooooooooooool000Kooooo1?ooo`0Looooo`;oool03?ooool00ol0
o`3oooooooooo`04ooooo`04o`3o0?ooooooooooooooo`;oool00_ooool00oooo`3oooooooooo`08
ooooo`03o`3o0?oooooooooo00Cooooo00Go0?l0ooooooooo`3ooooooooo000Cooooo`004_ooool0
1Oooo`3oooooooooooooooooool000Kooooo00Go0?l0oooooooooooooooooooo0007ooooo`03oooo
0?oooooooooo00Oooooo00?oool0ooooooooool01Oooool01?ooo`3oooooooooooooo`0=ooooo`03
o`3o0?ooo`3ooooo00Cooooo0ol0o`0:ooooo`03oooo0?oooooooooo00_ooooo00?oool0oooooooo
ool0=_ooool00ol0o`3oooooooooo`05ooooo`03o`3o0?ooooooool000?ooooo1?ooo`000ooooooo
ool0ooooo`0Jooooo`?oool03_ooool00ol0o`3oooooooooo`02ooooo`;o0?l00oooool01Oooo`3o
ooooooooooooooooool000_ooooo00?o0?l0ooooooooool01?ooool01Ol0o`3ooooooooo0?oooooo
ool001?ooooo000Booooo`05oooo0?ooooooooooooooooooo`001oooool01Ol0o`3ooooooooooooo
ooooool000Kooooo00?oool0ooooooooool01_ooool00oooo`3oooooooooo`06ooooo`04oooo0?oo
oooooooooooo00gooooo00?o0?l0oooo0?ooool01oooool3o`3o00Oooooo00?oool0ooooooooool0
2_ooool00oooo`3oooooooooo`0fooooo`03o`3o0?oooooooooo00Oooooo1Oooo`04ooooo`03oooo
0?oooooooooo01Sooooo0_ooo`0Booooo`04o`3o0?ooooooooooo`3o00Cooooo00Goool0oooooooo
oooooooooooo000;ooooo`03o`3o0?oooooooooo00Gooooo00Go0?l0ooooooooo`3ooooooooo000C
ooooo`004oooool01Oooo`3oooooooooooooooooool000Oooooo00Co0?l0ooooooooooooool01_oo
ool00oooo`3oooooooooo`06ooooo`03oooo0?oooooooooo00Gooooo00?oool0ooooooooool00_oo
ool00oooo`3oooooooooo`09ooooo`04o`3o0?oooooooooooooo00[ooooo0ol0o`04ooooo`03oooo
0?oooooooooo00[ooooo00?oool0ooooooooool0=_ooool00ol0o`3oooooooooo`05ooooo`?oool0
00?oooooo`3o0?ooool01Oooool00oooo`3oooooooooo`0Fooooo`;oool05?ooool3o`3o00?ooooo
0_ooo`03ooooo`03oooo0?oooooooooo00Wooooo00?o0?l0ooooooooool01Oooool01Ol0o`3ooooo
oooo0?ooooooool001Cooooo000Cooooo`05oooo0?ooooooooooooooooooo`001oooool01?l0o`3o
ooooooooooooo`06ooooo`03oooo0?oooooooooo00Kooooo00?oool0ooooooooool01Oooool00ooo
o`3oooooooooo`02ooooo`03oooo0?oooooooooo00Sooooo00Go0?l0oooooooooooooooooooo000=
ooooo`?o0?l000?ooooooooo0?ooool02oooool00oooo`3oooooooooo`0eooooo`03o`3o0?oooooo
oooo00;ooooo1?ooo`000oooooooool0ooooo`02ooooo`03o`3o0?oooooooooo00;ooooo00?oool0
ooooooooool05?ooool3oooo01Kooooo00?o0?l0ooooooooool00_ooool00oooo`3oooooooooo`02
ooooo`03oooo0?oooooooooo00[ooooo00?o0?l0ooooooooool01Oooool01Ol0o`3ooooooooo0?oo
ooooool001Cooooo000Cooooo`03oooo0?oooooooooo00;ooooo00?oool0ooooooooool01Oooool0
0ol0o`3ooooooooo0006ooooo`03oooo0?oooooooooo00Kooooo00?oool0ooooooooool01?ooool0
0oooo`3oooooooooo`03ooooo`03oooo0?oooooooooo00Oooooo00?o0?l0ooooooooool00_ooool0
0oooo`3oooooooooo`0>ooooo`03o`3o0?ooo`3o0?l000_ooooo00?oool0ooooooooool0=?ooool0
0ol0o`3ooooooooo0003oooo00Cooooo00?oool0ooooooooool00oooool2o`3o00;ooooo00?oool0
ooooooooool04_ooool2oooo01Oooooo0_l0o`001Ooooooo0?l0ooooooooooooool000?ooooo0_oo
o`0<ooooo`03o`3o0?oooooooooo00Gooooo00Ko0?l0ooooooooooooool0ooooooooo`0Dooooo`00
4oooool00oooo`3oooooooooo`02ooooo`03oooo0?oooooooooo00Kooooo00?o0?l0oooo0?ooool0
1Oooool00oooo`3oooooooooo`06ooooo`03oooo0?oooooooooo00Cooooo00?oool0ooooooooool0
1?ooool00oooo`3oooooooooo`06ooooo`03o`3o0?oooooooooo00;ooooo00?oool0ooooooooool0
3oooool00oooo`3oooooo`3o0002o`3o00Sooooo00?oool0ooooooooool0<_ooool4oooo00Sooooo
00?oool0ooooooooool01Oooool00ol0o`3oool0ooooo`0Aooooo`?oool05oooool2o`3o00?ooooo
00?o0?l0oooo0?ooo`000oooool00oooo`3oooooooooo`0;ooooo`03o`3o0?oooooooooo00Kooooo
00?o0?l0ooooooooo`000_ooool00oooo`3oooooooooo`0Booooo`004oooool00oooo`3ooooooooo
o`02ooooo`03oooo0?oooooooooo00Kooooo00?o0?l0oooo0?ooool01Oooool00oooo`3ooooooooo
o`05ooooo`03oooo0?oooooooooo00Gooooo00?oool0ooooooooool01?ooool00oooo`3ooooooooo
o`05ooooo`03o`3o0?oooooooooo00Cooooo00?oool0ooooooooool03_ooool00oooo`3ooooooooo
o`02ooooo`?o0?l01Oooool00oooo`3oooooooooo`0_ooooo`?oool000?oooooo`3o0?ooool02?oo
ool00oooo`3oooooooooo`06ooooo`03oooo0?l0o`3ooooo00oooooo0_ooo`0Iooooo`03o`3o0?oo
oooooooo00?ooooo00?oool0ooooooooool00_ooool00oooo`3oooooooooo`0<ooooo`03o`3o0?oo
oooooooo00Kooooo00?o0?l0ooooooooo`000_ooool00oooo`3oooooooooo`0Booooo`005?ooool0
0oooo`3oooooooooo`02ooooo`03oooo0?oooooooooo00Kooooo00?oool0ooooooooool01?ooool0
0oooo`3oooooooooo`05ooooo`03oooo0?oooooooooo00Cooooo00?oool0ooooooooool01Oooool0
0oooo`3oooooooooo`04ooooo`03o`3o0?oooooooooo00Gooooo00?oool0ooooooooool03_ooool0
0oooo`3oooooooooo`05ooooo`?o0?l00_ooool00oooo`3oooooooooo`0[ooooo`Coool01?ooool0
0ol0o`3oooooooooo`06ooooo`03oooo0?oooooooooo00Oooooo00Coool0ooooool0o`3o0?l03?oo
ool2oooo01Wooooo0_l0o`05ooooo`03oooo0?l0o`3ooooo00;ooooo00?oool0ooooooooool03?oo
ool00ol0o`3oooooooooo`06ooooo`06o`3o0?oooooooooooooo0?ooooooool05Oooool001Cooooo
00?oool0ooooooooool00_ooool00oooo`3oooooooooo`06ooooo`03oooo0?l0o`3ooooo00Cooooo
00?oool0ooooooooool01Oooool00oooo`3oooooooooo`04ooooo`03oooo0?oooooooooo00Kooooo
00?oool0ooooooooool00oooool00ol0o`3oooooooooo`05ooooo`03oooo0?oooooooooo00kooooo
00?oool0ooooooooool02?ooool2o`3o0003oooo0?oooooooooo02Sooooo0oooo`07ooooo`03o`3o
0?oooooooooo00Kooooo00?oool0ooooooooool01oooool00oooo`3oooooooooo`02ooooo`03o`3o
0?oooooooooo00Kooooo0oooo`0Jooooo`03o`3o0?oooooooooo00?ooooo0_ooo`02ooooo`03o`3o
0?ooooooool000kooooo00?o0?l0ooooooooool01oooool01_l0o`3oooooooooooooo`3ooooooooo
01Gooooo000Dooooo`03oooo0?oooooooooo00?ooooo00?oool0ooooooooool01Oooool00oooo`3o
ooooo`3o0004ooooo`03oooo0?oooooooooo00Gooooo00?oool0ooooooooool00oooool00oooo`3o
ooooooooo`07ooooo`03oooo0?oooooooooo00;ooooo00?o0?l0ooooooooool01_ooool00oooo`3o
ooooooooo`0>ooooo`03oooo0?oooooooooo00[ooooo00Coool0o`3o0?l0o`3o0?l09?ooool3oooo
00Wooooo00?o0?l0ooooooooool01oooool00oooo`3oooooooooo`06ooooo`03oooo0?oooooooooo
00Cooooo00?o0?l0ooooooooool00oooool2oooo01_ooooo0_l0o`05ooooo`03oooo0?oooooooooo
00;ooooo00?o0?l0oooo0?ooool03Oooool00ol0o`3oooooooooo`07ooooo`04o`3o0?oooooooooo
oooo00;ooooo00?oool0ooooooooool04oooool001Cooooo00?oool0ooooooooool00oooool00ooo
o`3oooooooooo`05ooooo`03oooo0?oooooo0?l000?ooooo00?oool0ooooooooool01Oooool00ooo
o`3oooooooooo`04ooooo`03oooo0?oooooooooo00Sooooo00Coool0oooooooooooo0?l02_ooool0
0oooo`3oooooooooo`0=ooooo`03oooo0?oooooooooo00[ooooo00Coool0oooooooooooooooo0ol0
o`0Oooooo`;oool03?ooool00ol0o`3oooooooooo`06ooooo`03oooo0?oooooooooo00Kooooo00?o
ool0ooooooooool01_ooool2o`3o00?oool07?ooool00ol0o`3oooooooooo`04ooooo`03oooo0?oo
oooooooo00?ooooo00?oool0ooooooooool03Oooool00ol0o`3oooooooooo`07ooooo`04o`3o0?oo
oooooooooooo00;ooooo00?oool0ooooooooool04oooool001Gooooo00?oool0ooooooooool00_oo
ool00oooo`3oooooooooo`05ooooo`04oooo0?ooooooooooo`3o00;ooooo00?oool0ooooooooool0
1Oooool00oooo`3oooooooooo`04ooooo`03oooo0?oooooooooo00Sooooo00Coool0oooooooooooo
0?l02_ooool00oooo`3oooooooooo`0=ooooo`03oooo0?oooooooooo00[ooooo00?oool0oooooooo
ool01?ooool3o`3o01[ooooo0_ooo`0=ooooo`03o`3o0?oooooooooo00Kooooo00?oool0oooooooo
ool01_ooool00oooo`3oooooooooo`07ooooo`;oool000?o0?l0ooooooooool06_ooool2o`3o00Ko
oooo00?oool0ooooooooool00_ooool2oooo0003ooooool0o`3ooooo00cooooo00?o0?l0oooooooo
ool02?ooool01_l0o`3oooooooooooooo`3ooooooooo01Kooooo000Eooooo`03oooo0?oooooooooo
00?ooooo00?oool0ooooooooool01?ooool01oooo`3ooooooooooooooooo0?l0ooooooooo`001ooo
ool00oooo`3oooooooooo`03ooooo`03oooo0?oooooooooo00Wooooo00?oool0ooooool0o`002ooo
ool00oooo`3oooooooooo`0=ooooo`03oooo0?oooooooooo00[ooooo00?oool0ooooooooool01ooo
ool3o`3o01Cooooo0oooo`0?ooooo`03o`3o0?oooooooooo00Kooooo00?oool0ooooooooool01_oo
ool00oooo`3oooooooooo`05ooooo`;oool00oooool00ol0o`3oooooooooo`0Hooooo`03o`3o0?oo
oooooooo00Cooooo0_ooo`04ooooo`05oooo0?ooooooooooooooool0o`003?ooool00ol0o`3ooooo
ooooo`08ooooo`04o`3o0?oooooooooooooo00;ooooo00?oool0ooooooooool05?ooool001Gooooo
00?oool0ooooooooool00oooool00oooo`3oooooooooo`04ooooo`07oooo0?ooooooooooooooool0
o`3ooooooooo0007ooooo`03oooo0?oooooooooo00?ooooo00?oool0ooooooooool02_ooool00ol0
o`3oooooooooo`0:ooooo`03oooo0?oooooooooo00kooooo00?oool0ooooooooool02Oooool00ooo
o`3oooooooooo`0:ooooo`?o0?l03oooool2oooo017ooooo00?o0?l0ooooooooool01_ooool00ooo
o`3oooooooooo`06ooooo`03oooo0?oooooooooo00?ooooo0oooo`06ooooo`;o0?l05_ooool2o`3o
00Kooooo00?oool0ooooooooool00oooool00oooo`3oooooooooo`02ooooo`03o`3o0?oooooooooo
00[ooooo00?o0?l0ooooooooool02?ooool01?l0o`3oooooooooooooo`02ooooo`03oooo0?oooooo
oooo01Cooooo000Eooooo`03oooo0?oooooooooo00?ooooo00?oool0ooooooooool01?ooool00ooo
o`3oooooooooo`02ooooo`03o`3o0?ooo`3ooooo00Gooooo00?oool0ooooooooool01?ooool00ooo
o`3oooooooooo`0:ooooo`03o`3o0?oooooooooo00_ooooo00?oool0ooooooooool03Oooool00ooo
o`3oooooooooo`09ooooo`03oooo0?oooooooooo00gooooo0ol0o`09ooooo`?oool04_ooool00ol0
o`3oooooooooo`06ooooo`03oooo0?oooooooooo00Kooooo00?oool0ooooooooool00_ooool2oooo
00_ooooo00?o0?l0ooooooooool04_ooool00ol0o`3oooooooooo`05ooooo`03oooo0?oooooooooo
00?ooooo00?oool0ooooooooool01?ooool00ol0o`3oooooooooo`08ooooo`03o`3o0?oooooooooo
00Wooooo00Co0?l0ooooooooooooool00_ooool00oooo`3oooooooooo`0Dooooo`005Oooool00ooo
o`3oooooooooo`04ooooo`03oooo0?oooooooooo00?ooooo00?oool0ooooooooool00oooool00ooo
o`3oooooooooo`04ooooo`03oooo0?oooooooooo00?ooooo00?oool0ooooooooool02_ooool00ol0
o`3oool0ooooo`0<ooooo`03oooo0?oooooooooo00gooooo00?oool0ooooooooool02Oooool00ooo
o`3oooooooooo`0@ooooo`?o0?l01?ooool2oooo01Gooooo00?o0?l0ooooooooool01_ooool00ooo
o`3oooooooooo`05ooooo`03oooo0?oooooooooo00?oool03_ooool00ol0o`3oooooooooo`0?oooo
o`;o0?l01_ooool2oooo00Gooooo00?oool0ooooooooool01Oooool00ol0o`3oooooooooo`07oooo
o`03o`3o0?oooooooooo00Wooooo00Co0?l0ooooooooooooool00oooool00oooo`3oooooooooo`0D
ooooo`005_ooool00oooo`3oooooooooo`03ooooo`03oooo0?oooooooooo00?ooooo00?oool0oooo
ooooool00oooool00oooo`3oooooooooo`04ooooo`03oooo0?oooooooooo00?ooooo00?oool0oooo
ooooool02Oooool01?l0o`3oooooooooooooo`0<ooooo`03oooo0?oooooooooo00gooooo00?oool0
ooooooooool02Oooool00oooo`3oooooooooo`0Cooooo`04o`3o0?ooo`3oool0oooo01Kooooo00?o
0?l0ooooooooool01_ooool00oooo`3oooooooooo`05ooooo`04oooo0?ooooooool0oooo01;ooooo
0_l0o`0>ooooo`03o`3o0?oooooooooo00Gooooo00?oool0ooooooooool01?ooool00oooo`3ooooo
ooooo`06ooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0ooooooooool02Oooool01?l0o`3ooooo
ooooooooo`02ooooo`03oooo0?oooooooooo01Gooooo000Fooooo`03oooo0?oooooooooo00?ooooo
00?oool0ooooooooool01?ooool00oooo`3oooooooooo`02ooooo`03oooo0?l0o`3ooooo00Cooooo
00?oool0ooooooooool00_ooool00oooo`3oooooooooo`09ooooo`05o`3o0?oooooooooooooooooo
o`003?ooool00oooo`3oooooooooo`0=ooooo`03oooo0?oooooooooo00Wooooo00?oool0oooooooo
ool04_ooool2oooo0004ooooool0o`3o0?l0o`3o01Gooooo00?o0?l0ooooooooool01Oooool00ooo
o`3oooooooooo`06ooooo`;oool05_ooool00ol0o`3oooooooooo`09ooooo`;o0?l01oooool00ooo
o`3oooooooooo`04ooooo`03oooo0?oooooooooo00Sooooo00?o0?l0ooooooooool01Oooool00ol0
o`3oooooooooo`0:ooooo`04o`3o0?oooooooooooooo00;ooooo00?oool0ooooooooool05Oooool0
01Kooooo00?oool0ooooooooool01?ooool00oooo`3oooooooooo`03ooooo`03oooo0?oooooooooo
00;ooooo00?oool0ooooool0o`000oooool00oooo`3oooooooooo`03ooooo`03oooo0?oooooooooo
00Wooooo00?o0?l0ooooooooool00_ooool00oooo`3oooooooooo`09ooooo`03oooo0?oooooooooo
00gooooo00?oool0ooooooooool02?ooool00oooo`3oooooooooo`0Aooooo`;oool01_ooool3o`3o
017ooooo00?o0?l0ooooooooool01_ooool00oooo`3oooooooooo`03ooooo`?oool06Oooool00ol0
o`3oooooooooo`07ooooo`03o`3o0?oooooooooo00Gooooo0_ooo`06ooooo`03oooo0?oooooooooo
00Wooooo00?o0?l0ooooooooool01?ooool00ol0o`3oooooooooo`0:ooooo`05o`3o0?oooooooooo
ooooooooo`000_ooool00oooo`3oooooooooo`0Eooooo`005oooool00oooo`3oooooooooo`03oooo
o`03oooo0?oooooooooo00?ooooo00?oool0ooooooooool00_ooool00oooo`3oooooo`3o0003oooo
o`03oooo0?oooooooooo00?ooooo00?oool0ooooooooool02?ooool00ol0o`3oooooooooo`03oooo
o`03oooo0?oooooooooo00[ooooo00?oool0ooooooooool03?ooool00oooo`3oooooooooo`08oooo
o`03oooo0?oooooooooo00kooooo0oooo`0;ooooo`?o0?l03Oooool00ol0o`3oooooooooo`06oooo
o`03oooo0?oooooooooo00;ooooo0_ooo`000oooooooool0ooooo`0Jooooo`;o0?l01Oooool2o`3o
00Oooooo00?oool0ooooooooool01?ooool2oooo00cooooo00?o0?l0ooooooooool01?ooool00ol0
o`3oooooooooo`0:ooooo`04o`3o0?oooooooooooooo00;ooooo00?oool0ooooooooool05_ooool0
01Oooooo00?oool0ooooooooool00oooool00oooo`3oooooooooo`03ooooo`03oooo0?oooooooooo
00;ooooo00Coool0oooooooooooo0?l00_ooool00oooo`3oooooooooo`02ooooo`03oooo0?oooooo
oooo00Sooooo00?o0?l0ooooooooool01?ooool00oooo`3oooooooooo`0:ooooo`03oooo0?oooooo
oooo00cooooo00?oool0ooooooooool02?ooool00oooo`3oooooooooo`0<ooooo`;oool04Oooool3
o`3o00[ooooo00?o0?l0ooooooooool01Oooool00oooo`3oooooooooo`03oooo00;ooooo00?oool0
ooooooooool07?ooool01Ol0o`3ooooooooooooooooo0?l000Sooooo00?oool0ooooooooool01?oo
ool00oooo`3oooooooooo`0=ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool02ooo
ool01?l0o`3oooooooooooooo`02ooooo`03oooo0?oooooooooo01Kooooo000Gooooo`03oooo0?oo
oooooooo00?ooooo00?oool0ooooooooool00oooool00oooo`3oooooooooo`02ooooo`07oooo0?oo
ooooooooooooool0o`3ooooooooo0004ooooo`03oooo0?oooooooooo00Sooooo00?o0?l0oooooooo
ool01Oooool00oooo`3oooooooooo`09ooooo`03oooo0?oooooooooo00cooooo00?oool0oooooooo
ool02?ooool00oooo`3oooooooooo`09ooooo`?oool05_ooool3o`3o00Kooooo00?o0?l0oooooooo
ool01Oooool01?ooo`3ooooooooo0?ooo`05ooooo`03oooo0?oooooooooo01gooooo0ol0o`07oooo
o`;oool01_ooool00oooo`3oooooooooo`0>ooooo`05o`3o0?ooooooooooooooool0o`003_ooool0
1?l0o`3oooooooooooooo`02ooooo`03oooo0?oooooooooo01Kooooo000Hooooo`03oooo0?oooooo
oooo00;ooooo00?oool0ooooooooool00oooool00oooo`3oooooooooo`02ooooo`03oooo0?oooooo
oooo00;ooooo00?oool0ooooooooool00_ooool00oooo`3oooooooooo`08ooooo`03o`3o0?oooooo
oooo00Kooooo00?oool0ooooooooool02Oooool00oooo`3oooooooooo`0<ooooo`03oooo0?oooooo
oooo00Sooooo00?oool0ooooooooool01oooool2oooo01cooooo0ol0o`03ooooo`03o`3o0?oooooo
oooo00Gooooo0_ooo`06ooooo`03oooo0?oooooooooo01kooooo0ol0o`06ooooo`03oooo0?oooooo
oooo00Gooooo00?oool0ooooooooool03oooool01?l0o`3oooooooooool0o`0?ooooo`03o`3o0?oo
ooooool000;ooooo00?oool0ooooooooool05oooool001Sooooo00?oool0ooooooooool00oooool0
0oooo`3oooooooooo`02ooooo`03oooo0?oooooooooo00;ooooo00?oool0ooooooooool00_ooool0
0oooo`3oooooooooo`02ooooo`03oooo0?oooooooooo00Oooooo00?o0?l0ooooooooool02?ooool0
0oooo`3oooooooooo`09ooooo`03oooo0?oooooooooo00_ooooo00?oool0ooooooooool02?ooool0
0oooo`3oooooooooo`05ooooo`;oool08Oooool3o`3o00Gooooo0oooo`07ooooo`03oooo0?oooooo
oooo01gooooo0_l0o`03ooooo`03o`3o0?oooooooooo00;ooooo00?oool0ooooooooool01Oooool0
0oooo`3oooooooooo`0@ooooo`04o`3o0?ooooooooooo`3o00kooooo00Co0?l0ooooooooooooool0
0_ooool00oooo`3oooooooooo`0Gooooo`006Oooool00oooo`3oooooooooo`02ooooo`03oooo0?oo
oooooooo00;ooooo00Goool0oooooooooooooooooooo0005ooooo`03oooo0?l0o`3ooooo00;ooooo
00?oool0ooooooooool01oooool00ol0o`3oooooooooo`08ooooo`03oooo0?oooooooooo00Wooooo
00?oool0ooooooooool02oooool00oooo`3oooooooooo`08ooooo`03oooo0?oooooooooo00;ooooo
0oooo`0Tooooo`04o`3o0?oooooo0?l0o`3o00?oool000?ooooooooo0?ooool01_ooool00oooo`3o
ooooooooo`0Mooooo`03o`3o0?oooooooooo00Cooooo00Co0?l0ooooooooooooool01oooool00ooo
o`3oooooooooo`0Booooo`;o0?l03oooool01_l0o`3oooooooooooooo`3ooooooooo01[ooooo000I
ooooo`03oooo0?oooooooooo00;ooooo00?oool0ooooooooool00_ooool01Oooo`3ooooooooooooo
ooooool000Gooooo00Goool0ooooool0o`3ooooooooo0009ooooo`03o`3o0?oooooooooo00Wooooo
00?oool0ooooooooool02Oooool00oooo`3oooooooooo`0;ooooo`03oooo0?oooooooooo00Sooooo
00?oool0ooooooooool00_ooo`0Wooooo`Coool000Goooooo`3o0?l0o`3o0?l0oooo0006ooooo`03
oooo0?oooooooooo01cooooo0_l0o`08ooooo`;oool01oooool00oooo`3oooooooooo`0Cooooo`03
o`3o0?oooooooooo00kooooo00?o0?l0ooooooooo`000_ooool00oooo`3oooooooooo`0Hooooo`00
6Oooool00oooo`3oooooooooo`02ooooo`03oooo0?oooooooooo00;ooooo00Goool0oooooooooooo
oooooooo0004ooooo`06oooo0?ooooooooooo`3o0?ooooooool02?ooool00ol0o`3oooooooooo`0;
ooooo`03oooo0?oooooooooo00Sooooo00?oool0ooooooooool02oooool00oooo`3oooooooooo`08
ooooo`?oool09_ooool3oooo00Oooooo00Coool0o`3o0?l0o`3o0?l01?ooool00oooo`3ooooooooo
o`0Kooooo`03o`3o0?oooooooooo00Oooooo00Coool0oooooooooooo0?l01?ooool2oooo01Kooooo
00?o0?l0ooooooooool03_ooool00ol0o`3ooooooooo0002ooooo`03oooo0?oooooooooo01Sooooo
000Jooooo`03oooo0?oooooooooo00;ooooo00Goool0oooooooooooooooooooo0003ooooo`03oooo
0?oooooooooo00;ooooo00Goool0oooooooooooooooooooo0009ooooo`03o`3o0?oooooooooo00_o
oooo00?oool0ooooooooool02Oooool00oooo`3oooooooooo`0:ooooo`03oooo0?oooooooooo00Ko
oooo0oooo`0Tooooo`Coool00_ooool00ol0o`3oooooooooo`04ooooo`03oooo0?oooooooooo00;o
oooo0ol0o`000oooo`3oooooooooo`0Jooooo`;o0?l02Oooool00oooo`3oooooooooo`02ooooo`04
o`3o0?oooooooooooooo01Oooooo00?o0?l0ooooool0o`003_ooool01_l0o`3oooooooooooooo`3o
oooooooo01_ooooo000Jooooo`03oooo0?oooooooooo00;ooooo00Goool0oooooooooooooooooooo
0003ooooo`03oooo0?oooooooooo00;ooooo00Koool0oooooooooooooooooooo0?l0o`07ooooo`03
o`3o0?oooooooooo00gooooo00?oool0ooooooooool02?ooool00oooo`3oooooooooo`0;ooooo`03
oooo0?oooooooooo00;ooooo0oooo`02ooooo`03oooo0?oooooooooo01kooooo1?ooo`05ooooo`03
o`3o0?oooooooooo00Gooooo00?oool0ooooooooool01?ooool01?ooo`3o0?l0o`3o0?l0o`0Ioooo
o`03o`3o0?oooooooooo00Oooooo0_ooo`06ooooo`03o`3o0?ooo`3ooooo01Kooooo00Co0?l0oooo
oooooooo0?l03_ooool01_l0o`3oooooooooooooo`3ooooooooo01_ooooo000Jooooo`03oooo0?oo
oooooooo00;ooooo00Goool0oooooooooooooooooooo0003ooooo`03oooo0?oooooooooo00;ooooo
00Koool0oooooooooooooooooooo0?l0o`06ooooo`03o`3o0?oooooooooo00kooooo00?oool0oooo
ooooool02?ooool00oooo`3oooooooooo`0;ooooo`03oooo0?oooooooooo00;oool01Oooool00ooo
o`3oooooooooo`0Jooooo`Coool02?ooool00ol0o`3oooooooooo`05ooooo`03oooo0?oooooooooo
00Cooooo00?oool0ooooooooool00_ooool3o`3o01Cooooo0_l0o`09ooooo`03oooo0?oooooooooo
00Kooooo00?oool0ooooool0o`005_ooool01?l0o`3oooooooooool0o`0>ooooo`03o`3o0?oooooo
ool000;ooooo00?oool0ooooooooool06Oooool001_ooooo00Goool0oooooooooooooooooooo0003
ooooo`05oooo0?ooooooooooooooooooo`000oooool01Oooo`3oooooooooooooooooool000;ooooo
00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`0?ooooo`03oooo0?oooooooooo00Sooooo
00?oool0ooooooooool02oooool3oooo00Oooooo00?oool0ooooooooool05_ooool4oooo00cooooo
00?o0?l0ooooooooool01?ooool00oooo`3oooooooooo`04ooooo`03oooo0?oooooooooo00Kooooo
0ol0o`0@ooooo`03o`3o0?oooooooooo00Sooooo00?oool0ooooooooool01_ooool01Oooo`3ooooo
oooooooooooo0?l001Cooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`0;ooooo`05
o`3o0?ooooooool0ooooooooo`007?ooool001_ooooo00Goool0oooooooooooooooooooo0003oooo
o`05oooo0?ooooooooooooooooooo`000oooool01Oooo`3oooooooooooooooooool000?ooooo00Go
0?l0ooooooooooooooooo`3o000Booooo`03oooo0?oooooooooo00Sooooo00?oool0ooooooooool0
2?ooool3oooo00Wooooo00?oool0ooooooooool04oooool3oooo00oooooo00?o0?l0ooooooooool0
1?ooool00oooo`3oooooooooo`05ooooo`03oooo0?oooooooooo00Wooooo0ol0o`0;ooooo`;o0?l0
2Oooool2oooo00Sooooo00?oool0ooooooooool00oooool2o`3o017ooooo00?o0?l0ooooooooool0
0oooool00ol0o`3oooooooooo`0;ooooo`05o`3o0?ooooooool0ooooooooo`007?ooool001cooooo
00Goool0oooooooooooooooooooo0002ooooo`05oooo0?ooooooooooooooooooo`000oooool01Ooo
o`3oooooooooooooooooool000?ooooo00Co0?l0oooooooooooo0?l04oooool00oooo`3ooooooooo
o`08ooooo`03oooo0?oooooooooo00Kooooo0_ooo`02ooooo`03oooo0?oooooooooo00Oooooo00?o
ool0ooooooooool03oooool4oooo01;ooooo00?o0?l0ooooooooool01?ooool00oooo`3ooooooooo
o`04ooooo`03oooo0?oooooooooo00gooooo0ol0o`07ooooo`03o`3o0?oooooooooo00Sooooo00?o
ool0ooooooooool01oooool00oooo`3oooooooooo`06ooooo`03o`3o0?oooooooooo00kooooo00?o
0?l0ooooooooool00oooool00ol0o`3oooooooooo`0:ooooo`05o`3o0?ooooooool0ooooooooo`00
7Oooool001cooooo00Goool0oooooooooooooooooooo0003ooooo`04oooo0?oooooooooooooo00?o
oooo00Coool0ooooooooooooool01Oooool2o`3o01Cooooo00?oool0ooooooooool02?ooool00ooo
o`3oooooooooo`03ooooo`?oool01?ooool00oooo`3oooooooooo`07ooooo`03oooo0?oooooooooo
00_ooooo1?ooo`0Eooooo`03o`3o0?oooooooooo00Cooooo00?oool0ooooooooool01?ooool00ooo
o`3oooooooooo`0Aooooo`?o0?l00_ooool2o`3o00[ooooo00?oool0ooooooooool01_ooool2oooo
00[ooooo00?o0?l0ooooooooool03?ooool00ol0o`3oooooooooo`05ooooo`03o`3o0?oooooooooo
00Wooooo00Go0?l0ooooooooo`3ooooooooo000Mooooo`007?ooool01Oooo`3ooooooooooooooooo
ool000?ooooo00Coool0ooooooooooooool00_ooool01Oooo`3oooooooooooooooooool000Kooooo
00?o0?l0ooooooooool04oooool00oooo`3oooooooooo`07ooooo`04oooo0?ooooooooooooooo`;o
ool01oooool00oooo`3oooooooooo`06ooooo`03oooo0?oooooooooo00Sooooo1?ooo`0Hooooo`03
o`3o0?oooooooooo00Cooooo00?oool0ooooooooool01?ooool00oooo`3oooooooooo`0Eooooo`?o
0?l02Oooool2oooo00Sooooo00?oool0ooooooooool02oooool2o`3o00_ooooo00?o0?l0oooooooo
ool01_ooool00ol0o`3oooooooooo`09ooooo`05o`3o0?ooooooool0ooooooooo`007Oooool001go
oooo00Coool0ooooooooooooool00oooool01?ooo`3oooooooooooooo`02ooooo`04oooo0?oooooo
oooooooo00Kooooo00?o0?l0ooooool0o`005?ooool00oooo`3oooooooooo`08ooooo`?oool02Ooo
ool00oooo`3oooooooooo`06ooooo`03oooo0?oooooooooo00Gooooo0oooo`0Looooo`03o`3o0?oo
oooooooo00Cooooo00?oool0ooooooooool00oooool00oooo`3oooooooooo`0Eooooo`;o0?l00_oo
ool3o`3o00Gooooo00?oool0ooooooooool01oooool00oooo`3oooooooooo`0>ooooo`03o`3o0?oo
oooooooo00Oooooo00?o0?l0ooooooooool01oooool00ol0o`3oooooooooo`09ooooo`04o`3o0?oo
o`3ooooooooo01kooooo000Mooooo`05oooo0?ooooooooooooooooooo`000_ooool01?ooo`3ooooo
ooooooooo`02ooooo`04oooo0?oooooooooooooo00Gooooo00Co0?l0oooooooooooo0?l05Oooool0
0oooo`3oooooooooo`05ooooo`?oool02oooool00oooo`3oooooooooo`06ooooo`04oooo0?oooooo
ooooooooo`Coool07_ooool00ol0o`3oooooooooo`04ooooo`03oooo0?oooooooooo00Cooooo00?o
ool0ooooooooool05?ooool00ol0o`3oooooooooo`05ooooo`;o0?l00_ooool00oooo`3ooooooooo
o`07ooooo`03oooo0?oooooooooo013ooooo00?o0?l0ooooooooool01_ooool00ol0o`3ooooooooo
o`08ooooo`03o`3o0?oooooooooo00Oooooo00Go0?l0ooooooooo`3ooooooooo000Nooooo`007_oo
ool01?ooo`3oooooooooooooo`02ooooo`03oooo0?ooooooool000?ooooo00Coool0oooooooooooo
ool01Oooool01Ol0o`3ooooooooooooooooo0?l001Cooooo00?oool0ooooooooool00oooool2oooo
00;ooooo00?oool0ooooooooool02Oooool00oooo`3oooooooooo`06ooooo`Coool08_ooool00ol0
o`3oooooooooo`03ooooo`03oooo0?oooooooooo00Cooooo00?oool0ooooooooool05?ooool00ol0
o`3oooooooooo`08ooooo`03o`3o0?ooo`3o0?l000Sooooo00?oool0ooooooooool04_ooool00ol0
o`3oooooooooo`04ooooo`03o`3o0?oooooooooo00Wooooo00?o0?l0ooooooooool01oooool01?l0
o`3ooooooooo0?ooo`0Oooooo`007_ooool01?ooo`3oooooooooooooo`02ooooo`03oooo0?oooooo
ool000;ooooo00Coool0ooooooooooooool01Oooool00ol0o`3oooooooooo`03ooooo`03o`3o0?oo
oooooooo017ooooo00?oool0ooooooooool00oooo`04ooooo`03oooo0?oooooooooo00Wooooo00?o
ool0ooooooooool00_ooool5oooo02Cooooo00?o0?l0ooooooooool01?ooool00oooo`3ooooooooo
o`03ooooo`03oooo0?oooooooooo01Cooooo00?o0?l0ooooooooool02?ooool2oooo00;ooooo0ol0
o`04ooooo`03oooo0?oooooooooo01Cooooo0_l0o`03ooooo`03o`3o0?oooooooooo00[ooooo00?o
0?l0ooooooooool01oooool01?l0o`3ooooooooo0?ooo`0Oooooo`007_ooool01?ooo`3ooooooooo
ooooo`02ooooo`03oooo0?ooooooool000;ooooo00Coool0ooooooooooooool01?ooool00ol0o`3o
ooooooooo`04ooooo`03o`3o0?oooooooooo01;ooooo0_ooo`08ooooo`03oooo0?oooooooooo00So
oooo1Oooo`04ooooo`03oooo0?oooooooooo027ooooo00?o0?l0ooooooooool01?ooool00oooo`3o
ooooooooo`03ooooo`03oooo0?oooooooooo01Cooooo00?o0?l0ooooooooool02?ooool00oooo`3o
ooooooooo`05ooooo`?o0?l000?oool0ooooooooool05oooool01?l0o`3oooooooooool0o`0=oooo
o`03o`3o0?oooooooooo00Kooooo00Co0?l0oooo0?ooooooool07oooool001oooooo00?oool0oooo
ooooo`000_ooool00oooo`3ooooooooo0002ooooo`03oooo0?ooooooool000Cooooo00?o0?l0oooo
ooooool01_ooool00ol0o`3oooooooooo`0>ooooo`Coool02Oooool00oooo`3oooooooooo`06oooo
o`?oool02?ooool00oooo`3oooooooooo`0Qooooo`03o`3o0?oooooooooo00?ooooo00?oool0oooo
ooooool01?ooool00oooo`3oooooooooo`0Cooooo`03o`3o0?oooooooooo00Sooooo00?oool0oooo
ooooool01oooool2oooo00?o0?l06?ooool2o`3o00kooooo00?o0?l0ooooooooool01_ooool00ol0
o`3oool0oooo000Pooooo`007oooool02?ooo`3oooooooooooooo`3ooooooooo0?ooooooool00_oo
ool00oooo`3ooooooooo0004ooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0ooooooooool02ooo
ool2oooo00Cooooo00?oool0ooooooooool01_ooool00oooo`3oooooooooo`02ooooo`Coool00_oo
ool00oooo`3oooooooooo`06ooooo`03oooo0?oooooooooo023ooooo00?o0?l0ooooooooool01?oo
ool00oooo`3oooooooooo`03ooooo`03oooo0?oooooooooo01?ooooo00?o0?l0ooooooooool01ooo
ool2oooo00Wooooo00?oool0ooooooooool00oooool3o`3o01Gooooo0ol0o`0=ooooo`03o`3o0?oo
oooooooo00Gooooo00Co0?l0ooooooooo`3oool08?ooool001oooooo00Soool0ooooooooooooool0
ooooooooo`3ooooooooo00;ooooo00?oool0ooooooooo`000oooool00ol0o`3oooooooooo`08oooo
o`03o`3o0?oooooooooo00Wooooo0_ooo`06ooooo`03oooo0?oooooooooo00Kooooo1Oooo`07oooo
o`03oooo0?oooooooooo00Gooooo00?oool0ooooooooool08?ooool00ol0o`3oooooooooo`03oooo
o`03oooo0?oooooooooo00?ooooo00?oool0ooooooooool04_ooool2o`3o00Wooooo00?oool0oooo
ooooool02?ooool00oooo`3oooooooooo`07ooooo`?o0?l04_ooool01?l0o`3oooooooooool0o`0<
ooooo`03o`3o0?oooooooooo00Gooooo00Co0?l0oooo0?ooooooool08?ooool0023ooooo00_oool0
ooooooooo`3ooooooooo0?ooooooool0ooooooooo`3ooooooooo0003ooooo`03o`3o0?oooooooooo
00[ooooo00?o0?l0ooooooooool01Oooool3oooo00Sooooo00?oool0ooooooooool00oooool5oooo
00[ooooo00?oool0ooooooooool01Oooool00oooo`3oooooooooo`0Oooooo`03o`3o0?oooooooooo
00?ooooo00?oool0ooooooooool00oooool00oooo`3oooooooooo`0Booooo`03o`3o0?oooooooooo
00Sooooo00?oool0ooooooooool02?ooool00oooo`3oooooooooo`0;ooooo`?o0?l03_ooool00ol0
o`3oooooooooo`02ooooo`03o`3o0?oooooooooo00[ooooo00?o0?l0ooooooooool01?ooool00ol0
o`3oool0oooo000Qooooo`008?ooool02oooo`3ooooooooo0?ooooooool0ooooooooo`3ooooooooo
0?ooooooool000?ooooo00?o0?l0ooooooooool02oooool00ol0o`3oooooooooo`02ooooo`;oool0
3?ooool5oooo00Cooooo00?oool0ooooooooool02?ooool00oooo`3oooooooooo`05ooooo`03oooo
0?oooooooooo01kooooo00?o0?l0ooooooooool00oooool00oooo`3oooooooooo`03ooooo`03oooo
0?oooooooooo01;ooooo00?o0?l0ooooooooool01oooool2oooo00[ooooo00?oool0ooooooooool0
3oooool3o`3o00[ooooo00?o0?l0ooooooooool01?ooool2o`3o00[ooooo00?o0?l0ooooooooool0
1?ooool00ol0o`3oool0oooo000Qooooo`008Oooool2oooo0005ooooooooo`3ooooooooo0?ooool0
0_ooo`03ooooo`03o`3o0?oooooooooo00cooooo00?o0?l0ooooooooo`000_ooo`0<ooooo`?oool0
2?ooool00oooo`3oooooooooo`08ooooo`03oooo0?oooooooooo00Gooooo00?oool0ooooooooool0
7_ooool00ol0o`3oooooooooo`03ooooo`03oooo0?oooooooooo00?ooooo00?oool0ooooooooool0
4Oooool00ol0o`3oooooooooo`07ooooo`03oooo0?oooooooooo00Wooooo00?oool0ooooooooool0
4oooool3o`3o00Oooooo00?o0?l0ooooooooool01_ooool00ol0o`3oooooooooo`07ooooo`03o`3o
0?oooooooooo00Cooooo0_ooo`0Rooooo`008Oooool01oooo`3ooooooooo0?ooo`3ooooooooo0?oo
ool00_ooo`02ooooo`03o`3o0?oooooooooo00gooooo0_ooo`0;ooooo`Coool00oooool00oooo`3o
ooooooooo`05ooooo`03oooo0?oooooooooo00Sooooo00?oool0ooooooooool01Oooool00oooo`3o
ooooooooo`0Mooooo`03o`3o0?oooooooooo00?ooooo00?oool0ooooooooool00oooool00oooo`3o
ooooooooo`0Aooooo`03o`3o0?oooooooooo00Oooooo00?oool0ooooooooool02Oooool00oooo`3o
ooooooooo`0Gooooo`?o0?l00oooool00ol0o`3oooooooooo`08ooooo`03o`3o0?oooooooooo00Oo
oooo00?o0?l0ooooooooool00_ooool00ol0o`3oool0oooo000Rooooo`008Oooool01Oooo`3ooooo
oooo0?ooo`3ooooo00;oool000Gooooooooo0?ooooooooooo`3o000=ooooo`;oool00_ooool00ol0
o`3oooooooooo`04ooooo`Coool01oooool00oooo`3oooooooooo`06ooooo`03oooo0?oooooooooo
00Oooooo00?oool0ooooooooool01Oooool00oooo`3oooooooooo`0Mooooo`03o`3o0?oooooooooo
00;ooooo00?oool0ooooooooool00oooool00oooo`3oooooooooo`0Aooooo`03o`3o0?oooooooooo
00Kooooo0_ooo`0:ooooo`;oool07Oooool3o`3o00cooooo0_l0o`07ooooo`03o`3o0?oooooooooo
00;ooooo00?o0?l0oooo0?ooo`008_ooool002;ooooo0oooo`001?ooooooool0oooo0?ooo`02oooo
o`03o`3o0?oooooooooo00Wooooo0oooo`05ooooo`03o`3o0?ooooooool000?oool02oooool00ooo
o`3oooooooooo`06ooooo`03oooo0?oooooooooo00Oooooo00?oool0ooooooooool01Oooool00ooo
o`3oooooooooo`0Looooo`03o`3o0?oooooooooo00?ooooo00?oool0ooooooooool00_ooool00ooo
o`3oooooooooo`0Aooooo`03o`3o0?oooooooooo00Kooooo00?oool0ooooooooool02Oooool00ooo
o`3oooooooooo`0Nooooo`03o`3o0?oooooo0?l000;o0?l02oooool00ol0o`3oooooooooo`04oooo
o`03o`3o0?oooooooooo00;ooooo00?o0?l0oooo0?ooool08_ooool002;ooooo0_ooo`000ooooooo
ool0oooo0002oooo0003ooooool0o`3ooooo00Wooooo0_ooo`07ooooo`?oool04?ooool00oooo`3o
ooooooooo`05ooooo`03oooo0?oooooooooo00Oooooo00?oool0ooooooooool01Oooool00oooo`3o
ooooooooo`0Kooooo`03o`3o0?oooooooooo00?ooooo00?oool0ooooooooool00_ooool00oooo`3o
ooooooooo`0@ooooo`;o0?l02?ooool00oooo`3oooooooooo`08ooooo`;oool08Oooool00ol0o`3o
ooooooooo`02ooooo`?o0?l02Oooool00ol0o`3oooooooooo`04ooooo`04o`3o0?oooooooooooooo
o`;oool08oooool002?ooooo0oooo`001Oooooooool0oooo0?oooooo0?l000Oooooo0oooo`05oooo
o`Coool00_ooool00ol0o`3oooooooooo`0>ooooo`03oooo0?oooooooooo00Gooooo00?oool0oooo
ooooool01oooool00oooo`3oooooooooo`04ooooo`03oooo0?oooooooooo01cooooo00?o0?l0oooo
ooooool00_ooool00oooo`3oooooooooo`03ooooo`03oooo0?oooooooooo00oooooo00?o0?l0oooo
ooooool01oooool00oooo`3oooooooooo`08ooooo`03oooo0?oooooooooo023ooooo00?o0?l0oooo
ooooool01_ooool3o`3o00Oooooo0_l0o`04ooooo`05o`3o0?ooooooooooo`3o0?ooo`009?ooool0
02?ooooo1Oooo`000ooooooo0?l0ooooo`05ooooo`;oool01?ooool4oooo00Oooooo00?o0?l0oooo
ooooool03Oooool00oooo`3oooooooooo`06ooooo`03oooo0?oooooooooo00Kooooo00?oool0oooo
ooooool01?ooool00oooo`3oooooooooo`0Kooooo`03o`3o0?oooooooooo00?ooooo00?oool0oooo
ooooool00_ooool00oooo`3oooooooooo`0?ooooo`03o`3o0?oooooooooo00Kooooo0_ooo`09oooo
o`;oool08_ooool00ol0o`3oooooooooo`0:ooooo`?o0?l01_ooool01Ol0o`3ooooooooooooooooo
0?l000;ooooo00?o0?l0oooo0?ooool08oooool002?ooooo1Oooo`000ol0o`3oooooooooo`02oooo
o`?oool00_ooool4oooo00_ooooo00?o0?l0ooooooooool03_ooool00oooo`3oooooooooo`05oooo
o`03oooo0?oooooooooo00Kooooo00?oool0ooooooooool01?ooool00oooo`3oooooooooo`0Koooo
o`03o`3o0?oooooooooo00;ooooo00?oool0ooooooooool00_ooool00oooo`3oooooooooo`0?oooo
o`03o`3o0?oooooooooo00Kooooo00?oool0ooooooooool02?ooool00oooo`3oooooooooo`0Roooo
o`03o`3o0?oooooooooo00gooooo0ol0o`04ooooo`06o`3o0?ooooooooooooooool0o`3ooooo0_oo
o`0Tooooo`009?ooool3ool00004o`3o0?ooooooooooooooo`;oool000?ooooooooo0?ooo`000_oo
o`0@ooooo`03o`3o0?oooooooooo00gooooo00?oool0ooooooooool01Oooool00oooo`3ooooooooo
o`06ooooo`03oooo0?oooooooooo00Cooooo00?oool0ooooooooool06_ooool00ol0o`3ooooooooo
o`02ooooo`03oooo0?oooooooooo00;ooooo00?oool0ooooooooool03oooool00ol0o`3ooooooooo
o`06ooooo`03oooo0?oooooooooo00Oooooo0_ooo`0Tooooo`03o`3o0?oooooooooo017ooooo0ol0
o`02ooooo`;o0?l00ooo00000oooo`3oooooooooo`0Sooooo`008oooool5ool00003ooooooooo`3o
ool000?oool05Oooool00ol0o`3oooooooooo`0=ooooo`03oooo0?oooooooooo00Cooooo00?oool0
ooooooooool01_ooool00oooo`3oooooooooo`04ooooo`03oooo0?oooooooooo01Wooooo00?o0?l0
ooooooooool00_ooool00oooo`3oooooooooo`02ooooo`03oooo0?oooooooooo00oooooo00?o0?l0
ooooooooool01Oooool2oooo00Wooooo00?oool0ooooooooool08oooool00ol0o`3oooooooooo`0E
ooooo`?o0?l01Ooo000Uooooo`008_ooool7ool000;oool06?ooool00ol0o`3oooooooooo`0=oooo
o`03oooo0?oooooooooo00Cooooo00?oool0ooooooooool01_ooool00oooo`3oooooooooo`04oooo
o`03oooo0?oooooooooo01Wooooo00?o0?l0ooooooooool00_ooool00oooo`3oooooooooo`02oooo
o`03oooo0?oooooooooo00kooooo00?o0?l0ooooooooool01Oooool00oooo`3oooooooooo`07oooo
o`;oool09_ooool00ol0o`3oooooooooo`0Gooooo`Ooo`009?ooool002;ooooo1ooo000Zo`3o0003
oooo0?l0o`3o0?l000Go0?l000?oool0o`3o0?l0o`001_l0o`000oooo`3o0?l0o`3o0003o`3o0003
oooo0?l0o`3o0?l001go0?l000?oool0o`3o0?l0o`000_l0o`000oooo`3o0?l0o`3o000Fo`3o0003
oooo0?l0o`3o0?l000Oo0?l000?oool0o`3o0?l0o`00@?l0o`07ool002Cooooo000Rooooo`Ooo`00
7?ooool00ol0o`3oooooooooo`0<ooooo`03oooo0?oooooooooo00Cooooo00?oool0ooooooooool0
1_ooool00oooo`3oooooooooo`03ooooo`03oooo0?oooooooooo01Sooooo00Go0?l0oooooooooooo
oooooooo0004ooooo`03oooo0?oooooooooo00gooooo00?o0?l0ooooooooool01Oooool2oooo00So
oooo0_ooo`0Wooooo`03o`3o0?oooooooooo01Wooooo1ooo000Tooooo`008oooool5ool001gooooo
00?o0?l0ooooooooool03?ooool00oooo`3oooooooooo`04ooooo`03oooo0?oooooooooo00Kooooo
00?oool0ooooooooool00oooool00oooo`3oooooooooo`0Gooooo`03o`3o0?oooooooooo00;ooooo
00Goool0oooooooooooooooooooo000?ooooo`03o`3o0?oooooooooo00Gooooo00?oool0oooooooo
ool01oooool00oooo`3oooooooooo`0Wooooo`03o`3o0?oooooooooo01[ooooo1Ooo000Uooooo`00
9?ooool3ool001oooooo00?o0?l0ooooooooool03?ooool00oooo`3oooooooooo`03ooooo`03oooo
0?oooooooooo00Kooooo00?oool0ooooooooool00oooool00oooo`3oooooooooo`0Fooooo`03o`3o
0?oooooooooo00;ooooo00?oool0ooooooooool00_ooool00oooo`3oooooooooo`0<ooooo`03o`3o
0?oooooooooo00Gooooo00?oool0ooooooooool01_ooool2oooo02Wooooo00?o0?l0ooooooooool0
7?ooool3ool002Kooooo0017ooooo`03o`3o0?oooooooooo00_ooooo00?oool0ooooooooool01?oo
ool00oooo`3oooooooooo`05ooooo`03oooo0?oooooooooo00?ooooo00?oool0ooooooooool05_oo
ool01Ol0o`3oooooooooooooooooool000Cooooo00?oool0ooooooooool03?ooool00ol0o`3ooooo
ooooo`04ooooo`;oool02?ooool00oooo`3oooooooooo`0Xooooo`03o`3o0?oooooooooo04Kooooo
0018ooooo`03o`3o0?oooooooooo00[ooooo00?oool0ooooooooool01?ooool00oooo`3ooooooooo
o`05ooooo`03oooo0?oooooooooo00?ooooo00?oool0ooooooooool05Oooool00ol0o`3ooooooooo
o`02ooooo`05oooo0?ooooooooooooooooooo`003_ooool00ol0o`3oooooooooo`04ooooo`03oooo
0?oooooooooo00Kooooo0_ooo`0Zooooo`03o`3o0?oooooooooo04Oooooo0018ooooo`03o`3o0?oo
oooooooo00_ooooo00?oool0ooooooooool00oooool00oooo`3oooooooooo`05ooooo`03oooo0?oo
oooooooo00?ooooo00?oool0ooooooooool05Oooool01Ol0o`3oooooooooooooooooool000?ooooo
00?oool0ooooooooool03?ooool00ol0o`3oooooooooo`04ooooo`03oooo0?oooooooooo00Kooooo
00?oool0ooooooooool0:_ooool00ol0o`3oooooooooo`17ooooo`00BOooool00ol0o`3ooooooooo
o`0:ooooo`03oooo0?oooooooooo00?ooooo00?oool0ooooooooool01Oooool00oooo`3ooooooooo
o`03ooooo`03oooo0?oooooooooo01Cooooo00Go0?l0oooooooooooooooooooo0003ooooo`03oooo
0?oooooooooo00_ooooo0_l0o`06ooooo`03oooo0?oooooooooo00Gooooo0_ooo`0/ooooo`03o`3o
0?oooooooooo04Sooooo001:ooooo`03o`3o0?oooooooooo00Wooooo00?oool0ooooooooool01?oo
ool00oooo`3oooooooooo`04ooooo`03oooo0?oooooooooo00?ooooo00?oool0ooooooooool04ooo
ool00ol0o`3oooooooooo`02ooooo`05oooo0?ooooooooooooooooooo`003?ooool00ol0o`3ooooo
ooooo`04ooooo`;oool01oooool00oooo`3oooooooooo`0[ooooo`03o`3o0?oooooooooo04Wooooo
001:ooooo`03o`3o0?oooooooooo00[ooooo00?oool0ooooooooool00oooool00oooo`3ooooooooo
o`04ooooo`03oooo0?oooooooooo00?ooooo00?oool0ooooooooool04oooool01Ol0o`3ooooooooo
ooooooooool000?ooooo00?oool0ooooooooool02_ooool00ol0o`3oooooooooo`04ooooo`03oooo
0?oooooooooo00Gooooo0_ooo`0^ooooo`03o`3o0?oooooooooo04Wooooo001;ooooo`03o`3o0?oo
oooooooo00Wooooo00?oool0ooooooooool00oooool00oooo`3oooooooooo`04ooooo`03oooo0?oo
oooooooo00;ooooo00?oool0ooooooooool04oooool01Ol0o`3oooooooooooooooooool000?ooooo
00?oool0ooooooooool02_ooool00ol0o`3oooooooooo`04ooooo`03oooo0?oooooooooo00Gooooo
00?oool0ooooooooool0;Oooool00ol0o`3oooooooooo`1:ooooo`00C?ooool00ol0o`3ooooooooo
o`09ooooo`03oooo0?oooooooooo00;ooooo00?oool0ooooooooool01?ooool00oooo`3ooooooooo
o`02ooooo`03oooo0?oooooooooo01?ooooo00Co0?l0ooooooooooooool00oooool00oooo`3ooooo
ooooo`0:ooooo`03o`3o0?oooooooooo00?ooooo0_ooo`06ooooo`;oool0;oooool00ol0o`3ooooo
ooooo`1;ooooo`00C?ooool00ol0o`3oooooooooo`09ooooo`03oooo0?oooooooooo00?ooooo00?o
ool0ooooooooool00oooool00oooo`3oooooooooo`02ooooo`03oooo0?oooooooooo01;ooooo00Go
0?l0oooooooooooooooooooo0002ooooo`03oooo0?oooooooooo00[ooooo00?o0?l0ooooooooool0
0oooool00oooo`3oooooooooo`05ooooo`03oooo0?oooooooooo02oooooo00?o0?l0ooooooooool0
Boooool004gooooo00?o0?l0ooooooooool02?ooool00oooo`3oooooooooo`03ooooo`03oooo0?oo
oooooooo00?ooooo00?oool0ooooooooool00_ooool00oooo`3oooooooooo`0Aooooo`05o`3o0?oo
ooooooooooooooooo`000oooool00oooo`3oooooooooo`09ooooo`03o`3o0?oooooooooo00?ooooo
00?oool0ooooooooool01?ooool2oooo037ooooo00?o0?l0ooooooooool0C?ooool004kooooo00?o
0?l0ooooooooool02?ooool00oooo`3oooooooooo`02ooooo`03oooo0?oooooooooo00?ooooo00?o
ool0ooooooooool00_ooool00oooo`3oooooooooo`0Aooooo`04o`3o0?oooooooooooooo00?ooooo
00?oool0ooooooooool02?ooool2o`3o00Cooooo0_ooo`06ooooo`03oooo0?oooooooooo033ooooo
00?o0?l0ooooooooool0COooool004kooooo00?o0?l0ooooooooool02?ooool00oooo`3ooooooooo
o`02ooooo`03oooo0?oooooooooo00Cooooo00Goool0oooooooooooooooooooo000Booooo`05o`3o
0?ooooooooooooooooooo`000_ooool00oooo`3oooooooooo`08ooooo`03o`3o0?oooooooooo00?o
oooo00?oool0ooooooooool01?ooool2oooo03?ooooo00?o0?l0ooooooooool0COooool004oooooo
00?o0?l0ooooooooool02?ooool00oooo`3oooooooooo`02ooooo`03oooo0?oooooooooo00?ooooo
00Goool0oooooooooooooooooooo000Booooo`04o`3o0?oooooooooooooo00;ooooo00?oool0oooo
ooooool02?ooool00ol0o`3oooooooooo`03ooooo`03oooo0?oooooooooo00Cooooo00?oool0oooo
ooooool0<_ooool00ol0o`3oooooooooo`1>ooooo`00D?ooool00ol0o`3oooooooooo`07ooooo`03
oooo0?oooooooooo00;ooooo00?oool0ooooooooool00oooool01Oooo`3oooooooooooooooooool0
017ooooo00Co0?l0ooooooooooooool00_ooool00oooo`3oooooooooo`08ooooo`03o`3o0?oooooo
oooo00;ooooo0_ooo`05ooooo`;oool0=?ooool00ol0o`3oooooooooo`1?ooooo`00DOooool00ol0
o`3oooooooooo`06ooooo`03oooo0?oooooooooo00;ooooo00?oool0ooooooooool00oooool01Ooo
o`3oooooooooooooooooool0013ooooo00Go0?l0oooooooooooooooooooo0002ooooo`03oooo0?oo
oooooooo00Oooooo00?o0?l0ooooooooool00_ooool00oooo`3oooooooooo`04ooooo`03oooo0?oo
oooooooo03?ooooo00?o0?l0ooooooooool0D?ooool0057ooooo00?o0?l0ooooooooool01oooool0
1Oooo`3oooooooooooooooooool000Gooooo00Goool0oooooooooooooooooooo000@ooooo`04o`3o
0?oooooooooooooo00;ooooo00?oool0ooooooooool01oooool00ol0o`3oooooooooo`02ooooo`03
oooo0?oooooooooo00?ooooo0_ooo`0fooooo`03o`3o0?oooooooooo053ooooo001Booooo`03o`3o
0?oooooooooo00Kooooo00?oool0ooooooooool00_ooool00oooo`3oooooooooo`02ooooo`05oooo
0?ooooooooooooooooooo`003oooool01?l0o`3oooooooooooooo`02ooooo`03oooo0?oooooooooo
00Oooooo00?o0?l0ooooooooool00_ooool00oooo`3oooooooooo`02ooooo`;oool0=oooool00ol0
o`3oooooooooo`1Aooooo`00Doooool00ol0o`3oooooooooo`06ooooo`05oooo0?oooooooooooooo
ooooo`001?ooool01Oooo`3oooooooooooooooooool000oooooo00Ko0?l0ooooooooooooool0oooo
ooooo`09ooooo`04o`3o0?ooooooooooooooo`;oool01?ooool00oooo`3oooooooooo`0fooooo`03
o`3o0?oooooooooo05;ooooo001Cooooo`03o`3o0?oooooooooo00Kooooo00Goool0oooooooooooo
oooooooo0004ooooo`05oooo0?ooooooooooooooooooo`003_ooool01?l0o`3oooooooooooooo`02
ooooo`03oooo0?oooooooooo00Gooooo0_l0o`03ooooo`03oooo0?oooooooooo00;ooooo0_ooo`0i
ooooo`03o`3o0?oooooooooo05;ooooo001Dooooo`03o`3o0?oooooooooo00Gooooo00Goool0oooo
oooooooooooooooo0004ooooo`05oooo0?ooooooooooooooooooo`003Oooool01?l0o`3ooooooooo
ooooo`02ooooo`03oooo0?oooooooooo00Gooooo00?o0?l0ooooooooool00_ooool00oooo`3ooooo
ooooo`02ooooo`03oooo0?oooooooooo03Sooooo00?o0?l0ooooooooool0Doooool005Gooooo00?o
0?l0ooooooooool01Oooool01Oooo`3oooooooooooooooooool000?ooooo00Goool0oooooooooooo
oooooooo000=ooooo`03o`3o0?ooooooool000;ooooo00?oool0ooooooooool01Oooool01?l0o`3o
ooooooooooooool2oooo00?ooooo0_ooo`0jooooo`03o`3o0?oooooooooo05Cooooo001Eooooo`03
o`3o0?oooooooooo00Gooooo00Goool0oooooooooooooooooooo0003ooooo`05oooo0?oooooooooo
ooooooooo`003?ooool01_l0o`3oooooooooooooo`3ooooooooo00Oooooo00Go0?l0oooooooooooo
oooooooo0004ooooo`03oooo0?oooooooooo03[ooooo00?o0?l0ooooooooool0E?ooool005Kooooo
00?o0?l0ooooooooool01?ooool01Oooo`3oooooooooooooooooool000?ooooo00Goool0oooooooo
oooooooooooo000<ooooo`05o`3o0?ooooooool0ooooooooo`001oooool01Ol0o`3ooooooooooooo
ooooool000?ooooo0_ooo`0looooo`03o`3o0?oooooooooo05Gooooo001Gooooo`03o`3o0?oooooo
oooo00Cooooo00Coool0ooooooooooooool00oooool01?ooo`3oooooooooooooo`0<ooooo`03o`3o
0?ooooooool000;ooooo00?oool0ooooooooool01?ooool00ol0o`3oooooooooo`02oooo00?ooooo
00?oool0ooooooooool0>oooool00ol0o`3oooooooooo`1Fooooo`00Eoooool00ol0o`3ooooooooo
o`04ooooo`05oooo0?ooooooooooooooooooo`000_ooool01?ooo`3oooooooooooooo`0;ooooo`06
o`3o0?oooooooooooooo0?ooooooool01_ooool01?l0o`3oooooooooooooo`03ooooo`;oool0?_oo
ool00ol0o`3oooooooooo`1Fooooo`00F?ooool00ol0o`3oooooooooo`04ooooo`04oooo0?oooooo
oooooooo00?ooooo00?oool0ooooooooo`002oooool01Ol0o`3ooooooooo0?ooooooool000Gooooo
0_l0o`02ooooo`05oooo0?ooooooooooooooooooo`00?oooool00ol0o`3oooooooooo`1Gooooo`00
FOooool00ol0o`3oooooooooo`03ooooo`04oooo0?oooooooooooooo00?ooooo00?oool0oooooooo
o`002_ooool01Ol0o`3ooooooooo0?ooooooool000Gooooo00?o0?l0ooooooooool00_ooo`02oooo
o`;oool0?oooool00ol0o`3oooooooooo`1Hooooo`00F_ooool00ol0o`3oooooooooo`02ooooo`04
oooo0?oooooooooooooo00?ooooo00?oool0ooooooooo`002_ooool01?l0o`3ooooooooo0?ooo`05
ooooo`04o`3o0?oooooooooooooo00?ooooo00?oool0ooooooooool0?_ooool00ol0o`3ooooooooo
o`1Iooooo`00F_ooool00ol0o`3oooooooooo`03ooooo`04oooo0?oooooooooooooo00;ooooo00?o
ool0ooooooooo`002Oooool01Ol0o`3ooooooooo0?ooooooool000Cooooo00Co0?l0oooooooooooo
ool00_ooool2oooo047ooooo00?o0?l0ooooooooool0FOooool005_ooooo00?o0?l0ooooooooool0
0_ooool01?ooo`3oooooooooooooo`02ooooo`03oooo0?ooooooool000Sooooo00Go0?l0oooooooo
o`3ooooooooo0004ooooo`04o`3o0?oooooooooooooo00;ooooo00?oool0ooooooooool0@?ooool0
0ol0o`3oooooooooo`1Jooooo`00G?ooool00ol0o`3oooooooooo`02ooooo`03oooo0?ooooooool0
00;ooooo00?oool0ooooooooo`002?ooool01?l0o`3oool0ooooooooo`04ooooo`05o`3o0?oooooo
ool0oooo0?ooool00_ooo`12ooooo`03o`3o0?oooooooooo05_ooooo001Looooo`03o`3o0?oooooo
oooo00;ooooo00?oool0ooooooooo`000_ooool00oooo`3ooooooooo0007ooooo`04o`3o0?oooooo
ool0oooo00Cooooo00?o0?l0ooooooooo`000_ooool00oooo`3oooooooooo`12ooooo`03o`3o0?oo
oooooooo05_ooooo001Mooooo`07o`3o0?ooooooooooooooooooo`3ooooooooo0002ooooo`03oooo
0?ooooooool000Oooooo00?o0?l0oooo0?ooo`000oooool2o`3o0003ooooooooo`3ooooo00;oool0
A?ooool00ol0o`3oooooooooo`1Looooo`00G_ooool02ol0o`3oooooooooooooooooool0oooooooo
o`3ooooooooo0?ooooooool000Kooooo00Co0?l0oooo0?ooooooool00_ooool01_l0o`3ooooooooo
0?ooo`3ooooooooo04Gooooo00?o0?l0ooooooooool0GOooool005kooooo00_o0?l0oooooooooooo
oooooooo0?ooooooool0ooooooooo`3ooooooooo0005ooooo`04o`3o0?ooooooool0oooo00;ooooo
00Co0?l0ooooooooo`3ooooo0_ooo`16ooooo`03o`3o0?oooooooooo05gooooo001Oooooo`04o`3o
0?ooooooooooooooo`;oool000Cooooooooo0?ooooooool01Oooool00ol0o`3oool0oooo0002oooo
o`05o`3o0?ooooooool0ooooooooo`00Aoooool00ol0o`3oooooooooo`1Nooooo`00H?ooool00ol0
o`3oooooooooo`02oooo0004ooooooooo`3ooooooooo00Cooooo00?o0?l0oooo0?ooo`000_ooool0
0ol0o`3oool0oooo0002oooo04Oooooo00?o0?l0ooooooooool0Goooool0063ooooo00Go0?l0oooo
ooooooooool0ooooo`02oooo0003ooooooooo`3ooooo00?ooooo00So0?l0oooo0?ooo`3oooooo`3o
0?ooo`3ooooooooo04Wooooo00?o0?l0ooooooooool0Goooool0067ooooo00?o0?l0ooooooooool0
0oooo`000oooooooool0ooooo`02ooooo`05o`3o0?ooo`3oool0ooooool0o`000oooo`19ooooo`03
o`3o0?oooooooooo063ooooo001Rooooo`03o`3o0?ooooooool000?oool00oooool01?l0o`3oool0
oooo0?l0o`03oooo04[ooooo00?o0?l0ooooooooool0HOooool006?ooooo00Go0?l0oooo0?ooo`3o
oooooooo0003ooooo`03o`3o0?ooo`3o0?l000?oool0B_ooool00ol0o`3oooooooooo`1Rooooo`00
Hoooool00ol0o`3ooooooooo0002oooo00;ooooo00?o0?l0oooo0?l0o`000_ooo`1<ooooo`03o`3o
0?oooooooooo06;ooooo001Tooooo`04o`3o0?ooo`3oool0oooo00;ooooo00Coool0o`3o0?ooo`3o
ool0C?ooool00ol0o`3oooooooooo`1Sooooo`00IOooool4o`3o00?oool0B_ooool3ool00003o`3o
0?oooooooooo06Cooooo001Uooooo`Go0?l000?oool0ooooooooool0B?ooool5ool006Kooooo001T
ooooo`Oo0?l0BOooool7ool006Gooooo001Toooooe3o0?l01ooo001Uooooo`00I?ooool7o`3o04Wo
oooo1ooo001Uooooo`00IOooool5o`3o04_ooooo1Ooo001Vooooo`00I_ooool3o`3o04gooooo0ooo
001Wooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0500054, -0.0132976, \
0.00383279, 0.00366225}},
  CellTags->"LocalInteractions:14"]
}, Open  ]],

Cell[BoxData[
    \(DeleteModel[m]\)], "Input",
  CellLabel->"In[8]:=",
  CellTags->"LocalInteractions:14"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 701}},
WindowSize->{520, 578},
WindowMargins->{{Automatic, 111}, {35, Automatic}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Title"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    CellBracketOptions->{"Color"->RGBColor[0.269993, 0.308507, 0.6]},
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowCellBracket->True,
    CellBracketOptions->{"Color"->RGBColor[0.269993, 0.308507, 0.6]},
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    CellBracketOptions->{"Color"->RGBColor[0.269993, 0.308507, 0.6]},
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "SlideShow"],
    PageWidth->WindowWidth,
    ScrollingOptions->{"PagewiseDisplay"->True,
    "VerticalScrollRange"->Fit},
    ShowCellBracket->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}],
  
  Cell[StyleData[All, "EnhancedPrintout"],
    PageWidth->PaperWidth,
    ShowCellBracket->True,
    ScriptMinSize->5,
    FontFamily->"Palatino",
    PrivateFontOptions->{"FontType"->"Outline"}],
  
  Cell[StyleData[All, "EnhancedPrintoutNonGray"],
    PageWidth->PaperWidth,
    ShowCellBracket->False,
    ScriptMinSize->5,
    FontFamily->"Palatino",
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1988-2003 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1988-2003 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None],
  
  Cell[StyleData["Notebook", "Printout"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1988-2003 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1988-2003 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True}],
  
  Cell[StyleData["Notebook", "EnhancedPrintout"],
    PageFooters->{{None, None, None}, {None, None, None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{False, False},
    PrintingOptions->{"PrintingMargins"->{{54, 54}, {36, 72}},
    "PageSize"->{594, 657},
    "PrintRegistrationMarks"->True,
    "FirstPageHeader"->False,
    "FacingPages"->True,
    "FirstPageFace"->Right}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{27, 27}, {10, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Chapter",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Plain",
    FontColor->RGBColor[0.592157, 0.313726, 0.313726]],
  
  Cell[StyleData["Chapter", "Presentation"],
    FontSize->36],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 10}, {6, 30}},
    FontSize->24],
  
  Cell[StyleData["Chapter", "EnhancedPrintout"],
    CellMargins->{{2, 10}, {6, 30}},
    FontFamily->"Frutiger 55 Roman",
    FontSize->24,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Chapter", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 10}, {6, 30}},
    FontFamily->"Frutiger 55 Roman",
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{27, 27}, {9, 30}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold",
    FontColor->RGBColor[0.592157, 0.313726, 0.313726]],
  
  Cell[StyleData["Section", "Presentation"],
    FontSize->30],
  
  Cell[StyleData["Section", "SlideShow"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {5, 0}},
    PageBreakBelow->False,
    CellFrameMargins->{{36, 36}, {Inherited, 15}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.408011, 0.440726, 0.8]],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18],
  
  Cell[StyleData["Section", "EnhancedPrintout"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{2, 2}, {5, 30}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Frutiger 65 Bold",
    FontSize->16,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Section", "EnhancedPrintoutNonGray"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{2, Inherited}, {5, 30}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Frutiger 65 Bold",
    FontSize->16,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->None,
    CellMargins->{{27, 27}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.592157, 0.313726, 0.313726]],
  
  Cell[StyleData["Subsection", "Presentation"],
    FontSize->24],
  
  Cell[StyleData["Subsection", "SlideShow"],
    CellDingbat->None,
    CellMargins->{{70, 0}, {4, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{2, 0}, {5, 24}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {5, 20}},
    FontFamily->"Frutiger 65 Bold",
    FontSize->12,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Subsection", "EnhancedPrintoutNonGray"],
    CellMargins->{{9, 0}, {5, 20}},
    FontFamily->"Frutiger 65 Bold",
    FontSize->12,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{27, 27}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.592157, 0.313726, 0.313726]],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {3, 8}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {3, 8}},
    FontFamily->"Frutiger 65 Bold",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Subsubsection", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {3, 8}},
    FontFamily->"Frutiger 65 Bold",
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{27, 27}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    CellGroupingRules->{"SectionGrouping", 50},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{46, 27}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 40},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    CounterIncrements->"Subsection",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.592157, 0.313726, 0.313726]],
  
  Cell[StyleData["SubsectionIcon", "Presentation"],
    FontSize->24],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{46, 27}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 50},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.592157, 0.313726, 0.313726]],
  
  Cell[StyleData["SubsubsectionIcon", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{27, 27}, {0, 8}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    FontSize->12],
  
  Cell[StyleData["Text", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Text", "SlideShow"],
    CellMargins->{{36, 24}, {4, 4}},
    Hyphenation->False,
    FontSize->14],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    Hyphenation->True,
    FontSize->10],
  
  Cell[StyleData["Text", "EnhancedPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["Text", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{27, 27}, {0, 8}},
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Presentation"],
    FontSize->15],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Hyphenation->True,
    FontSize->8],
  
  Cell[StyleData["CompactText", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->8],
  
  Cell[StyleData["CompactText", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{27, 27}, {0, 8}},
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Hyphenation->True,
    FontSize->10],
  
  Cell[StyleData["Compact12Text", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["Compact12Text", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{27, 27}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Presentation"],
    FontSize->15],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Hyphenation->True,
    FontSize->8],
  
  Cell[StyleData["TextSans", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    Hyphenation->True,
    FontFamily->"Frutiger 55 Roman",
    FontSize->8],
  
  Cell[StyleData["TextSans", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    Hyphenation->True,
    FontFamily->"Frutiger 55 Roman",
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{66, 4}, {4, 4}},
    LineSpacing->{1, 3},
    ParagraphIndent->-22,
    CounterIncrements->"ItemizedText",
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{16, 4}, {2, 4}},
    Hyphenation->True,
    FontSize->10],
  
  Cell[StyleData["ItemizedText", "EnhancedPrintout"],
    CellMargins->{{16, 4}, {2, 4}},
    Hyphenation->True,
    LineSpacing->{1, 1},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ItemizedText", "EnhancedPrintoutNonGray"],
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphIndent->-18,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{88, 4}, {4, 0}},
    LineSpacing->{1, 2},
    CounterIncrements->"ItemizedTextNote",
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{34, 4}, {4, 1}},
    Hyphenation->True,
    FontSize->10],
  
  Cell[StyleData["ItemizedTextNote", "EnhancedPrintout"],
    CellMargins->{{39, 4}, {4, 1}},
    Hyphenation->True,
    LineSpacing->{1, 1},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ItemizedTextNote", "EnhancedPrintoutNonGray"],
    CellMargins->{{39, 4}, {4, 1}},
    Hyphenation->True,
    LineSpacing->{1, 1},
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{66, 4}, {0, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"IndentedText",
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["IndentedText", "SlideShow"],
    CellMargins->{{80, 24}, {5, 5}},
    Hyphenation->False,
    FontSize->13],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{16, 4}, {2, 4}},
    Hyphenation->True,
    FontSize->10],
  
  Cell[StyleData["IndentedText", "EnhancedPrintout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    Hyphenation->True,
    LineSpacing->{1, 1},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["IndentedText", "EnhancedPrintoutNonGray"],
    Hyphenation->True,
    LineSpacing->{1, 1},
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedList"],
    CellMargins->{{58, 4}, {4, 4}},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              StyleBox[ 
                CounterBox[ "ItemizedList"], "TB"], 
              StyleBox[ ".", "TB"]}], CellBaseline -> Baseline, CellSize -> {
            24, Inherited}, TextAlignment -> Right], Inherited}, {
        Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"ItemizedList",
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedList", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemizedList", "Printout"],
    CellMargins->{{9, 4}, {2, 4}},
    Hyphenation->True,
    FontSize->10],
  
  Cell[StyleData["ItemizedList", "EnhancedPrintout"],
    CellMargins->{{9, 4}, {2, 4}},
    Hyphenation->True,
    LineSpacing->{1, 1},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ItemizedList", "EnhancedPrintoutNonGray"],
    Hyphenation->True,
    LineSpacing->{1, 1},
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedSubList"],
    CellMargins->{{92, 4}, {4, 4}},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              StyleBox[ 
                CounterBox[ "ItemizedSubList"], "TB"], 
              StyleBox[ ".", "TB"]}], CellBaseline -> Baseline, CellSize -> {
            24, Inherited}, TextAlignment -> Right], Inherited}, {
        Inherited, Inherited}},
    CounterIncrements->"ItemizedSubList",
    StyleMenuListing->None,
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "a", "z"], #]&)}],
  
  Cell[StyleData["ItemizedSubList", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemizedSubList", "Printout"],
    CellMargins->{{34, 4}, {4, 1}},
    Hyphenation->True,
    FontSize->10],
  
  Cell[StyleData["ItemizedSubList", "EnhancedPrintout"],
    CellMargins->{{26, 4}, {2, 4}},
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ItemizedSubList", "EnhancedPrintoutNonGray"],
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedSubListNote"],
    CellMargins->{{110, 4}, {4, 4}},
    CounterIncrements->"ItemizedSubList",
    StyleMenuListing->None,
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "a", "z"], #]&)}],
  
  Cell[StyleData["ItemizedSubListNote", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemizedSubListNote", "Printout"],
    CellMargins->{{34, 4}, {4, 1}},
    Hyphenation->True,
    FontSize->10],
  
  Cell[StyleData["ItemizedSubListNote", "EnhancedPrintout"],
    CellMargins->{{56, 4}, {2, 4}},
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ItemizedSubListNote", "EnhancedPrintoutNonGray"],
    CellMargins->{{48, 4}, {2, 4}},
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BulletedList"],
    CellMargins->{{76, 4}, {4, 4}},
    CellFrameLabels->{{
      Cell[ "\[Bullet]", "BulletedList", CellBaseline -> Baseline], 
          Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"BulletText",
    StyleMenuListing->None],
  
  Cell[StyleData["BulletedList", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["BulletedList", "Printout"],
    CellMargins->{{16, 4}, {4, 1}},
    Hyphenation->True,
    FontSize->10],
  
  Cell[StyleData["BulletedList", "EnhancedPrintout"],
    CellMargins->{{26, 4}, {2, 4}},
    Hyphenation->True,
    LineSpacing->{1, 1},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["BulletedList", "EnhancedPrintoutNonGray"],
    Hyphenation->True,
    LineSpacing->{1, 1},
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ListNote"],
    CellMargins->{{88, 4}, {4, 0}},
    LineSpacing->{1, 2},
    CounterIncrements->"ListNote",
    StyleMenuListing->None],
  
  Cell[StyleData["ListNote", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ListNote", "Printout"],
    CellMargins->{{34, 4}, {4, 1}},
    Hyphenation->True,
    FontSize->10],
  
  Cell[StyleData["ListNote", "EnhancedPrintout"],
    CellMargins->{{39, 4}, {4, 1}},
    Hyphenation->True,
    LineSpacing->{1, 1},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ListNote", "EnhancedPrintoutNonGray"],
    CellMargins->{{39, 4}, {4, 1}},
    Hyphenation->True,
    LineSpacing->{1, 1},
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{66, 12}, {2, 20}},
    PageBreakBelow->False,
    CellFrameMargins->{{8, 8}, {8, 2}},
    CellFrameColor->GrayLevel[0.700008],
    CellFrameLabelMargins->4,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->GrayLevel[0.2]],
  
  Cell[StyleData["MathCaption", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MathCaption", "SlideShow"],
    ShowCellBracket->False,
    CellMargins->{{36, 36}, {6, 6}}],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    Hyphenation->True,
    FontSize->9,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["MathCaption", "EnhancedPrintout"],
    CellMargins->{{9, 0}, {0, 14}},
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->9,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["MathCaption", "EnhancedPrintoutNonGray"],
    CellMargins->{{9, 0}, {0, 14}},
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{27, 27}, {0, 8}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->1,
    Hyphenation->True,
    FontSize->7],
  
  Cell[StyleData["SmallText", "EnhancedPrintout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->7],
  
  Cell[StyleData["SmallText", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Input", "SlideShow"],
    ShowCellBracket->True,
    CellMargins->{{100, 50}, {0, 6}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellFrameMargins->{{8, 8}, {4, 8}},
    Background->RGBColor[1, 1, 0.8]],
  
  Cell[StyleData["Input", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9],
  
  Cell[StyleData["Input", "EnhancedPrintout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9],
  
  Cell[StyleData["Input", "EnhancedPrintoutNonGray"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Output", "SlideShow"],
    ShowCellBracket->True,
    CellMargins->{{100, 50}, {6, 0}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellFrameMargins->{{8, 8}, {8, 4}},
    Background->RGBColor[1, 1, 0.8]],
  
  Cell[StyleData["Output", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9],
  
  Cell[StyleData["Output", "EnhancedPrintout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9],
  
  Cell[StyleData["Output", "EnhancedPrintoutNonGray"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InputOnly"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["InputOnly", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["InputOnly", "SlideShow"],
    ShowCellBracket->True,
    CellMargins->{{100, 50}, {6, 6}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    Background->RGBColor[1, 1, 0.8]],
  
  Cell[StyleData["InputOnly", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9],
  
  Cell[StyleData["InputOnly", "EnhancedPrintout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9],
  
  Cell[StyleData["InputOnly", "EnhancedPrintoutNonGray"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    AutoStyleOptions->{"UnmatchedBracketStyle"->None},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0.6, 0.100008, 0.100008]],
  
  Cell[StyleData["Message", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Message", "SlideShow"],
    CellMargins->{{100, 50}, {6, 6}},
    FontSize->10,
    FontColor->RGBColor[0.699992, 0.4, 0]],
  
  Cell[StyleData["Message", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->9,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Message", "EnhancedPrintout"],
    ShowCellBracket->False,
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontFamily->"Courier",
    FontSize->9,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Message", "EnhancedPrintoutNonGray"],
    ShowCellBracket->False,
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontFamily->"Courier",
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Print", "SlideShow"],
    CellMargins->{{100, 50}, {6, 6}}],
  
  Cell[StyleData["Print", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{57, Inherited}, {Inherited, Inherited}},
    FontSize->9],
  
  Cell[StyleData["Print", "EnhancedPrintout"],
    ShowCellBracket->False,
    CellMargins->{{57, Inherited}, {Inherited, Inherited}},
    FontFamily->"Courier Std",
    FontSize->9],
  
  Cell[StyleData["Print", "EnhancedPrintoutNonGray"],
    ShowCellBracket->False,
    CellMargins->{{57, Inherited}, {Inherited, Inherited}},
    FontFamily->"Courier Std",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultFormatTypeForOutput,
    LanguageCategory->None,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Graphics", "SlideShow"],
    ShowCellBracket->True,
    CellMargins->{{100, 50}, {6, 0}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellFrameMargins->{{8, 8}, {4, 4}},
    Background->RGBColor[1, 1, 0.8]],
  
  Cell[StyleData["Graphics", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250},
    FontSize->9],
  
  Cell[StyleData["Graphics", "EnhancedPrintout"],
    ShowCellBracket->False,
    CellMargins->{{32, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250},
    FontFamily->"Courier Std",
    FontSize->9],
  
  Cell[StyleData["Graphics", "EnhancedPrintoutNonGray"],
    ShowCellBracket->False,
    CellMargins->{{32, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250},
    FontFamily->"Courier Std",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0.269993, 0.308507, 0.6]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["CellLabel", "SlideShow"],
    FontColor->RGBColor[0.699992, 0.4, 0]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "EnhancedPrintout"],
    FontFamily->"Courier Std",
    FontSize->8,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "EnhancedPrintoutNonGray"],
    FontFamily->"Courier Std",
    FontSize->8,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0.269993, 0.308507, 0.6]],
  
  Cell[StyleData["Name", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Name", "EnhancedPrintout"],
    FontFamily->"Frutiger 56 Italic",
    FontSize->7,
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Name", "EnhancedPrintoutNonGray"],
    FontFamily->"Frutiger 56 Italic",
    FontSize->7,
    FontSlant->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Hyperlink", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Hyperlink", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLink", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLink", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLinkMR", "EnhancedPrintout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLinkMR", "EnhancedPrintoutNonGray"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLink", "EnhancedPrintout"],
    FontFamily->"WRICourier",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLink", "EnhancedPrintoutNonGray"],
    FontFamily->"WRICourier",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLinkText"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLinkText", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLinkText", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLinkText", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["RefGuideLink", "EnhancedPrintout"],
    FontFamily->"WRICourier",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["RefGuideLink", "EnhancedPrintoutNonGray"],
    FontFamily->"WRICourier",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["GettingStartedLink", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["GettingStartedLink", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DemosLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Demos", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["DemosLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["DemosLink", "EnhancedPrintout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["DemosLink", "EnhancedPrintoutNonGray"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TourLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Tour", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["TourLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["TourLink", "EnhancedPrintout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["TourLink", "EnhancedPrintoutNonGray"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLink", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLink", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLinkMR", "EnhancedPrintout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLinkMR", "EnhancedPrintoutNonGray"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MasterIndexLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MasterIndex", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MasterIndexLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MasterIndexLink", "EnhancedPrintout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MasterIndexLink", "EnhancedPrintoutNonGray"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotebookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["NotebookLink", "Printout"],
    FontSize->11,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["NotebookLink", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["NotebookLink", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino",
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotebookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["NotebookLinkMR", "Printout"],
    FontSize->11,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["NotebookLinkMR", "EnhancedPrintout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["NotebookLinkMR", "EnhancedPrintoutNonGray"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JT", "Printout"]],
  
  Cell[StyleData["JT", "EnhancedPrintout"]],
  
  Cell[StyleData["JT", "EnhancedPrintoutNonGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JS", "Printout"]],
  
  Cell[StyleData["JS", "EnhancedPrintout"]],
  
  Cell[StyleData["JS", "EnhancedPrintoutNonGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["JSB", "Printout"]],
  
  Cell[StyleData["JSB", "EnhancedPrintout"]],
  
  Cell[StyleData["JSB", "EnhancedPrintoutNonGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["RM", "Printout"]],
  
  Cell[StyleData["RM", "EnhancedPrintout"]],
  
  Cell[StyleData["RM", "EnhancedPrintoutNonGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["BF", "Printout"]],
  
  Cell[StyleData["BF", "EnhancedPrintout"]],
  
  Cell[StyleData["BF", "EnhancedPrintoutNonGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["IT", "Printout"]],
  
  Cell[StyleData["IT", "EnhancedPrintout"]],
  
  Cell[StyleData["IT", "EnhancedPrintoutNonGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TR", "Printout"]],
  
  Cell[StyleData["TR", "EnhancedPrintout"],
    FontFamily->"Palatino"],
  
  Cell[StyleData["TR", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSlant->"Italic"],
  
  Cell[StyleData["TI", "Printout"]],
  
  Cell[StyleData["TI", "EnhancedPrintout"],
    FontFamily->"Palatino"],
  
  Cell[StyleData["TI", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TB", "Printout"]],
  
  Cell[StyleData["TB", "EnhancedPrintout"],
    FontFamily->"Palatino"],
  
  Cell[StyleData["TB", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["TBI", "Printout"]],
  
  Cell[StyleData["TBI", "EnhancedPrintout"],
    FontFamily->"Palatino"],
  
  Cell[StyleData["TBI", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MR"],
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MR", "Printout"]],
  
  Cell[StyleData["MR", "EnhancedPrintout"],
    FontFamily->"Courier Std"],
  
  Cell[StyleData["MR", "EnhancedPrintoutNonGray"],
    FontFamily->"Courier Std"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MO"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MO", "Printout"],
    FontSlant->"Oblique"],
  
  Cell[StyleData["MO", "EnhancedPrintout"],
    FontFamily->"Courier Std",
    FontSlant->"Oblique"],
  
  Cell[StyleData["MO", "EnhancedPrintoutNonGray"],
    FontFamily->"Courier Std",
    FontSlant->"Oblique"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MB"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MB", "Printout"]],
  
  Cell[StyleData["MB", "EnhancedPrintout"],
    FontFamily->"Courier Std"],
  
  Cell[StyleData["MB", "EnhancedPrintoutNonGray"],
    FontFamily->"Courier Std"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MBO"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MBO", "Printout"],
    FontSlant->"Oblique"],
  
  Cell[StyleData["MBO", "EnhancedPrintout"],
    FontFamily->"Courier Std",
    FontSlant->"Oblique"],
  
  Cell[StyleData["MBO", "EnhancedPrintoutNonGray"],
    FontFamily->"Courier Std",
    FontSlant->"Oblique"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SR", "Printout"]],
  
  Cell[StyleData["SR", "EnhancedPrintout"],
    FontFamily->"Frutiger 55 Roman"],
  
  Cell[StyleData["SR", "EnhancedPrintoutNonGray"],
    FontFamily->"Frutiger 55 Roman"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO", "EnhancedPrintout"],
    FontFamily->"Frutiger 56 Italic",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO", "EnhancedPrintoutNonGray"],
    FontFamily->"Frutiger 56 Italic",
    FontSlant->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SB", "Printout"],
    StyleMenuListing->None],
  
  Cell[StyleData["SB", "EnhancedPrintout"],
    FontFamily->"Frutiger 65 Bold",
    FontWeight->"Plain"],
  
  Cell[StyleData["SB", "EnhancedPrintoutNonGray"],
    FontFamily->"Frutiger 65 Bold",
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SBColor"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBColor", "Printout"],
    StyleMenuListing->None],
  
  Cell[StyleData["SBColor", "EnhancedPrintout"],
    FontFamily->"Frutiger 65 Bold",
    FontWeight->"Plain"],
  
  Cell[StyleData["SBColor", "EnhancedPrintoutNonGray"],
    FontFamily->"Frutiger 65 Bold",
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SBO", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SBO", "EnhancedPrintout"],
    FontFamily->"Frutiger 66 BoldItalic",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO", "EnhancedPrintoutNonGray"],
    FontFamily->"Frutiger 66 BoldItalic",
    FontWeight->"Plain",
    FontSlant->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Mathematica4",
    CharacterEncoding->"Mathematica4"],
  
  Cell[StyleData["M4", "Printout"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Mathematica4",
    CharacterEncoding->"Mathematica4"],
  
  Cell[StyleData["M4", "EnhancedPrintout"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Mathematica4",
    CharacterEncoding->"Mathematica4"],
  
  Cell[StyleData["M4", "EnhancedPrintoutNonGray"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Mathematica4",
    CharacterEncoding->"Mathematica4"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "EnhancedPrintout"],
    StyleMenuListing->None,
    FontFamily->"Frutiger 56 Italic",
    FontSize->8,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO10", "EnhancedPrintoutNonGray"],
    StyleMenuListing->None,
    FontFamily->"Frutiger 56 Italic",
    FontSize->8,
    FontWeight->"Plain",
    FontSlant->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["S9"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain"],
  
  Cell[StyleData["S9", "Printout"],
    FontSize->9,
    FontWeight->"Plain"],
  
  Cell[StyleData["S9", "EnhancedPrintout"],
    FontFamily->"Frutiger 55 Roman",
    FontSize->9,
    FontWeight->"Plain"],
  
  Cell[StyleData["S9", "EnhancedPrintoutNonGray"],
    FontFamily->"Frutiger 55 Roman",
    FontSize->9,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["S10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain"],
  
  Cell[StyleData["S10", "Printout"],
    FontSize->10,
    FontWeight->"Plain"],
  
  Cell[StyleData["S10", "EnhancedPrintout"],
    FontFamily->"Frutiger 55 Roman",
    FontSize->10,
    FontWeight->"Plain"],
  
  Cell[StyleData["S10", "EnhancedPrintoutNonGray"],
    FontFamily->"Frutiger 55 Roman",
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SB9"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold",
    PrivateFontOptions->{"OperatorSubstitution"->False}],
  
  Cell[StyleData["SB9", "Printout"],
    FontSize->7],
  
  Cell[StyleData["SB9", "EnhancedPrintout"],
    FontFamily->"Frutiger 65 Bold",
    FontSize->7,
    FontWeight->"Plain"],
  
  Cell[StyleData["SB9", "EnhancedPrintoutNonGray"],
    FontFamily->"Frutiger 65 Bold",
    FontSize->7,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SB10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["SB10", "Printout"],
    FontSize->8],
  
  Cell[StyleData["SB10", "EnhancedPrintout"],
    FontFamily->"Frutiger 65 Bold",
    FontSize->8,
    FontWeight->"Plain"],
  
  Cell[StyleData["SB10", "EnhancedPrintoutNonGray"],
    FontFamily->"Frutiger 65 Bold",
    FontSize->8,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MR10"],
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    SingleLetterItalics->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MR10", "Printout"],
    FontSize->7],
  
  Cell[StyleData["MR10", "EnhancedPrintout"],
    FontFamily->"Courier Std",
    FontSize->7],
  
  Cell[StyleData["MR10", "EnhancedPrintoutNonGray"],
    FontFamily->"Courier Std",
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["C1", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["C1", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino",
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["C1MR", "EnhancedPrintout"],
    FontFamily->"Courier Std",
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["C1MR", "EnhancedPrintoutNonGray"],
    FontFamily->"Courier Std",
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallCaps"],
    StyleMenuListing->None,
    Magnification->0.8],
  
  Cell[StyleData["SmallCaps", "Printout"]],
  
  Cell[StyleData["SmallCaps", "EnhancedPrintout"],
    FontFamily->"Palatino"],
  
  Cell[StyleData["SmallCaps", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["KeyboardChars"],
    StyleMenuListing->None,
    FontSize->12],
  
  Cell[StyleData["KeyboardChars", "Printout"],
    FontSize->10],
  
  Cell[StyleData["KeyboardChars", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["KeyboardChars", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Box", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Box", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["DoubleBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["DoubleBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["1ColumnBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["1ColumnBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    SingleLetterItalics->False,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.31, 0.67}}],
  
  Cell[StyleData["2ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->9,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->9,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->9,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnEvenBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnEvenBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnSmallBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnSmallBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.32}],
  
  Cell[StyleData["3ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["3ColumnBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["3ColumnBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["3ColumnSmallBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["3ColumnSmallBox", "EnhancedPrintoutNonGray"],
    CellFrame->0.5,
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    SingleLetterItalics->False,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.13, 0.35, 0.13, 0.35}}],
  
  Cell[StyleData["4ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["4ColumnBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["4ColumnBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.202}],
  
  Cell[StyleData["5ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->9,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["5ColumnBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->9,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["5ColumnBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->9,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["6ColumnBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["6ColumnBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FramedBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["FramedBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["FramedBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["FramedBox", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["FramedBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 4}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 4}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox3Col", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox3Col", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 4}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox4Col", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox4Col", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 4}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox5Col", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox5Col", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 4}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox6Col", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox6Col", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 4}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["TopBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Palatino",
    Background->GrayLevel[1]],
  
  Cell[StyleData["TopBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Palatino",
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{27, 12}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 2}},
    CellFrameColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["MiddleBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 4}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Palatino",
    Background->GrayLevel[1]],
  
  Cell[StyleData["MiddleBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 4}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Palatino",
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{27, 12}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 0}, {0, -5}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->2.2}],
  
  Cell[StyleData["BottomBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, -5}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->2.2}],
  
  Cell[StyleData["BottomBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, -5}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->2.2}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{27, 12}, {-2, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {-2, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["TopSpanBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {-4, 8}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["TopSpanBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {-4, 8}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{27, 12}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 0}, {-5, 0}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}],
  
  Cell[StyleData["MiddleSpanBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {-7, 0}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}],
  
  Cell[StyleData["MiddleSpanBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {-7, 0}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{27, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.65],
  
  Cell[StyleData["Picture", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.65],
  
  Cell[StyleData["Picture", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.65]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OpenCloseItemizedPicture"],
    CellMargins->{{88, 4}, {4, 4}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["OpenCloseItemizedPicture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["OpenCloseItemizedPicture", "Printout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False],
  
  Cell[StyleData["OpenCloseItemizedPicture", "EnhancedPrintout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False],
  
  Cell[StyleData["OpenCloseItemizedPicture", "EnhancedPrintoutNonGray"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{88, 4}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{77, 2}, {4, -4}},
    Magnification->0.5],
  
  Cell[StyleData["ItemizedPicture", "EnhancedPrintout"],
    CellMargins->{{78, 2}, {12, -6}},
    Magnification->0.5],
  
  Cell[StyleData["ItemizedPicture", "EnhancedPrintoutNonGray"],
    CellMargins->{{75, 2}, {4, -6}},
    Magnification->0.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ListGraphic"],
    CellMargins->{{88, 4}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ListGraphic", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ListGraphic", "Printout"],
    CellMargins->{{77, 2}, {4, -4}},
    Magnification->0.5],
  
  Cell[StyleData["ListGraphic", "EnhancedPrintout"],
    CellMargins->{{78, 2}, {12, -6}},
    Magnification->0.5],
  
  Cell[StyleData["ListGraphic", "EnhancedPrintoutNonGray"],
    CellMargins->{{75, 2}, {4, -6}},
    Magnification->0.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ListNoteBox"],
    CellFrame->0.5,
    CellMargins->{{88, 12}, {8, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ListNoteBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ListNoteBox", "Printout"],
    CellMargins->{{77, 4}, {6, 2}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["ListNoteBox", "EnhancedPrintout"],
    CellMargins->{{39, 4}, {6, 2}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["ListNoteBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{77, 4}, {6, 2}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{41, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False],
  
  Cell[StyleData["PictureGroup", "EnhancedPrintout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False],
  
  Cell[StyleData["PictureGroup", "EnhancedPrintoutNonGray"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{27, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["Sound", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["Sound", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{27, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 4}, {2, 0}},
    FontSize->7],
  
  Cell[StyleData["Caption", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {2, 2}},
    FontFamily->"Frutiger 55 Roman",
    FontSize->7],
  
  Cell[StyleData["Caption", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 4}, {2, -2}},
    FontFamily->"Frutiger 55 Roman",
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9],
  
  Cell[StyleData["2ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9],
  
  Cell[StyleData["2ColumnTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9],
  
  Cell[StyleData["2ColumnEvenTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9],
  
  Cell[StyleData["2ColumnEvenTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9],
  
  Cell[StyleData["3ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9],
  
  Cell[StyleData["3ColumnTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{27, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["InlineFormula", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["InlineFormula", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{27, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5],
  
  Cell[StyleData["InlineOutput", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5],
  
  Cell[StyleData["InlineOutput", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{66, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DisplayFormula", "Printout"]],
  
  Cell[StyleData["DisplayFormula", "EnhancedPrintout"],
    FontFamily->"Palatino"],
  
  Cell[StyleData["DisplayFormula", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{66, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9],
  
  Cell[StyleData["DisplayMath", "EnhancedPrintout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontFamily->"WRICourier",
    FontSize->9],
  
  Cell[StyleData["DisplayMath", "EnhancedPrintoutNonGray"],
    CellMargins->{{39, 0}, {4, 6}},
    FontFamily->"WRICourier",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{66, 27}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{39, 55}, {0, 10}},
    FontSize->10],
  
  Cell[StyleData["NumberedEquation", "EnhancedPrintout"],
    CellMargins->{{39, 55}, {0, 10}},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["NumberedEquation", "EnhancedPrintoutNonGray"],
    CellMargins->{{39, 55}, {0, 10}},
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    CellMargins->{{66, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0}],
  
  Cell[StyleData["EquationNumber", "EnhancedPrintout"],
    LineSpacing->{1.7, 0},
    FontFamily->"Palatino"],
  
  Cell[StyleData["EquationNumber", "EnhancedPrintoutNonGray"],
    LineSpacing->{1.7, 0},
    FontFamily->"Palatino"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{66, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    ShowSpecialCharacters->Automatic,
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{42, 30}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "EnhancedPrintout"],
    CellMargins->{{42, 30}, {Inherited, 4}},
    FontFamily->"WRICourier",
    FontSize->9.5],
  
  Cell[StyleData["Program", "EnhancedPrintoutNonGray"],
    CellMargins->{{42, 30}, {Inherited, 4}},
    FontFamily->"WRICourier",
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell["\<\
Standard Styles
\
\>", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{27, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphIndent->-38,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Presentation"],
    FontSize->24],
  
  Cell[StyleData["InspectorLevel1", "SlideShow"],
    HyphenationOptions->{"HyphenationCharacter"->"-"}],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{27, 4}, {0, 14}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Presentation"],
    FontSize->21],
  
  Cell[StyleData["InspectorLevel2", "SlideShow"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{0, 0}, {0, 0}},
    CellGroupingRules->{"SectionGrouping", 50},
    CellFrameMargins->{{27, 12}, {3, 15}},
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold",
    Background->RGBColor[0.960784, 0.878431, 0.666667]],
  
  Cell[StyleData["ObjectName", "Presentation"],
    FontSize->24],
  
  Cell[StyleData["ObjectName", "SlideShow"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{0, 0}, {0, 10}},
    CellFrameMargins->{{24, 8}, {Inherited, Inherited}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{27, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Presentation"],
    FontSize->21],
  
  Cell[StyleData["SubObjectNameClosed", "SlideShow"],
    CellMargins->{{72, 4}, {1, 14}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{27, 4}, {1, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Presentation"],
    FontSize->24],
  
  Cell[StyleData["SubObjectName", "SlideShow"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{27, 4}, {0, 14}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Presentation"],
    FontSize->24],
  
  Cell[StyleData["GroupObjectName", "SlideShow"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{27, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Presentation"],
    FontSize->24],
  
  Cell[StyleData["GroupObjectNameClosed", "SlideShow"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{27, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Presentation"],
    FontSize->24],
  
  Cell[StyleData["ObjectNameWarningMessages", "SlideShow"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{0, 0}, {0, 0}},
    CellFrameMargins->{{27, 12}, {3, 15}},
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold",
    Background->RGBColor[0.960784, 0.878431, 0.666667]],
  
  Cell[StyleData["Command", "Presentation"],
    FontSize->24],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{0, 0}, {0, 14}},
    PageBreakBelow->False,
    CellFrameMargins->{{24, 8}, {Inherited, Inherited}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{0, 0}, {0, 0}},
    CellFrameMargins->{{27, 27}, {8, 8}},
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216]],
  
  Cell[StyleData["CharacterName", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["CharacterName", "SlideShow"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{0, 0}, {0, 0}},
    CellFrameMargins->{{27, 27}, {8, 8}},
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    Hyphenation->False,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216]],
  
  Cell[StyleData["Usage", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Usage", "SlideShow"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    CellFrameMargins->{{24, 8}, {Inherited, Inherited}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{27, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ErrorMessage", "SlideShow"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{27, 27}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Notes", "SlideShow"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{24, 0}, {0, 8}},
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["NotesList", "SlideShow"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ReferenceSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{27, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 30},
    CellFrameMargins->12,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  
  Cell[StyleData["ReferenceSection", "Presentation"],
    FontSize->20],
  
  Cell[StyleData["ReferenceSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{27, 27}, {0, 8}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Reference",
    FontSize->12],
  
  Cell[StyleData["Reference", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Reference", "SlideShow"],
    CellMargins->{{27, 27}, {4, 4}},
    Hyphenation->False,
    FontSize->14],
  
  Cell[StyleData["Reference", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    Hyphenation->True,
    FontSize->10],
  
  Cell[StyleData["Reference", "EnhancedPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["Reference", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{27, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSection", "Presentation"],
    FontSize->20],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{27, 40}, {0, 18}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{27, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Presentation"],
    FontSize->15],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MessagesSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{27, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  
  Cell[StyleData["MessagesSection", "Presentation"],
    FontSize->20],
  
  Cell[StyleData["MessagesSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TemplateSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{27, 4}, {0, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->True},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  
  Cell[StyleData["TemplateSection", "Presentation"],
    FontSize->20],
  
  Cell[StyleData["TemplateSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{27, 4}, {8, 18}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{27, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{27, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{27, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Presentation"],
    FontSize->15],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{27, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None],
  
  Cell[StyleData["GroupDivider", "Presentation"],
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellFrame->0.5,
    CellMargins->{{27, 4}, {0, 18}},
    CellFrameColor->GrayLevel[0.800015],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.950011]],
  
  Cell[StyleData["Highlight", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{27, 4}, {0, 8}},
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Presentation"],
    FontSize->15],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    LineSpacing->{1, 3},
    FontSize->8],
  
  Cell[StyleData["UserNotes", "EnhancedPrintout"],
    CellMargins->{{0, 0}, {0, 4}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    FontFamily->"Frutiger 55 Roman",
    FontSize->8],
  
  Cell[StyleData["UserNotes", "EnhancedPrintoutNonGray"],
    CellMargins->{{0, 0}, {0, 4}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    FontFamily->"Frutiger 55 Roman",
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    Background->RGBColor[0.964706, 0.929412, 0.839216]],
  
  Cell[StyleData["MoreInfo", "Presentation"],
    FontSize->15],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    Background->RGBColor[0.964706, 0.929412, 0.839216]],
  
  Cell[StyleData["UserTips", "Presentation"],
    FontSize->15],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    CellFrameColor->GrayLevel[0.800015],
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["UserTips", "EnhancedPrintout"],
    CellMargins->{{0, 0}, {0, 4}},
    CellFrameColor->GrayLevel[0],
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    LineSpacing->{1, 3},
    FontFamily->"Frutiger 55 Roman",
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{27, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    LineSpacing->{1, 3},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{36, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10],
  
  Cell[StyleData["Commentary", "EnhancedPrintout"],
    CellMargins->{{36, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["Commentary", "EnhancedPrintoutNonGray"],
    CellMargins->{{36, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CopyrightHead"],
    CellMargins->{{27, 4}, {0, 8}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CopyrightHead", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["CopyrightHead", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    CellMargins->{{27, 4}, {0, 8}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Copyright", "Presentation"],
    FontSize->15],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontSize->8],
  
  Cell[StyleData["Copyright", "EnhancedPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontFamily->"Frutiger 55 Roman",
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RegisterSubsection"],
    CellDingbat->None,
    CellMargins->{{27, 27}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    CellGroupingRules->{"SectionGrouping", 45},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    FontFamily->"Helvetica",
    FontSize->16],
  
  Cell[StyleData["RegisterSubsection", "Presentation"],
    FontSize->24],
  
  Cell[StyleData["RegisterSubsection", "SlideShow"],
    CellDingbat->None,
    CellMargins->{{70, 0}, {4, 12}},
    FontSize->12],
  
  Cell[StyleData["RegisterSubsection", "Printout"],
    CellMargins->{{9, 0}, {5, 24}},
    FontSize->12],
  
  Cell[StyleData["RegisterSubsection", "EnhancedPrintout"],
    CellMargins->{{9, 0}, {5, 20}},
    FontFamily->"Frutiger 55 Roman",
    FontSize->12],
  
  Cell[StyleData["RegisterSubsection", "EnhancedPrintoutNonGray"],
    CellMargins->{{9, 0}, {5, 20}},
    FontFamily->"Frutiger 55 Roman",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RegisterSubsubsection"],
    CellMargins->{{27, 27}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    CellGroupingRules->{"SectionGrouping", 50},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->RGBColor[0.592157, 0.313726, 0.313726]],
  
  Cell[StyleData["RegisterSubsubsection", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["RegisterSubsubsection", "Printout"],
    CellMargins->{{2, 0}, {3, 8}},
    FontSize->10],
  
  Cell[StyleData["RegisterSubsubsection", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {3, 8}},
    FontFamily->"Frutiger 65 Bold",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["RegisterSubsubsection", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {3, 8}},
    FontFamily->"Frutiger 65 Bold",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RegisterText"],
    CellMargins->{{27, 4}, {0, 8}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["RegisterText", "Presentation"],
    FontSize->15],
  
  Cell[StyleData["RegisterText", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontSize->8],
  
  Cell[StyleData["RegisterText", "EnhancedPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CaptionHead"],
    CellMargins->{{27, 4}, {0, 8}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CaptionHead", "Presentation"],
    FontSize->15],
  
  Cell[StyleData["CaptionHead", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontSize->8],
  
  Cell[StyleData["CaptionHead", "EnhancedPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CaptionText"],
    CellMargins->{{66, 4}, {0, 8}},
    PageBreakAbove->False,
    StyleMenuListing->None],
  
  Cell[StyleData["CaptionText", "Presentation"],
    FontSize->15],
  
  Cell[StyleData["CaptionText", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontSize->8],
  
  Cell[StyleData["CaptionText", "EnhancedPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BulletText"],
    CellMargins->{{76, 4}, {4, 4}},
    CellFrameLabels->{{
      Cell[ "\[Bullet]", "BulletText", CellBaseline -> Baseline], 
          Inherited}, {Inherited, Inherited}},
    Hyphenation->False,
    LineSpacing->{1, 3},
    CounterIncrements->"BulletText",
    StyleMenuListing->None],
  
  Cell[StyleData["BulletText", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["BulletText", "Printout"],
    FontSize->10],
  
  Cell[StyleData["BulletText", "EnhancedPrintout"],
    CellMargins->{{16, 4}, {2, 4}},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["BulletText", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["HelpLabels"],
    CellMargins->{{88, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["HelpLabels", "Presentation"],
    FontSize->15],
  
  Cell[StyleData["HelpLabels", "Printout"],
    CellMargins->{{34, 2}, {6, 6}},
    FontSize->10],
  
  Cell[StyleData["HelpLabels", "EnhancedPrintout"],
    CellMargins->{{34, 2}, {6, 6}},
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Manual.nb Merge", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell["Function List", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FunctionName"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 10}, {10, 12}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold",
    CellTags->"FunctionName"],
  
  Cell[StyleData["FunctionName", "Presentation"],
    FontSize->21],
  
  Cell[StyleData["FunctionName", "Printout"],
    CellMargins->{{9, 0}, {10, 10}},
    FontSize->12],
  
  Cell[StyleData["FunctionName", "EnhancedPrintout"],
    CellMargins->{{9, 0}, {10, 10}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["FunctionName", "EnhancedPrintoutNonGray"],
    CellMargins->{{9, 0}, {10, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FunctionSubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{36, 10}, {0, 6}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    StyleMenuListing->None,
    FontWeight->"Bold",
    CellTags->"FunctionSubsection"],
  
  Cell[StyleData["FunctionSubsection", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["FunctionSubsection", "Printout"],
    CellMargins->{{30, 0}, {0, 6}}],
  
  Cell[StyleData["FunctionSubsection", "EnhancedPrintout"],
    CellMargins->{{30, 0}, {0, 6}},
    FontFamily->"Palatino",
    FontSize->11],
  
  Cell[StyleData["FunctionSubsection", "EnhancedPrintoutNonGray"],
    CellMargins->{{30, 0}, {0, 6}},
    FontFamily->"Palatino",
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FunctionDescription"],
    CellMargins->{{36, 10}, {4, 0}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"FunctionDescription",
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["FunctionDescription", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["FunctionDescription", "Printout"],
    CellMargins->{{30, 0}, {4, 0}},
    FontSize->11],
  
  Cell[StyleData["FunctionDescription", "EnhancedPrintout"],
    CellMargins->{{30, 0}, {4, 0}},
    TextJustification->0,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["FunctionDescription", "EnhancedPrintoutNonGray"],
    CellMargins->{{30, 0}, {4, 0}},
    TextJustification->0,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FunctionDescriptionRuled"],
    CellFrame->{{0, 0}, {0.25, 0.25}},
    CellMargins->{{36, 10}, {4, 0}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"FunctionDescriptionRuled",
    StyleMenuListing->None],
  
  Cell[StyleData["FunctionDescriptionRuled", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["FunctionDescriptionRuled", "Printout"],
    CellMargins->{{30, 0}, {4, 0}},
    FontSize->11],
  
  Cell[StyleData["FunctionDescriptionRuled", "EnhancedPrintout"],
    CellMargins->{{30, 0}, {4, 0}},
    TextJustification->0,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["FunctionDescriptionRuled", "EnhancedPrintoutNonGray"],
    CellMargins->{{30, 0}, {4, 0}},
    TextJustification->0,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FunctionDescriptionRuleTop"],
    CellFrame->{{0, 0}, {0, 0.25}},
    CellMargins->{{36, 10}, {4, 0}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"FunctionDescriptionRuleTop",
    StyleMenuListing->None],
  
  Cell[StyleData["FunctionDescriptionRuleTop", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["FunctionDescriptionRuleTop", "Printout"],
    CellMargins->{{30, 0}, {4, 0}},
    FontSize->11],
  
  Cell[StyleData["FunctionDescriptionRuleTop", "EnhancedPrintout"],
    CellMargins->{{30, 0}, {4, 0}},
    TextJustification->0,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["FunctionDescriptionRuleTop", "EnhancedPrintoutNonGray"],
    CellMargins->{{30, 0}, {4, 0}},
    TextJustification->0,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FunctionDescriptionRuleBottom"],
    CellFrame->{{0, 0}, {0.25, 0}},
    CellMargins->{{36, 10}, {4, 0}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"FunctionDescriptionRuleBottom",
    StyleMenuListing->None],
  
  Cell[StyleData["FunctionDescriptionRuleBottom", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["FunctionDescriptionRuleBottom", "Printout"],
    CellMargins->{{30, 0}, {4, 0}},
    FontSize->11],
  
  Cell[StyleData["FunctionDescriptionRuleBottom", "EnhancedPrintout"],
    CellMargins->{{30, 0}, {4, 0}},
    TextJustification->0,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["FunctionDescriptionRuleBottom", "EnhancedPrintoutNonGray"],
    CellMargins->{{30, 0}, {4, 0}},
    TextJustification->0,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FunctionExample"],
    CellMargins->{{36, 10}, {4, 0}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["FunctionExample", "Presentation"],
    FontSize->15],
  
  Cell[StyleData["FunctionExample", "Printout"],
    CellMargins->{{30, 0}, {4, 0}},
    FontSize->9],
  
  Cell[StyleData["FunctionExample", "EnhancedPrintout"],
    CellMargins->{{30, 0}, {4, 0}},
    FontFamily->"Palatino",
    FontSize->9],
  
  Cell[StyleData["FunctionExample", "EnhancedPrintoutNonGray"],
    CellMargins->{{30, 0}, {4, 0}},
    FontFamily->"Palatino",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FunctionTextNote"],
    CellMargins->{{36, 4}, {0, 4}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 4},
    LineIndent->0,
    StyleMenuListing->None],
  
  Cell[StyleData["FunctionTextNote", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["FunctionTextNote", "Printout"],
    CellMargins->{{36, 4}, {0, 4}},
    FontSize->9],
  
  Cell[StyleData["FunctionTextNote", "EnhancedPrintout"],
    CellMargins->{{36, 4}, {0, 4}},
    FontFamily->"Palatino",
    FontSize->8],
  
  Cell[StyleData["FunctionTextNote", "EnhancedPrintoutNonGray"],
    CellMargins->{{36, 4}, {0, 4}},
    FontFamily->"Palatino",
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnFunctionTable"],
    CellMargins->{{36, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnFunctionTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnFunctionTable", "Printout"],
    CellMargins->{{30, 0}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["3ColumnFunctionTable", "EnhancedPrintout"],
    CellMargins->{{30, 0}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["3ColumnFunctionTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{30, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Browser Emulation", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextNormal"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"TextNormal",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["TextNormal", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TextNormal", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BrowserEmulation"],
    CellMargins->{{12, 1}, {7, 24}},
    CellGroupingRules->{"SectionGrouping", 70},
    LineSpacing->{1, 3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    GridBoxOptions->{ColumnWidths->0.25,
    ColumnAlignments->{Left},
    GridFrame->True,
    GridFrameMargins->0.5,
    ColumnLines->True}],
  
  Cell[StyleData["BrowserEmulation", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["BrowserEmulation", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CategoryDefs"],
    CellMargins->{{300, 10}, {7, 7}},
    LineSpacing->{1, 3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    Background->RGBColor[1, 0.8, 0.6],
    GridBoxOptions->{ColumnAlignments->{Left},
    GridFrame->False,
    RowLines->True,
    ColumnLines->True}],
  
  Cell[StyleData["CategoryDefs", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["CategoryDefs", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Category1"],
    ShowCellBracket->False,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 50},
    StyleMenuListing->None,
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Category1", "Presentation"],
    FontSize->24],
  
  Cell[StyleData["Category1", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Category2"],
    ShowCellBracket->False,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{85, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    StyleMenuListing->None,
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["Category2", "Presentation"],
    FontSize->21],
  
  Cell[StyleData["Category2", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Category3"],
    ShowCellBracket->False,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{157, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.2, 0, 0.4]],
  
  Cell[StyleData["Category3", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Category3", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Category4"],
    ShowCellBracket->False,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{230, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.300008, 0.4]],
  
  Cell[StyleData["Category4", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Category4", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Misc", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->0.25,
    ColumnAlignments->{Left, Center}}],
  
  Cell[StyleData["4ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["4ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["4ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["4ColumnTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->0.2,
    ColumnAlignments->{Left, Center}}],
  
  Cell[StyleData["5ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["5ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["5ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["5ColumnTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->0.16,
    ColumnAlignments->{Left, Center}}],
  
  Cell[StyleData["6ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["6ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["6ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["6ColumnTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["7ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->0.14,
    ColumnAlignments->{Left, Center}}],
  
  Cell[StyleData["7ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["7ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["7ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["7ColumnTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["8ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->0.12,
    ColumnAlignments->{Left, Center}}],
  
  Cell[StyleData["8ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["8ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["8ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["8ColumnTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ABItemizedText"],
    CellMargins->{{20, 4}, {0, 5}},
    LineSpacing->{1, 3},
    ParagraphIndent->-21,
    CounterIncrements->"ItemizedText",
    StyleMenuListing->None],
  
  Cell[StyleData["ABItemizedText", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ABItemizedText", "Printout"],
    Hyphenation->True,
    ParagraphIndent->-21,
    FontSize->11],
  
  Cell[StyleData["ABItemizedText", "EnhancedPrintout"],
    Hyphenation->True,
    ParagraphIndent->-21,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ABItemizedText", "EnhancedPrintoutNonGray"],
    Hyphenation->True,
    ParagraphIndent->-21,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChapNumber"],
    CellMargins->{{27, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->42,
    FontWeight->"Plain",
    FontColor->RGBColor[0.592157, 0.313726, 0.313726]],
  
  Cell[StyleData["ChapNumber", "Presentation"],
    FontSize->63],
  
  Cell[StyleData["ChapNumber", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->36],
  
  Cell[StyleData["ChapNumber", "EnhancedPrintout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontFamily->"Frutiger 55 Roman",
    FontSize->36,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["ChapNumber", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 10}, {15, 30}},
    FontFamily->"Frutiger 55 Roman",
    FontSize->36,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChapTitle"],
    CellMargins->{{27, Inherited}, {80, 10}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->RGBColor[0.592157, 0.313726, 0.313726]],
  
  Cell[StyleData["ChapTitle", "Presentation"],
    FontSize->54],
  
  Cell[StyleData["ChapTitle", "Printout"],
    CellMargins->{{2, 10}, {80, 6}},
    FontSize->30],
  
  Cell[StyleData["ChapTitle", "EnhancedPrintout"],
    CellMargins->{{2, 10}, {80, 6}},
    FontFamily->"Frutiger 65 Bold",
    FontSize->30,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["ChapTitle", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 10}, {80, 6}},
    FontFamily->"Frutiger 65 Bold",
    FontSize->30,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemDingbat"],
    CellSize->{22, 14},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["ItemDingbat", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemDingbat", "Printout"],
    CellSize->{22, 13.125}],
  
  Cell[StyleData["ItemDingbat", "EnhancedPrintout"],
    CellSize->{22, 11}],
  
  Cell[StyleData["ItemDingbat", "EnhancedPrintoutNonGray"],
    CellSize->{22, 11}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item1"],
    CellMargins->{{19, 4}, {4, 4}},
    ParagraphIndent->-22,
    CounterIncrements->"Item1",
    StyleMenuListing->None],
  
  Cell[StyleData["Item1", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Item1", "Printout"],
    CellMargins->{{12, 0}, {2, 4}},
    FontSize->10],
  
  Cell[StyleData["Item1", "EnhancedPrintout"],
    CellMargins->{{16, 0}, {2, 4}},
    FontSize->10],
  
  Cell[StyleData["Item1", "EnhancedPrintoutNonGray"],
    CellMargins->{{16, 0}, {2, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item1Continued"],
    CellMargins->{{41, 4}, {4, 1}},
    CounterIncrements->"Item1Continued",
    StyleMenuListing->None],
  
  Cell[StyleData["Item1Continued", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Item1Continued", "Printout"],
    CellMargins->{{34, 0}, {4, 1}},
    FontSize->10],
  
  Cell[StyleData["Item1Continued", "EnhancedPrintout"],
    CellMargins->{{39, 0}, {4, 1}},
    FontSize->10],
  
  Cell[StyleData["Item1Continued", "EnhancedPrintoutNonGray"],
    CellMargins->{{39, 0}, {4, 1}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item2"],
    CellMargins->{{32, 4}, {4, 4}},
    ParagraphIndent->-22,
    CounterIncrements->"Item2",
    StyleMenuListing->None],
  
  Cell[StyleData["Item2", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Item2", "Printout"],
    CellMargins->{{26, 0}, {4, 4}},
    ParagraphIndent->-22,
    FontSize->10],
  
  Cell[StyleData["Item2", "EnhancedPrintout"],
    CellMargins->{{29, 0}, {2, 4}},
    ParagraphIndent->-22,
    FontSize->10],
  
  Cell[StyleData["Item2", "EnhancedPrintoutNonGray"],
    CellMargins->{{29, 0}, {2, 4}},
    ParagraphIndent->-22,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item2Continued"],
    CellMargins->{{54, 4}, {4, 1}},
    CounterIncrements->"Item2Continued",
    StyleMenuListing->None],
  
  Cell[StyleData["Item2Continued", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Item2Continued", "Printout"],
    CellMargins->{{27, 0}, {4, 1}}],
  
  Cell[StyleData["Item2Continued", "EnhancedPrintout"],
    CellMargins->{{52, 0}, {4, 1}},
    FontSize->10],
  
  Cell[StyleData["Item2Continued", "EnhancedPrintoutNonGray"],
    CellMargins->{{52, 0}, {4, 1}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item3"],
    CellMargins->{{45, 4}, {4, 4}},
    ParagraphIndent->-23,
    CounterIncrements->"Item3",
    StyleMenuListing->None],
  
  Cell[StyleData["Item3", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Item3", "Printout"],
    CellMargins->{{27, 0}, {2, 4}}],
  
  Cell[StyleData["Item3", "EnhancedPrintout"],
    CellMargins->{{42, 0}, {2, 4}},
    FontSize->10],
  
  Cell[StyleData["Item3", "EnhancedPrintoutNonGray"],
    CellMargins->{{42, 0}, {2, 4}},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item3Continued"],
    CellMargins->{{67, 4}, {4, 1}},
    CounterIncrements->"Item3Continued",
    StyleMenuListing->None],
  
  Cell[StyleData["Item3Continued", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Item3Continued", "Printout"],
    CellMargins->{{27, 0}, {4, 1}}],
  
  Cell[StyleData["Item3Continued", "EnhancedPrintout"],
    CellMargins->{{65, 0}, {4, 1}},
    FontSize->10],
  
  Cell[StyleData["Item3Continued", "EnhancedPrintoutNonGray"],
    CellMargins->{{65, 0}, {4, 1}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedBulletText"],
    CellMargins->{{19, 4}, {0, 5}},
    LineSpacing->{1, 3},
    ParagraphIndent->-22,
    CounterIncrements->"ItemizedBulletText",
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedBulletText", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemizedBulletText", "Printout"],
    Hyphenation->True,
    ParagraphIndent->-20,
    FontSize->11],
  
  Cell[StyleData["ItemizedBulletText", "EnhancedPrintout"],
    Hyphenation->True,
    ParagraphIndent->-19,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ItemizedBulletText", "EnhancedPrintoutNonGray"],
    Hyphenation->True,
    ParagraphIndent->-19,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NoteBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {8, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["NoteBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["NoteBox", "Printout"],
    CellMargins->{{2, 4}, {6, 2}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["NoteBox", "EnhancedPrintout"],
    CellMargins->{{2, 2}, {6, 2}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["NoteBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 4}, {6, 2}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{41, 4}, {8, 2}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    CellMargins->{{39, 4}, {6, 2}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["ItemizedNoteBox", "EnhancedPrintout"],
    CellMargins->{{39, 4}, {6, 2}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["ItemizedNoteBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{39, 4}, {6, 2}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameMargins->{{8, 8}, {0, 8}},
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["ItemizedTopBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemizedTopBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["ItemizedTopBox", "EnhancedPrintout"],
    CellMargins->{{39, 4}, {0, 6}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["ItemizedTopBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{39, 4}, {0, 6}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedBottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{37, 4}, {4, 0}},
    CellHorizontalScrolling->True,
    CellFrameMargins->{{8, 8}, {8, 0}},
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["ItemizedBottomBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemizedBottomBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["ItemizedBottomBox", "EnhancedPrintout"],
    CellMargins->{{39, 4}, {6, 0}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["ItemizedBottomBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{39, 4}, {6, 0}},
    CellFrameColor->GrayLevel[0],
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpacedBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{27, 12}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpacedBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MiddleSpacedBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}],
  
  Cell[StyleData["MiddleSpacedBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 0}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Palatino",
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}],
  
  Cell[StyleData["MiddleSpacedBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 0}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Palatino",
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNote"],
    CellMargins->{{41, 4}, {0, 12}},
    LineSpacing->{1, 2},
    CounterIncrements->"ItemizedNote",
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedNote", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemizedNote", "Printout"],
    CellMargins->{{38, 4}, {0, 9}},
    Hyphenation->True,
    FontSize->11],
  
  Cell[StyleData["ItemizedNote", "EnhancedPrintout"],
    CellMargins->{{38, 4}, {0, 0}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ItemizedNote", "EnhancedPrintoutNonGray"],
    CellMargins->{{38, 4}, {0, 0}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBelow"],
    CellMargins->{{41, 4}, {0, 8}},
    LineSpacing->{1, 2},
    CounterIncrements->"ItemizedNote",
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedNoteBelow", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemizedNoteBelow", "Printout"],
    CellMargins->{{38, 4}, {0, 12}},
    Hyphenation->True,
    FontSize->11],
  
  Cell[StyleData["ItemizedNoteBelow", "EnhancedPrintout"],
    CellMargins->{{38, 4}, {0, 8}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ItemizedNoteBelow", "EnhancedPrintoutNonGray"],
    CellMargins->{{38, 4}, {0, 8}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextBelowPic"],
    CellMargins->{{19, 4}, {0, 8}},
    LineSpacing->{1, 3},
    ParagraphIndent->-22,
    CounterIncrements->"ItemizedText",
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextBelowPic", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemizedTextBelowPic", "Printout"],
    CellMargins->{{20, 4}, {2, 12}},
    Hyphenation->True,
    ParagraphIndent->-18,
    FontSize->11],
  
  Cell[StyleData["ItemizedTextBelowPic", "EnhancedPrintout"],
    CellMargins->{{20, 4}, {2, 12}},
    Hyphenation->True,
    ParagraphIndent->-17,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ItemizedTextBelowPic", "EnhancedPrintoutNonGray"],
    CellMargins->{{20, 4}, {2, 12}},
    Hyphenation->True,
    ParagraphIndent->-17,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote2"],
    CellMargins->{{41, 4}, {0, 4}},
    LineSpacing->{1, 2},
    CounterIncrements->"ItemizedNote",
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote2", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemizedTextNote2", "Printout"],
    CellMargins->{{38, 4}, {0, 2}},
    Hyphenation->True,
    FontSize->11],
  
  Cell[StyleData["ItemizedTextNote2", "EnhancedPrintout"],
    CellMargins->{{38, 4}, {0, 2}},
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ItemizedTextNote2", "EnhancedPrintoutNonGray"],
    CellMargins->{{38, 4}, {0, 2}},
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedItem1"],
    CellMargins->{{48, 4}, {4, 4}},
    CellGroupingRules->{"SectionGrouping", 15},
    ParagraphIndent->-23,
    CounterIncrements->"NumberedItem1",
    StyleMenuListing->None],
  
  Cell[StyleData["NumberedItem1", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["NumberedItem1", "Printout"],
    CellMargins->{{12, 0}, {0, 8}}],
  
  Cell[StyleData["NumberedItem1", "EnhancedPrintout"],
    CellMargins->{{12, 0}, {0, 8}}],
  
  Cell[StyleData["NumberedItem1", "EnhancedPrintoutNonGray"],
    CellMargins->{{12, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedItem2"],
    CellMargins->{{71, 4}, {3, 3}},
    CellGroupingRules->{"SectionGrouping", 15},
    ParagraphIndent->-21,
    CounterIncrements->"NumberedItem2",
    StyleMenuListing->None],
  
  Cell[StyleData["NumberedItem2", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["NumberedItem2", "Printout"],
    CellMargins->{{27, 0}, {0, 4}}],
  
  Cell[StyleData["NumberedItem2", "EnhancedPrintout"],
    CellMargins->{{27, 0}, {0, 4}}],
  
  Cell[StyleData["NumberedItem2", "EnhancedPrintoutNonGray"],
    CellMargins->{{27, 0}, {0, 4}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedItem3"],
    CellMargins->{{94, 4}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 15},
    ParagraphIndent->-23,
    CounterIncrements->"NumberedItem3",
    StyleMenuListing->None],
  
  Cell[StyleData["NumberedItem3", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["NumberedItem3", "Printout"],
    CellMargins->{{27, 0}, {0, 4}}],
  
  Cell[StyleData["NumberedItem3", "EnhancedPrintout"],
    CellMargins->{{27, 0}, {0, 4}}],
  
  Cell[StyleData["NumberedItem3", "EnhancedPrintoutNonGray"],
    CellMargins->{{27, 0}, {0, 4}},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageHeaderBold"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["PageHeaderBold", "Printout"]],
  
  Cell[StyleData["PageHeaderBold", "EnhancedPrintout"],
    FontFamily->"Frutiger"],
  
  Cell[StyleData["PageHeaderBold", "EnhancedPrintoutNonGray"],
    FontFamily->"Frutiger"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SingleRowTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["SingleRowTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["SingleRowTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["SingleRowTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["SingleRowTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsubsection"],
    CellMargins->{{27, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    StyleMenuListing->None,
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsubsection", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Subsubsubsection", "Printout"],
    CellMargins->{{2, 0}, {3, 8}},
    FontSize->10],
  
  Cell[StyleData["Subsubsubsection", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {3, 8}},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["Subsubsubsection", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {3, 8}},
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{27, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    FontSize->21],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "EnhancedPrintout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontFamily->"Frutiger 55 Roman",
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 10}, {8, 10}},
    FontFamily->"Frutiger 55 Roman",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{27, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->24],
  
  Cell[StyleData["Subtitle", "EnhancedPrintout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontFamily->"Frutiger 55 Roman",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 10}, {10, 15}},
    FontFamily->"Frutiger 55 Roman",
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextBelow"],
    CellMargins->{{27, 4}, {0, 14}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontSize->12],
  
  Cell[StyleData["TextBelow", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TextBelow", "Printout"],
    CellMargins->{{2, 2}, {6, 12}},
    TextJustification->1,
    Hyphenation->True,
    FontSize->10],
  
  Cell[StyleData["TextBelow", "EnhancedPrintout"],
    CellMargins->{{2, 2}, {6, 12}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["TextBelow", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 2}, {6, 12}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{27, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->RGBColor[0.592157, 0.313726, 0.313726]],
  
  Cell[StyleData["Title", "Presentation"],
    FontSize->54],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->30],
  
  Cell[StyleData["Title", "EnhancedPrintout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontFamily->"Frutiger 65 Bold",
    FontSize->30.5,
    FontWeight->"Plain"],
  
  Cell[StyleData["Title", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 10}, {15, 30}},
    FontFamily->"Frutiger 65 Bold",
    FontSize->30.5,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Undersubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Undersubsection", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Undersubsection", "Printout"],
    CellMargins->{{2, 0}, {7, 10}},
    FontSize->10],
  
  Cell[StyleData["Undersubsection", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {7, 8}},
    FontFamily->"Frutiger 65 Bold",
    FontSize->10,
    FontWeight->"Plain"],
  
  Cell[StyleData["Undersubsection", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {7, 8}},
    FontFamily->"Frutiger 65 Bold",
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellMargins->{{27, 27}, {12, 18}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold",
    FontColor->RGBColor[0.592157, 0.313726, 0.313726]],
  
  Cell[StyleData["SectionFirst", "Presentation"],
    FontSize->30],
  
  Cell[StyleData["SectionFirst", "Printout"],
    CellMargins->{{2, 0}, {0, 6}},
    PageBreakBelow->False,
    FontSize->18],
  
  Cell[StyleData["SectionFirst", "EnhancedPrintout"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{2, Inherited}, {5, 6}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Frutiger 65 Bold",
    FontSize->16,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["SectionFirst", "EnhancedPrintoutNonGray"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{2, Inherited}, {5, 6}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Frutiger 65 Bold",
    FontSize->16,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionFirst"],
    CellDingbat->None,
    CellMargins->{{27, 27}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.592157, 0.313726, 0.313726]],
  
  Cell[StyleData["SubsectionFirst", "Presentation"],
    FontSize->24],
  
  Cell[StyleData["SubsectionFirst", "SlideShow"],
    CellDingbat->None,
    CellMargins->{{70, 0}, {4, 6}},
    FontSize->12],
  
  Cell[StyleData["SubsectionFirst", "Printout"],
    CellMargins->{{9, 0}, {5, 6}},
    CellBracketOptions->{"Color"->RGBColor[1, 0, 0]},
    FontSize->12],
  
  Cell[StyleData["SubsectionFirst", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {5, 6}},
    CellBracketOptions->{"Color"->RGBColor[1, 0, 0]},
    FontFamily->"Frutiger 65 Bold",
    FontSize->12,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["SubsectionFirst", "EnhancedPrintoutNonGray"],
    CellMargins->{{9, 0}, {5, 6}},
    CellBracketOptions->{"Color"->RGBColor[1, 0, 0]},
    FontFamily->"Frutiger 65 Bold",
    FontSize->12,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionFirst"],
    CellMargins->{{27, 27}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.592157, 0.313726, 0.313726]],
  
  Cell[StyleData["SubsubsectionFirst", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["SubsubsectionFirst", "Printout"],
    CellMargins->{{2, 0}, {3, 3}},
    CellBracketOptions->{"Color"->RGBColor[1, 0, 0]},
    FontSize->10],
  
  Cell[StyleData["SubsubsectionFirst", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {3, 3}},
    CellBracketOptions->{"Color"->RGBColor[1, 0, 0]},
    FontFamily->"Frutiger 65 Bold",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["SubsubsectionFirst", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {3, 3}},
    CellBracketOptions->{"Color"->RGBColor[1, 0, 0]},
    FontFamily->"Frutiger 65 Bold",
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsubsectionFirst"],
    CellMargins->{{10, 4}, {0, 12}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    StyleMenuListing->None,
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsubsectionFirst", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["SubsubsubsectionFirst", "Printout"],
    CellMargins->{{2, 0}, {3, 3}},
    FontSize->10],
  
  Cell[StyleData["SubsubsubsectionFirst", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {3, 3}},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["SubsubsubsectionFirst", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {3, 3}},
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell["Spacer Cell", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Spacer"],
    CellMargins->{{10, 10}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->2,
    "ClosedCellHeight"->1},
    CellOpen->False,
    StyleMenuListing->None],
  
  Cell[StyleData["Spacer", "Printout"],
    CellOpen->True,
    FontSize->3]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DiscretionaryHyphen"],
    StyleMenuListing->None,
    FontSize->0.0625,
    FontColor->GrayLevel[1]],
  
  Cell[StyleData["DiscretionaryHyphen", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["DiscretionaryHyphen", "EnhancedPrintout"],
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["DiscretionaryHyphen", "EnhancedPrintoutNonGray"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureSmaller1"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureSmaller1", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["PictureSmaller1", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.63],
  
  Cell[StyleData["PictureSmaller1", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.63],
  
  Cell[StyleData["PictureSmaller1", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.63]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureSmaller2"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureSmaller2", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["PictureSmaller2", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.61],
  
  Cell[StyleData["PictureSmaller2", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.61],
  
  Cell[StyleData["PictureSmaller2", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.61]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureSmaller3"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureSmaller3", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["PictureSmaller3", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.59],
  
  Cell[StyleData["PictureSmaller3", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.59],
  
  Cell[StyleData["PictureSmaller3", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.59]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureSmaller4"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureSmaller4", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["PictureSmaller4", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.57],
  
  Cell[StyleData["PictureSmaller4", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.57],
  
  Cell[StyleData["PictureSmaller4", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.57]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureSmaller5"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureSmaller5", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["PictureSmaller5", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.55],
  
  Cell[StyleData["PictureSmaller5", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.55],
  
  Cell[StyleData["PictureSmaller5", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.55]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureSmaller6"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureSmaller6", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["PictureSmaller6", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.53],
  
  Cell[StyleData["PictureSmaller6", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.53],
  
  Cell[StyleData["PictureSmaller6", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.53]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPicture"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPicture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemPicture", "Printout"],
    CellMargins->{{55, Inherited}, {8, -4}},
    Magnification->0.65],
  
  Cell[StyleData["ItemPicture", "EnhancedPrintout"],
    CellMargins->{{60, Inherited}, {10, -3}},
    Magnification->0.65],
  
  Cell[StyleData["ItemPicture", "EnhancedPrintoutNonGray"],
    CellMargins->{{60, Inherited}, {10, -3}},
    Magnification->0.65]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureSmaller1"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureSmaller1", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemPictureSmaller1", "Printout"],
    CellMargins->{{56, Inherited}, {9, -3}},
    Magnification->0.63],
  
  Cell[StyleData["ItemPictureSmaller1", "EnhancedPrintout"],
    CellMargins->{{63, Inherited}, {10, -3}},
    Magnification->0.63],
  
  Cell[StyleData["ItemPictureSmaller1", "EnhancedPrintoutNonGray"],
    CellMargins->{{63, Inherited}, {10, -3}},
    Magnification->0.63]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureSmaller2"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureSmaller2", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemPictureSmaller2", "Printout"],
    CellMargins->{{58, Inherited}, {8, -4}},
    Magnification->0.61],
  
  Cell[StyleData["ItemPictureSmaller2", "EnhancedPrintout"],
    CellMargins->{{65, Inherited}, {11, -3}},
    Magnification->0.61],
  
  Cell[StyleData["ItemPictureSmaller2", "EnhancedPrintoutNonGray"],
    CellMargins->{{65, Inherited}, {11, -3}},
    Magnification->0.61]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureSmaller3"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureSmaller3", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemPictureSmaller3", "Printout"],
    CellMargins->{{61, Inherited}, {10, -2}},
    Magnification->0.59],
  
  Cell[StyleData["ItemPictureSmaller3", "EnhancedPrintout"],
    CellMargins->{{67, Inherited}, {11, -3}},
    Magnification->0.59],
  
  Cell[StyleData["ItemPictureSmaller3", "EnhancedPrintoutNonGray"],
    CellMargins->{{67, Inherited}, {11, -3}},
    Magnification->0.59]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureSmaller4"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureSmaller4", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemPictureSmaller4", "Printout"],
    CellMargins->{{63, Inherited}, {10, -2}},
    Magnification->0.57],
  
  Cell[StyleData["ItemPictureSmaller4", "EnhancedPrintout"],
    CellMargins->{{69, Inherited}, {12, -4}},
    Magnification->0.57],
  
  Cell[StyleData["ItemPictureSmaller4", "EnhancedPrintoutNonGray"],
    CellMargins->{{69, Inherited}, {12, -4}},
    Magnification->0.57]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureSmaller5"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureSmaller5", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemPictureSmaller5", "Printout"],
    CellMargins->{{65, Inherited}, {11, -2}},
    Magnification->0.55],
  
  Cell[StyleData["ItemPictureSmaller5", "EnhancedPrintout"],
    CellMargins->{{71, Inherited}, {13, -2}},
    Magnification->0.55],
  
  Cell[StyleData["ItemPictureSmaller5", "EnhancedPrintoutNonGray"],
    CellMargins->{{71, Inherited}, {13, -2}},
    Magnification->0.55]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureSmaller6"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureSmaller6", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemPictureSmaller6", "Printout"],
    CellMargins->{{67, Inherited}, {12, -2}},
    Magnification->0.53],
  
  Cell[StyleData["ItemPictureSmaller6", "EnhancedPrintout"],
    CellMargins->{{74, Inherited}, {13, -3}},
    Magnification->0.53],
  
  Cell[StyleData["ItemPictureSmaller6", "EnhancedPrintoutNonGray"],
    CellMargins->{{74, Inherited}, {13, -3}},
    Magnification->0.53]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureBigger1"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureBigger1", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["PictureBigger1", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.68],
  
  Cell[StyleData["PictureBigger1", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.68],
  
  Cell[StyleData["PictureBigger1", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.68]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureBigger2"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureBigger2", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["PictureBigger2", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.71],
  
  Cell[StyleData["PictureBigger2", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.71],
  
  Cell[StyleData["PictureBigger2", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.71]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureBigger3"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureBigger3", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["PictureBigger3", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.74],
  
  Cell[StyleData["PictureBigger3", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.74],
  
  Cell[StyleData["PictureBigger3", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.74]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureBigger4"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureBigger4", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["PictureBigger4", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.77],
  
  Cell[StyleData["PictureBigger4", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.77],
  
  Cell[StyleData["PictureBigger4", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.77]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureBigger5"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureBigger5", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["PictureBigger5", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.8],
  
  Cell[StyleData["PictureBigger5", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.8],
  
  Cell[StyleData["PictureBigger5", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureBigger6"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureBigger6", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["PictureBigger6", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.83],
  
  Cell[StyleData["PictureBigger6", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.83],
  
  Cell[StyleData["PictureBigger6", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.83]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureBigger1"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureBigger1", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemPictureBigger1", "Printout"],
    CellMargins->{{50, Inherited}, {9, -3}},
    Magnification->0.68],
  
  Cell[StyleData["ItemPictureBigger1", "EnhancedPrintout"],
    CellMargins->{{57, Inherited}, {10, -3}},
    Magnification->0.68],
  
  Cell[StyleData["ItemPictureBigger1", "EnhancedPrintoutNonGray"],
    CellMargins->{{57, Inherited}, {10, -3}},
    Magnification->0.68]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureBigger2"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureBigger2", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemPictureBigger2", "Printout"],
    CellMargins->{{48, Inherited}, {8, -4}},
    Magnification->0.71],
  
  Cell[StyleData["ItemPictureBigger2", "EnhancedPrintout"],
    CellMargins->{{54, Inherited}, {10, -3}},
    Magnification->0.71],
  
  Cell[StyleData["ItemPictureBigger2", "EnhancedPrintoutNonGray"],
    CellMargins->{{54, Inherited}, {10, -3}},
    Magnification->0.71]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureBigger3"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureBigger3", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemPictureBigger3", "Printout"],
    CellMargins->{{46, Inherited}, {10, -2}},
    Magnification->0.74],
  
  Cell[StyleData["ItemPictureBigger3", "EnhancedPrintout"],
    CellMargins->{{52, Inherited}, {10, -3}},
    Magnification->0.74],
  
  Cell[StyleData["ItemPictureBigger3", "EnhancedPrintoutNonGray"],
    CellMargins->{{52, Inherited}, {10, -3}},
    Magnification->0.74]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureBigger4"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureBigger4", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemPictureBigger4", "Printout"],
    CellMargins->{{45, Inherited}, {10, -2}},
    Magnification->0.77],
  
  Cell[StyleData["ItemPictureBigger4", "EnhancedPrintout"],
    CellMargins->{{50, Inherited}, {10, -3}},
    Magnification->0.77],
  
  Cell[StyleData["ItemPictureBigger4", "EnhancedPrintoutNonGray"],
    CellMargins->{{50, Inherited}, {10, -3}},
    Magnification->0.77]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureBigger5"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureBigger5", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemPictureBigger5", "Printout"],
    CellMargins->{{43, Inherited}, {11, -2}},
    Magnification->0.8],
  
  Cell[StyleData["ItemPictureBigger5", "EnhancedPrintout"],
    CellMargins->{{49, Inherited}, {10, -3}},
    Magnification->0.8],
  
  Cell[StyleData["ItemPictureBigger5", "EnhancedPrintoutNonGray"],
    CellMargins->{{49, Inherited}, {10, -3}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureBigger6"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureBigger6", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemPictureBigger6", "Printout"],
    CellMargins->{{43, Inherited}, {12, -2}},
    Magnification->0.83],
  
  Cell[StyleData["ItemPictureBigger6", "EnhancedPrintout"],
    CellMargins->{{46, Inherited}, {8, -2}},
    Magnification->0.83],
  
  Cell[StyleData["ItemPictureBigger6", "EnhancedPrintoutNonGray"],
    CellMargins->{{46, Inherited}, {8, -2}},
    Magnification->0.83]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ScreenGraphic"],
    CellMargins->{{12, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ScreenGraphic", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ScreenGraphic", "Printout"],
    CellMargins->{{2, Inherited}, {0, 8}}],
  
  Cell[StyleData["ScreenGraphic", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {0, 8}},
    CellElementSpacings->{"CellMinHeight"->2,
    "ClosedCellHeight"->2},
    CellOpen->False],
  
  Cell[StyleData["ScreenGraphic", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {0, 8}},
    CellElementSpacings->{"CellMinHeight"->2,
    "ClosedCellHeight"->2},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrintGraphic"],
    CellMargins->{{12, Inherited}, {0, 8}},
    CellElementSpacings->{"CellMinHeight"->2,
    "ClosedCellHeight"->2},
    CellOpen->False,
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PrintGraphic", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["PrintGraphic", "Printout"],
    CellMargins->{{2, Inherited}, {0, 8}},
    CellElementSpacings->{"CellMinHeight"->2,
    "ClosedCellHeight"->2},
    CellOpen->False],
  
  Cell[StyleData["PrintGraphic", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {0, 8}},
    CellElementSpacings->{"CellMinHeight"->12},
    CellOpen->True],
  
  Cell[StyleData["PrintGraphic", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {0, 8}},
    CellElementSpacings->{"CellMinHeight"->12},
    CellOpen->True]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallTextSans"],
    CellMargins->{{10, 4}, {8, 8}},
    TextJustification->1,
    LineSpacing->{1, 2},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallTextSans", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["SmallTextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Hyphenation->True,
    FontSize->7],
  
  Cell[StyleData["SmallTextSans", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, -2},
    FontFamily->"Frutiger 55 Roman",
    FontSize->7]
  }, Closed]]
  }, Closed]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["AuthorTools", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BilateralCell"],
    CellMargins->{{27, 4}, {0, 8}},
    StyleMenuListing->None,
    FontSize->12,
    GridBoxOptions->{ColumnWidths->{0.33, 0.6},
    RowAlignments->Top,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BilateralCell", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["BilateralCell", "SlideShow"],
    CellMargins->{{36, 24}, {4, 4}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["BilateralCell", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontSize->10],
  
  Cell[StyleData["BilateralCell", "EnhancedPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["BilateralCell", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RuledPageBreak"],
    CellFrame->{{0, 0}, {0.25, 0}},
    CellMargins->{{27, 4}, {12, 0}},
    CellFrameMargins->{{0, 0}, {1, 0}},
    FontSize->8],
  
  Cell[StyleData["RuledPageBreak", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["RuledPageBreak", "SlideShow"],
    CellMargins->{{36, 24}, {4, 4}}],
  
  Cell[StyleData["RuledPageBreak", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    PageBreakBelow->True,
    FontSize->1],
  
  Cell[StyleData["RuledPageBreak", "EnhancedPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    PageBreakBelow->True],
  
  Cell[StyleData["RuledPageBreak", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 2}, {6, 6}},
    PageBreakBelow->True]
  }, Closed]],
  
  Cell[StyleData["PaletteTitle"],
    CellFrame->{{0, 0}, {1, 0}},
    CellMargins->{{4, 0}, {Inherited, 0}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0.32549, 0.537255],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #2]}]&),
    ButtonEvaluator->None,
    ButtonStyle->"PaletteButton",
    ButtonMargins->3}],
  
  Cell[StyleData["PaletteButton"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    ButtonBoxOptions->{ButtonEvaluator->"Local",
    Active->True,
    ButtonMargins->6,
    Background->RGBColor[0.329412, 0.584314, 0.694118]}],
  
  Cell[StyleData["PaletteButton2"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    ButtonBoxOptions->{ButtonEvaluator->"Local",
    Active->True,
    ButtonMargins->4,
    Background->RGBColor[0.537255, 0.72549, 0.843137]}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Outline Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline1"],
    CellMargins->{{27, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 50},
    ParagraphIndent->-38,
    CounterIncrements->"Outline1",
    CounterAssignments->{{"Outline2", 0}, {"Outline3", 0}, {"Outline4", 0}},
    FontSize->18,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral}],
  
  Cell[StyleData["Outline1", "Presentation"],
    FontSize->27],
  
  Cell[StyleData["Outline1", "Printout"],
    CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline2"],
    CellMargins->{{57, 10}, {6, 6}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    CounterAssignments->{{"Outline3", 0}, {"Outline4", 0}},
    FontSize->15,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}],
  
  Cell[StyleData["Outline2", "Presentation"],
    FontSize->23],
  
  Cell[StyleData["Outline2", "Printout"],
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline3"],
    CellMargins->{{87, 10}, {5, 5}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-21,
    CounterIncrements->"Outline3",
    CounterAssignments->{{"Outline4", 0}},
    FontSize->12,
    CounterBoxOptions->{CounterFunction:>Identity}],
  
  Cell[StyleData["Outline3", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Outline3", "Printout"],
    CounterBoxOptions->{CounterFunction:>Identity}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline4"],
    CellMargins->{{117, 10}, {4, 4}},
    CellGroupingRules->{"SectionGrouping", 80},
    ParagraphIndent->-18,
    CounterIncrements->"Outline4",
    FontSize->10,
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "a", "z"], #]&)}],
  
  Cell[StyleData["Outline4", "Presentation"],
    FontSize->15],
  
  Cell[StyleData["Outline4", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Slide Show Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowNavigationBar"],
    Editable->False,
    CellFrame->True,
    CellMargins->{{0, 0}, {3, 3}},
    CellElementSpacings->{"CellMinHeight"->0.8125},
    CellGroupingRules->{"SectionGrouping", 30},
    CellFrameMargins->False,
    CellFrameColor->GrayLevel[1],
    CellFrameLabelMargins->False,
    TextAlignment->Center,
    CounterIncrements->"SlideShowNavigationBar",
    StyleMenuListing->None,
    FontSize->10,
    Background->GrayLevel[0.8],
    Magnification->1,
    GridBoxOptions->{GridBaseline->Center,
    RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->{3.5, 3.5, 3.5, 3.5, 13, 5, 4},
    RowAlignments->Baseline,
    ColumnAlignments->{
      Center, Center, Center, Center, Center, Center, Right, Center}}],
  
  Cell[StyleData["SlideShowNavigationBar", "SlideShow"],
    Deletable->False,
    ShowCellBracket->False,
    CellMargins->{{-1, -1}, {-1, -1}},
    PageBreakAbove->True,
    CellFrameMargins->{{1, 1}, {0, 0}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{0, 0}, {10, 0}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->{{12, 4}, {6, 12}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Plain",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.408011, 0.440726, 0.8]],
  
  Cell[StyleData["SlideShowSection", "Presentation"],
    FontSize->27],
  
  Cell[StyleData["SlideShowSection", "SlideShow"],
    ShowCellBracket->False,
    PageBreakAbove->True],
  
  Cell[StyleData["SlideShowSection", "Printout"],
    CellMargins->{{18, 30}, {0, 30}},
    CellFrameMargins->5,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideHyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->26,
    FontColor->GrayLevel[0.400015],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMinHeight->0.85,
    ButtonMargins->0.5,
    ButtonNote->None}],
  
  Cell[StyleData["SlideHyperlink", "SlideShow"]],
  
  Cell[StyleData["SlideHyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOCLink"],
    CellMargins->{{24, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Helvetica",
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMargins->1.5,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["SlideTOCLink", "SlideShow"]],
  
  Cell[StyleData["SlideTOCLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOC"],
    CellDingbat->"\[Bullet]",
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["SlideTOC", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["SlideTOC", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Title Page, Contents, and Index", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{21, 4}, {12, 24}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->RGBColor[0.592157, 0.313726, 0.313726]],
  
  Cell[StyleData["ContentsTitle", "Presentation"],
    FontSize->36],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{12, 0}, {102, 89}},
    PageBreakBelow->False,
    FontSize->30.5,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["ContentsTitle", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {15, 30}},
    PageBreakBelow->False,
    FontFamily->"Frutiger 65 Bold",
    FontSize->30.5,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{35, 4}, {3, 18}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{20, 0}, {3, 18}},
    PageBreakBelow->False,
    FontSize->11],
  
  Cell[StyleData["ContentsSection", "EnhancedPrintout"],
    CellMargins->{{20, 0}, {3, 18}},
    PageBreakBelow->False,
    FontFamily->"Frutiger 65 Bold",
    FontSize->11,
    FontWeight->"Plain"],
  
  Cell[StyleData["ContentsSection", "EnhancedPrintoutNonGray"],
    CellMargins->{{20, 0}, {3, 18}},
    PageBreakBelow->False,
    FontFamily->"Frutiger 65 Bold",
    FontSize->11,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{50, 4}, {0, 5}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{40, 4}, {0, 5}},
    FontSize->11],
  
  Cell[StyleData["Contents", "EnhancedPrintout"],
    CellMargins->{{40, 5}, {0, 5}},
    FontFamily->"Palatino",
    FontSize->11],
  
  Cell[StyleData["Contents", "EnhancedPrintoutNonGray"],
    CellMargins->{{40, 5}, {0, 5}},
    FontFamily->"Palatino",
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9],
  
  Cell[StyleData["Index", "EnhancedPrintout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontFamily->"Palatino",
    FontSize->9],
  
  Cell[StyleData["Index", "EnhancedPrintoutNonGray"],
    CellMargins->{{13, 0}, {0, 0}},
    FontFamily->"Palatino",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48],
  
  Cell[StyleData["IndexSubentry", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9],
  
  Cell[StyleData["IndexSubentry", "EnhancedPrintout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontFamily->"Palatino",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index2Column"],
    CellMargins->{{21, 4}, {0, 8}},
    ParagraphIndent->-20,
    TabSpacings->1,
    StyleMenuListing->None,
    FontSize->10,
    GridBoxOptions->{ColumnWidths->0.5,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["Index2Column", "Presentation"],
    FontSize->15],
  
  Cell[StyleData["Index2Column", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    FontSize->8],
  
  Cell[StyleData["Index2Column", "EnhancedPrintout"],
    CellMargins->{{2, 2}, {1, 1}},
    LineSpacing->{1, 0.2},
    FontFamily->"Palatino",
    FontSize->8],
  
  Cell[StyleData["Index2Column", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 2}, {1, 1}},
    LineSpacing->{1, 0.2},
    FontFamily->"Palatino",
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Leader"],
    TabFilling->".",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain"],
  
  Cell[StyleData["Leader", "Printout"],
    FontSize->10],
  
  Cell[StyleData["Leader", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LeaderNoDots"],
    TabFilling->" ",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain"],
  
  Cell[StyleData["LeaderNoDots", "Printout"],
    FontSize->10],
  
  Cell[StyleData["LeaderNoDots", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["PageLink", "Printout"],
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["PageLink", "EnhancedPrintout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCPage"],
    CellSize->{22, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontSize->12,
    FontWeight->"Plain"],
  
  Cell[StyleData["TOCPage", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TOCPage", "Printout"],
    FontSize->10],
  
  Cell[StyleData["TOCPage", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCTitle"],
    CellMargins->{{20, 0}, {1, 8}},
    CellGroupingRules->{"SectionGrouping", 70},
    TabSpacings->46,
    CounterIncrements->"TOCTitle",
    CounterAssignments->{{"TOCSection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["TOCTitle", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TOCTitle", "Printout"],
    CellMargins->{{12, 0}, {1, 8}},
    PageBreakBelow->False,
    TabSpacings->47.4,
    FontSize->11],
  
  Cell[StyleData["TOCTitle", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {2, 10}},
    PageBreakBelow->False,
    TabSpacings->49.3,
    FontFamily->"Frutiger 65 Bold",
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSection"],
    CellMargins->{{48, 0}, {1, 1}},
    CellGroupingRules->{"SectionGrouping", 75},
    TabSpacings->42.9,
    CounterIncrements->"TOCSection",
    CounterAssignments->{{"TOCSubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["TOCSection", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TOCSection", "Printout"],
    CellMargins->{{30, 0}, {1, 1}},
    PageBreakBelow->False,
    FontSize->12],
  
  Cell[StyleData["TOCSection", "EnhancedPrintout"],
    CellMargins->{{26, 0}, {1, 3}},
    PageBreakBelow->False,
    TabSpacings->46.45,
    FontFamily->"Frutiger",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSubsection"],
    CellMargins->{{76, 0}, {1, 1}},
    CellGroupingRules->{"SectionGrouping", 80},
    TabSpacings->39.8,
    CounterIncrements->"TOCSubsection",
    CounterAssignments->{{"TOCSubsubsection", 0}},
    FontSize->12],
  
  Cell[StyleData["TOCSubsection", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TOCSubsection", "Printout"],
    CellMargins->{{70, 0}, {1, 1}},
    PageBreakBelow->False,
    FontSize->10],
  
  Cell[StyleData["TOCSubsection", "EnhancedPrintout"],
    CellMargins->{{38, 0}, {1, 1}},
    PageBreakBelow->False,
    TabSpacings->45.15,
    FontFamily->"Palatino",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSubsubsection"],
    CellMargins->{{104, 0}, {1, 1}},
    CellGroupingRules->{"SectionGrouping", 85},
    TabSpacings->36.7,
    CounterIncrements->"TOCSubsubsection",
    FontSize->12],
  
  Cell[StyleData["TOCSubsubsection", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TOCSubsubsection", "Printout"],
    CellMargins->{{96, 0}, {1, 1}},
    PageBreakBelow->False,
    FontSize->9],
  
  Cell[StyleData["TOCSubsubsection", "EnhancedPrintout"],
    CellMargins->{{96, 0}, {1, 1}},
    PageBreakBelow->False,
    FontFamily->"Palatino",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCTitleDingbat"],
    CellSize->{34, Inherited},
    TextAlignment->Right],
  
  Cell[StyleData["TOCTitleDingbat", "EnhancedPrintout"],
    FontFamily->"Frutiger",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSectionDingbat"],
    CellSize->{38, Inherited},
    TextAlignment->Right],
  
  Cell[StyleData["TOCSectionDingbat", "EnhancedPrintout"],
    FontFamily->"Frutiger",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSubsectionDingbat"],
    CellSize->{54, Inherited},
    TextAlignment->Right],
  
  Cell[StyleData["TOCSubsectionDingbat", "EnhancedPrintout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCTitleCondensed"],
    CellMargins->{{20, 0}, {1, 8}},
    CellGroupingRules->{"SectionGrouping", 70},
    TabSpacings->50.4,
    CounterIncrements->"TOCTitleCondensed",
    CounterAssignments->{{"TOCSectionCondensed", 0}, {
        "TOCSubsectionCondensed", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["TOCTitleCondensed", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TOCTitleCondensed", "Printout"],
    CellMargins->{{12, 0}, {1, 8}},
    PageBreakBelow->False,
    FontSize->11],
  
  Cell[StyleData["TOCTitleCondensed", "EnhancedPrintout"],
    CellMargins->{{12, 0}, {1, 8}},
    PageBreakBelow->False,
    FontFamily->"Frutiger 65 Bold",
    FontSize->11,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSectionCondensed"],
    CellMargins->{{48, 0}, {1, 1}},
    CellGroupingRules->{"SectionGrouping", 75},
    TabSpacings->47.4,
    CounterIncrements->"TOCSectionCondensed",
    CounterAssignments->{{"TOCSubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold",
    FontColor->GrayLevel[0.2]],
  
  Cell[StyleData["TOCSectionCondensed", "Presentation"],
    FontSize->15],
  
  Cell[StyleData["TOCSectionCondensed", "Printout"],
    CellMargins->{{36, 0}, {1, 1}},
    PageBreakBelow->False,
    FontSize->11],
  
  Cell[StyleData["TOCSectionCondensed", "EnhancedPrintout"],
    CellMargins->{{36, 0}, {1, 1}},
    PageBreakBelow->False,
    FontFamily->"Palatino",
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSubsectionCondensed"],
    PageWidth->470,
    CellMargins->{{76, 0}, {1, 1}},
    CellGroupingRules->{"SectionGrouping", 80},
    TextJustification->1,
    FontSize->12],
  
  Cell[StyleData["TOCSubsectionCondensed", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TOCSubsectionCondensed", "Printout"],
    CellMargins->{{72, 0}, {1, 1}},
    PageBreakBelow->False,
    Hyphenation->True,
    FontSize->10],
  
  Cell[StyleData["TOCSubsectionCondensed", "EnhancedPrintout"],
    CellMargins->{{72, 0}, {1, 1}},
    PageBreakBelow->False,
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSubsubsectionCondensed"],
    CellMargins->{{104, 0}, {1, 1}},
    CellGroupingRules->{"SectionGrouping", 85},
    TabSpacings->39.3,
    CounterIncrements->"TOCSubsubsectionCondensed",
    FontSize->12],
  
  Cell[StyleData["TOCSubsubsectionCondensed", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TOCSubsubsectionCondensed", "Printout"],
    CellMargins->{{96, 0}, {1, 1}},
    PageBreakBelow->False,
    FontSize->9],
  
  Cell[StyleData["TOCSubsubsectionCondensed", "EnhancedPrintout"],
    CellMargins->{{96, 0}, {1, 1}},
    PageBreakBelow->False,
    FontFamily->"Palatino",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TitlePageGraphic"],
    CellMargins->{{0, 0}, {100, 20}},
    Evaluatable->False,
    PageBreakBelow->False,
    TextAlignment->Center],
  
  Cell[StyleData["TitlePageGraphic", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TitlePageGraphic", "Printout"],
    CellMargins->{{0, 0}, {230, 88}}],
  
  Cell[StyleData["TitlePageGraphic", "EnhancedPrintout"],
    CellMargins->{{0, 0}, {230, 88}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TitlePageLogo"],
    CellMargins->{{0, 0}, {0, 0}}],
  
  Cell[StyleData["TitlePageLogo", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TitlePageLogo", "Printout"]],
  
  Cell[StyleData["TitlePageLogo", "EnhancedPrintout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Presentation"],
    FontSize->3],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{27, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Presentation"],
    FontSize->6],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{27, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Presentation"],
    FontSize->6],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{27, 4}, {-4, 18}},
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageHeader", "Printout"]],
  
  Cell[StyleData["PageHeader", "EnhancedPrintout"],
    FontFamily->"Frutiger 55 Roman"],
  
  Cell[StyleData["PageHeader", "EnhancedPrintoutNonGray"],
    FontFamily->"Frutiger 55 Roman"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageNumber", "Printout"]],
  
  Cell[StyleData["PageNumber", "EnhancedPrintout"],
    FontFamily->"Frutiger 65 Bold",
    FontWeight->"Plain"],
  
  Cell[StyleData["PageNumber", "EnhancedPrintoutNonGray"],
    FontFamily->"Frutiger 65 Bold",
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["PageFooter", "Printout"]],
  
  Cell[StyleData["PageFooter", "EnhancedPrintout"],
    FontFamily->"Frutiger 55 Roman"],
  
  Cell[StyleData["PageFooter", "EnhancedPrintoutNonGray"],
    FontFamily->"Frutiger 55 Roman"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["For compatibility", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["Header", "Printout"]],
  
  Cell[StyleData["Header", "EnhancedPrintout"],
    FontFamily->"Frutiger 55 Roman",
    FontSlant->"Plain"],
  
  Cell[StyleData["Header", "EnhancedPrintoutNonGray"],
    FontFamily->"Frutiger 55 Roman",
    FontSlant->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Footer"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["Footer", "Printout"]],
  
  Cell[StyleData["Footer", "EnhancedPrintout"],
    FontFamily->"Frutiger 55 Roman"],
  
  Cell[StyleData["Footer", "EnhancedPrintoutNonGray"],
    FontFamily->"Frutiger 55 Roman"]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["CellExpression", "EnhancedPrintout"],
    FontFamily->"Courier Std",
    FontSize->10],
  
  Cell[StyleData["CellExpression", "EnhancedPrintoutNonGray"],
    FontFamily->"Courier Std",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InputForm", "EnhancedPrintout"],
    FontFamily->"Courier Std"],
  
  Cell[StyleData["InputForm", "EnhancedPrintoutNonGray"],
    FontFamily->"Courier Std"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm", "EnhancedPrintout"],
    FontFamily->"Courier Std"],
  
  Cell[StyleData["OutputForm", "EnhancedPrintoutNonGray"],
    FontFamily->"Courier Std"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm", "EnhancedPrintout"],
    FontFamily->"Courier Std"],
  
  Cell[StyleData["StandardForm", "EnhancedPrintoutNonGray"],
    FontFamily->"Courier Std"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "LocalInteractions:14"->{
    Cell[1776, 53, 70, 1, 38, "ObjectName",
      CellTags->"LocalInteractions:14"],
    Cell[1849, 56, 269, 9, 48, "Usage",
      CellTags->"LocalInteractions:14"],
    Cell[2121, 67, 199, 5, 40, "Notes",
      CellTags->"LocalInteractions:14"],
    Cell[2323, 74, 591, 21, 72, "Notes",
      CellTags->"LocalInteractions:14"],
    Cell[2917, 97, 114, 3, 24, "Notes",
      CellTags->"LocalInteractions:14"],
    Cell[3056, 104, 69, 1, 38, "ExampleSection",
      CellTags->"LocalInteractions:14"],
    Cell[3128, 107, 699, 14, 154, "Input",
      CellTags->"LocalInteractions:14"],
    Cell[3852, 125, 126, 3, 26, "Input",
      CellTags->"LocalInteractions:14"],
    Cell[3981, 130, 94532, 1367, 294, 2767, 228, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LocalInteractions:14"],
    Cell[98528, 1500, 107, 3, 26, "Input",
      CellTags->"LocalInteractions:14"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"LocalInteractions:14", 350963, 10308}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 70, 1, 38, "ObjectName",
  CellTags->"LocalInteractions:14"],
Cell[1849, 56, 269, 9, 48, "Usage",
  CellTags->"LocalInteractions:14"],
Cell[2121, 67, 199, 5, 40, "Notes",
  CellTags->"LocalInteractions:14"],
Cell[2323, 74, 591, 21, 72, "Notes",
  CellTags->"LocalInteractions:14"],
Cell[2917, 97, 114, 3, 24, "Notes",
  CellTags->"LocalInteractions:14"],

Cell[CellGroupData[{
Cell[3056, 104, 69, 1, 38, "ExampleSection",
  CellTags->"LocalInteractions:14"],
Cell[3128, 107, 699, 14, 154, "Input",
  CellTags->"LocalInteractions:14"],

Cell[CellGroupData[{
Cell[3852, 125, 126, 3, 26, "Input",
  CellTags->"LocalInteractions:14"],
Cell[3981, 130, 94532, 1367, 294, 2767, 228, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"LocalInteractions:14"]
}, Open  ]],
Cell[98528, 1500, 107, 3, 26, "Input",
  CellTags->"LocalInteractions:14"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

