(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     93903,       1629]*)
(*NotebookOutlinePosition[     96095,       1690]*)
(*  CellTagsIndexPosition[     96008,       1684]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["VonNeumann", "ObjectName",
  CellTags->"LocalInteractions:51"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["VonNeumann",
    FontFamily->"Courier"],
  "[",
  StyleBox["cols",
    FontSlant->"Italic"],
  StyleBox[", rows",
    FontSlant->"Italic"],
  "] creates a von Neumann lattice with ",
  StyleBox["cols",
    FontSlant->"Italic"],
  " columns and ",
  StyleBox["rows",
    FontSlant->"Italic"],
  " rows."
}], "Usage",
  CellTags->"LocalInteractions:51"],

Cell[TextData[{
  "\[FilledSmallSquare] By default, the lattice does not wrap at the edges. A \
von Neumann graph which wraps can be obtained by setting the option ",
  StyleBox["Wrap",
    FontFamily->"Courier"],
  " to ",
  StyleBox["True.",
    FontFamily->"Courier"]
}], "Notes",
  CellTags->"LocalInteractions:51"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection",
  CellTags->"LocalInteractions:51"],

Cell[BoxData[
    \(<< LocalInteractions`Graphs`\)], "Input",
  CellLabel->"In[1]:=",
  CellTags->"LocalInteractions:51"],

Cell["A von Neumann graph is the same thing as a grid graph.", "Text",
  CellTags->"LocalInteractions:51"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(VonNeumann[5, 5] // ShowGraph;\)\)], "Input",
  CellLabel->"In[2]:=",
  CellTags->"LocalInteractions:51"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.909091 0.0454545 0.909091 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 0 r
.005 w
[ ] 0 setdash
.04545 .04545 m
.27273 .04545 L
s
.04545 .04545 m
.04545 .27273 L
s
.27273 .04545 m
.5 .04545 L
s
.27273 .04545 m
.27273 .27273 L
s
.5 .04545 m
.72727 .04545 L
s
.5 .04545 m
.5 .27273 L
s
.72727 .04545 m
.95455 .04545 L
s
.72727 .04545 m
.72727 .27273 L
s
.95455 .04545 m
.95455 .27273 L
s
.04545 .27273 m
.27273 .27273 L
s
.04545 .27273 m
.04545 .5 L
s
.27273 .27273 m
.5 .27273 L
s
.27273 .27273 m
.27273 .5 L
s
.5 .27273 m
.72727 .27273 L
s
.5 .27273 m
.5 .5 L
s
.72727 .27273 m
.95455 .27273 L
s
.72727 .27273 m
.72727 .5 L
s
.95455 .27273 m
.95455 .5 L
s
.04545 .5 m
.27273 .5 L
s
.04545 .5 m
.04545 .72727 L
s
.27273 .5 m
.5 .5 L
s
.27273 .5 m
.27273 .72727 L
s
.5 .5 m
.72727 .5 L
s
.5 .5 m
.5 .72727 L
s
.72727 .5 m
.95455 .5 L
s
.72727 .5 m
.72727 .72727 L
s
.95455 .5 m
.95455 .72727 L
s
.04545 .72727 m
.27273 .72727 L
s
.04545 .72727 m
.04545 .95455 L
s
.27273 .72727 m
.5 .72727 L
s
.27273 .72727 m
.27273 .95455 L
s
.5 .72727 m
.72727 .72727 L
s
.5 .72727 m
.5 .95455 L
s
.72727 .72727 m
.95455 .72727 L
s
.72727 .72727 m
.72727 .95455 L
s
.95455 .72727 m
.95455 .95455 L
s
.04545 .95455 m
.27273 .95455 L
s
.27273 .95455 m
.5 .95455 L
s
.5 .95455 m
.72727 .95455 L
s
.72727 .95455 m
.95455 .95455 L
s
.025 w
.04545 .04545 Mdot
.27273 .04545 Mdot
.5 .04545 Mdot
.72727 .04545 Mdot
.95455 .04545 Mdot
.04545 .27273 Mdot
.27273 .27273 Mdot
.5 .27273 Mdot
.72727 .27273 Mdot
.95455 .27273 Mdot
.04545 .5 Mdot
.27273 .5 Mdot
.5 .5 Mdot
.72727 .5 Mdot
.95455 .5 Mdot
.04545 .72727 Mdot
.27273 .72727 Mdot
.5 .72727 Mdot
.72727 .72727 Mdot
.95455 .72727 Mdot
.04545 .95455 Mdot
.27273 .95455 Mdot
.5 .95455 Mdot
.72727 .95455 Mdot
.95455 .95455 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[2]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`002oooool3o`0003oooooo0ol0000nooooo`?o0000?_ooool3o`0003kooooo0ol0000=oooo
o`002_ooool5o`0003gooooo1Ol0000looooo`Go0000??ooool5o`0003cooooo1Ol0000<ooooo`00
2Oooool7o`0003_ooooo1ol0000jooooo`Oo0000>_ooool7o`0003[ooooo1ol0000;ooooo`002Ooo
ooooo`0000go00002oooool000Wooooo1ol0000kooooo`Oo0000>_ooool7o`0003[ooooo1ol0000j
ooooo`Oo00002oooool000[ooooo1Ol0000mooooo`Go0000??ooool5o`0003cooooo1Ol0000loooo
o`Go00003?ooool000_ooooo0ol0000oooooo`?o0000?_ooool3o`0003kooooo0ol0000nooooo`?o
00003Oooool000gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Ooo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00co
oooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`00
3Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<oooo
o`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000go
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<
ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool0
00gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=oooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?oo
ool000gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
3?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo
000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`002oooool3o`0003oooooo0ol0000noooo
o`?o0000?_ooool3o`0003kooooo0ol0000=ooooo`002_ooool5o`0003gooooo1Ol0000looooo`Go
0000??ooool5o`0003cooooo1Ol0000<ooooo`002Oooool7o`0003_ooooo1ol0000jooooo`Oo0000
>_ooool7o`0003[ooooo1ol0000;ooooo`002Oooooooo`0000go00002oooool000Wooooo1ol0000k
ooooo`Oo0000>_ooool7o`0003[ooooo1ol0000jooooo`Oo00002oooool000[ooooo1Ol0000moooo
o`Go0000??ooool5o`0003cooooo1Ol0000looooo`Go00003?ooool000_ooooo0ol0000oooooo`?o
0000?_ooool3o`0003kooooo0ol0000nooooo`?o00003Oooool000gooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool0
00gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=oooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?oo
ool000gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
3?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo
000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Ooo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00co
oooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`00
3Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<oooo
o`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000go
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<
ooooo`002oooool3o`0003oooooo0ol0000nooooo`?o0000?_ooool3o`0003kooooo0ol0000=oooo
o`002_ooool5o`0003gooooo1Ol0000looooo`Go0000??ooool5o`0003cooooo1Ol0000<ooooo`00
2Oooool7o`0003_ooooo1ol0000jooooo`Oo0000>_ooool7o`0003[ooooo1ol0000;ooooo`002Ooo
ooooo`0000go00002oooool000Wooooo1ol0000kooooo`Oo0000>_ooool7o`0003[ooooo1ol0000j
ooooo`Oo00002oooool000[ooooo1Ol0000mooooo`Go0000??ooool5o`0003cooooo1Ol0000loooo
o`Go00003?ooool000_ooooo0ol0000oooooo`?o0000?_ooool3o`0003kooooo0ol0000nooooo`?o
00003Oooool000gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Ooo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00co
oooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`00
3Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<oooo
o`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000go
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<
ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool0
00gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=oooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?oo
ool000gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
3?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo
000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`002oooool3o`0003oooooo0ol0000noooo
o`?o0000?_ooool3o`0003kooooo0ol0000=ooooo`002_ooool5o`0003gooooo1Ol0000looooo`Go
0000??ooool5o`0003cooooo1Ol0000<ooooo`002Oooool7o`0003_ooooo1ol0000jooooo`Oo0000
>_ooool7o`0003[ooooo1ol0000;ooooo`002Oooooooo`0000go00002oooool000Wooooo1ol0000k
ooooo`Oo0000>_ooool7o`0003[ooooo1ol0000jooooo`Oo00002oooool000[ooooo1Ol0000moooo
o`Go0000??ooool5o`0003cooooo1Ol0000looooo`Go00003?ooool000_ooooo0ol0000oooooo`?o
0000?_ooool3o`0003kooooo0ol0000nooooo`?o00003Oooool000gooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool0
00gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=oooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?oo
ool000gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
3?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo
000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Ooo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00co
oooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`00
3Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<oooo
o`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool000go
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<
ooooo`003Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo000;ooooo`?o
0000?oooool3o`0003kooooo0ol0000nooooo`?o0000?_ooool3o`0000gooooo000:ooooo`Go0000
?Oooool5o`0003cooooo1Ol0000looooo`Go0000??ooool5o`0000cooooo0009oooooooo00003Ol0
000;ooooo`002Oooool7o`0003_ooooo1ol0000jooooo`Oo0000>_ooool7o`0003[ooooo1ol0000;
ooooo`002Oooool7o`0003_ooooo1ol0000jooooo`Oo0000>_ooool7o`0003[ooooo1ol0000;oooo
o`002_ooool5o`0003gooooo1Ol0000looooo`Go0000??ooool5o`0003cooooo1Ol0000<ooooo`00
2oooool3o`0003oooooo0ol0000nooooo`?o0000?_ooool3o`0003kooooo0ol0000=ooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0500054, -0.0500054, \
0.00383279, 0.00383279}},
  CellTags->"LocalInteractions:51"]
}, Open  ]],

Cell[TextData[{
  "von Neumann graphs can be embedded on the torus by setting the option ",
  StyleBox["Wrap",
    FontFamily->"Courier"],
  " to ",
  StyleBox["True",
    FontFamily->"Courier"],
  ". The graph is shaken before displayed so that the wrapped edges can be \
seen."
}], "Text",
  CellTags->"LocalInteractions:51"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShakeGraph[\[IndentingNewLine]VonNeumann[5, 5, Wrap \[Rule] True], 
          0.3\[IndentingNewLine]] // ShowGraph;\)\)], "Input",
  CellLabel->"In[5]:=",
  CellTags->"LocalInteractions:51"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.909091 0.0337187 0.934993 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 0 r
.005 w
[ ] 0 setdash
.05802 .04675 m
.26621 .11191 L
s
.05802 .04675 m
.89317 .11987 L
s
.05802 .04675 m
.05737 .30636 L
s
.05802 .04675 m
.04545 .88889 L
s
.26621 .11191 m
.49856 .10994 L
s
.26621 .11191 m
.25539 .27294 L
s
.26621 .11191 m
.30621 .89051 L
s
.49856 .10994 m
.65977 .0763 L
s
.49856 .10994 m
.54156 .34288 L
s
.49856 .10994 m
.56145 .93173 L
s
.65977 .0763 m
.89317 .11987 L
s
.65977 .0763 m
.72179 .31464 L
s
.65977 .0763 m
.69541 .95325 L
s
.89317 .11987 m
.93366 .31927 L
s
.89317 .11987 m
.95455 .93311 L
s
.05737 .30636 m
.25539 .27294 L
s
.05737 .30636 m
.93366 .31927 L
s
.05737 .30636 m
.0871 .50259 L
s
.25539 .27294 m
.54156 .34288 L
s
.25539 .27294 m
.28467 .51293 L
s
.54156 .34288 m
.72179 .31464 L
s
.54156 .34288 m
.52565 .50541 L
s
.72179 .31464 m
.93366 .31927 L
s
.72179 .31464 m
.74306 .51632 L
s
.93366 .31927 m
.90553 .4528 L
s
.0871 .50259 m
.28467 .51293 L
s
.0871 .50259 m
.90553 .4528 L
s
.0871 .50259 m
.04927 .70906 L
s
.28467 .51293 m
.52565 .50541 L
s
.28467 .51293 m
.29287 .72472 L
s
.52565 .50541 m
.74306 .51632 L
s
.52565 .50541 m
.51053 .723 L
s
.74306 .51632 m
.90553 .4528 L
s
.74306 .51632 m
.71842 .69673 L
s
.90553 .4528 m
.9267 .71628 L
s
.04927 .70906 m
.29287 .72472 L
s
.04927 .70906 m
.9267 .71628 L
s
.04927 .70906 m
.04545 .88889 L
s
.29287 .72472 m
.51053 .723 L
s
.29287 .72472 m
.30621 .89051 L
s
.51053 .723 m
.71842 .69673 L
s
.51053 .723 m
.56145 .93173 L
s
.71842 .69673 m
.9267 .71628 L
s
.71842 .69673 m
.69541 .95325 L
s
.9267 .71628 m
.95455 .93311 L
s
.04545 .88889 m
.30621 .89051 L
s
.04545 .88889 m
.95455 .93311 L
s
.30621 .89051 m
.56145 .93173 L
s
.56145 .93173 m
.69541 .95325 L
s
.69541 .95325 m
.95455 .93311 L
s
.025 w
.05802 .04675 Mdot
.26621 .11191 Mdot
.49856 .10994 Mdot
.65977 .0763 Mdot
.89317 .11987 Mdot
.05737 .30636 Mdot
.25539 .27294 Mdot
.54156 .34288 Mdot
.72179 .31464 Mdot
.93366 .31927 Mdot
.0871 .50259 Mdot
.28467 .51293 Mdot
.52565 .50541 Mdot
.74306 .51632 Mdot
.90553 .4528 Mdot
.04927 .70906 Mdot
.29287 .72472 Mdot
.51053 .723 Mdot
.71842 .69673 Mdot
.9267 .71628 Mdot
.04545 .88889 Mdot
.30621 .89051 Mdot
.56145 .93173 Mdot
.69541 .95325 Mdot
.95455 .93311 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[5]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`003oooool3o`000?oooooo3oooool000kooooo1Ol0003oooooo`kooooo000=ooooo`Oo0000
ooooool=ooooo`003Oooool:o`000?oooooo2_ooool000gooooo2Ol000000ooooooo0000o`000009
o`000?kooooo000>ooooo`Go00000oooool3o`0000Wooooo3?l0003booooo`003oooool3o`0000Oo
oooo0ol0000Booooo`_o0000ioooool0013ooooo00?o0000ooooooooool02Oooool3o`0001[ooooo
2ol0003Looooo`004?ooool00ol0003oooooooooo`0<ooooo`?o00008_ooool<o`0006cooooo0ol0
001Qooooo`004?ooool00ol0003oooooooooo`0?ooooo`Co0000:_ooool;o`00063ooooo1Ol0001P
ooooo`004?ooool00ol0003oooooooooo`0Cooooo`?o0000<_ooool<o`0005?ooooo1ol0001Ooooo
o`004?ooool00ol0003oooooooooo`0Fooooo`?o0000>oooool;o`0004Sooooo1ol0001Oooooo`00
4?ooool00ol0003oooooooooo`0Iooooo`?o0000@oooool<o`0003Sooooo4?l0001Jooooo`004?oo
ool00ol0003oooooooooo`0Looooo`?o0000C?ooool;o`0002Sooooo1Ol00005ooooo`Go00001_oo
ool5o`0005Gooooo000@ooooo`03o`000?oooooooooo01oooooo0ol0001Dooooo`_o00006Oooool4
o`0000_ooooo0ol0000<ooooo`Go0000D?ooool0013ooooo00?o0000ooooooooool08_ooool3o`00
05cooooo3?l00008ooooo`Go00004?ooool2o`00017ooooo1Ol0001;ooooo`004?ooool00ol0003o
ooooooooo`0Uooooo`Co0000I?ooool;o`0001;ooooo0_l0000Fooooo`Go0000A_ooool0013ooooo
00?o0000ooooooooool0:Oooool3o`00063ooooo1Ol00007ooooo`co00001_ooool2o`0001_ooooo
1_l00010ooooo`004?ooool00ol0003oooooooooo`0/ooooo`?o0000C?ooool3o`0000Wooooo1Ol0
000Hooooo`_o00007_ooool5o`0003_ooooo000@ooooo`03o`000?oooooooooo02oooooo0ol00006
ooooo`?o0000?oooool5o`0000Cooooo1?l0000Sooooo`03o`000?oooooo000000;ooooo3?l0000G
ooooo`Go0000=_ooool0013ooooo00?o0000ooooooooool0<_ooool3o`0000;ooooo1Ol0000moooo
o`[o00009oooool00ol0003oooooo`00000>ooooo`_o00004Oooool5o`00037ooooo000@ooooo`03
o`000?oooooooooo03Gooooo2?l0000NooooobGo0000:_ooool00ol0003oooooo`00000Iooooo`_o
00002oooool5o`0000_ooooo0ol0000Nooooo`004?ooool00ol0003oooooooooo`0fooooobGo0000
7_ooool7o`0002[ooooo00Co0000oooooooooooo00008oooool<o`0000Cooooo1Ol00005ooooo`Go
00007Oooool0013ooooo00?o0000ooooooooool0=_ooool7o`0003gooooo1Ol0000[ooooo`04o`00
0?ooooooooooo`0002oooooo5?l0000Looooo`004?ooool00ol0003oooooooooo`0gooooo`Go0000
?oooool3o`0002cooooo00Co0000oooooooooooo0000>_ooool9o`0001cooooo000@ooooo`03o`00
0?oooooooooo03Sooooo0ol00011ooooo`;o0000;Oooool01?l0003oooooooooool0000kooooo`Oo
00007?ooool0013ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`10ooooo`;o0000
;Oooool01?l0003oooooooooool0000looooo`Go00007Oooool0013ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`10ooooo`;o0000;Oooool01?l0003oooooooooool0000mooooo`?o
00007_ooool0013ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`10ooooo`;o0000
;Oooool01?l0003oooooooooool0000nooooo`;o00007_ooool0013ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo02_ooooo00Go0000oooooooooooo
ooooo`00000mooooo`;o00007_ooool0013ooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`11ooooo`;o0000;?ooool01Ol0003ooooooooooooooooo000003gooooo0_l0000Nooooo`00
4?ooool00ol0003oooooooooo`0hooooo`;o0000@oooool2o`0002cooooo00Go0000oooooooooooo
ooooo`00000mooooo`;o00007_ooool0013ooooo00?o0000ooooooooool0>?ooool2o`0004?ooooo
0_l0000/ooooo`05o`000?ooooooooooooooool00000?_ooool00ol0003oooooooooo`0Looooo`00
4?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooo000004;ooooo0_l0000/ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0>oooool2o`0001gooooo000@ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooool00000@_ooool2o`0002cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0kooooo`;o00007Oooool0013ooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooo`000012ooooo`;o0000;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo0_l0000Mooooo`004?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooo0000
04;ooooo00?o0000ooooool00000:oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
03_ooooo0_l0000Mooooo`004?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooo000004;o
oooo00?o0000ooooool00000:oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03[o
oooo0_l0000Mooooo`004?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooo000004;ooooo
00?o0000ooooool00000:oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooool000007?ooool0013ooooo00?o0000ooooooooool0>?ooool00ol0003oooooo`00
0012ooooo`03o`000?oooooo000002_ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooo000001cooooo000@ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooool00000@_ooool00ol0003oooooo`00000[ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0>_ooool00ol0003oooooo`00000Looooo`004?ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooo000004;ooooo00?o0000ooooool00000:oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooool000007?ooool0013ooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooo`000013ooooo`03o`000?oooooo000002[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo000001cooooo000@ooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooool00000@oooool00ol0003oooooo`00000Zooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0>Oooool01?l0003oooooooooool0000Kooooo`00
3oooool2o`0003[ooooo00?o0000ooooool00000@oooool00ol0003oooooo`00000Zooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0>Oooool01?l0003oooooooooool0000Kooooo`00
3oooool2o`0003[ooooo00?o0000ooooool00000@oooool00ol0003oooooo`00000Zooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0>?ooool01?l0003oooooooooool0000Kooooo`00
3oooool2o`0003Wooooo00Co0000oooooooooooo0000@oooool00ol0003oooooo`00000Zooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooo`00000Kooooo`00
3oooool2o`0003Wooooo00Co0000oooooooooooo0000@oooool01?l0003oooooooooool0000Yoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooo`00000Koooo
o`003oooool2o`0003Wooooo00Co0000oooooooooooo0000@oooool01?l0003oooooooooool0000Y
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>?ooool01?l0003oooooooooool0
000Jooooo`003oooool2o`0003Wooooo00Co0000oooooooooooo0000@oooool01?l0003ooooooooo
ool0000Yooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>?ooool01?l0003ooooo
ooooool0000Jooooo`003oooool2o`0003Wooooo00Co0000oooooooooooo0000@oooool01?l0003o
ooooooooool0000Zooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>?ooool01?l0
003oooooooooool0000Jooooo`003oooool2o`0003Wooooo00Co0000oooooooooooo0000@oooool0
1?l0003oooooooooool0000Zooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>?oo
ool01?l0003oooooooooool0000Jooooo`003oooool2o`0003Wooooo00Co0000oooooooooooo0000
@oooool01?l0003oooooooooool0000Zooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0=oooool01?l0003oooooooooool0000Jooooo`003oooool2o`0003Wooooo00Go0000oooooooo
ooooooooo`000012ooooo`05o`000?ooooooooooooooool00000:Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo03Oooooo00Go0000ooooooooooooooooo`00000Iooooo`003oooool2
o`0003Wooooo00Go0000ooooooooooooooooo`000012ooooo`05o`000?ooooooooooooooool00000
:Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Oooooo00Go0000oooooooooooo
ooooo`00000Iooooo`003oooool2o`0003Wooooo00Go0000ooooooooooooooooo`000013ooooo`04
o`000?ooooooooooo`0002Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0goooo
o`05o`000?ooooooooooooooool000006Oooool000oooooo0_l0000iooooo`05o`000?oooooooooo
ooooool00000@oooool01?l0003oooooooooool0000Yooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0=_ooool01Ol0003ooooooooooooooooo000001Wooooo000?ooooo`;o0000>Ooo
ool01Ol0003ooooooooooooooooo000004?ooooo00Co0000oooooooooooo0000:Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo03Kooooo00Go0000ooooooooooooooooo`00000Ioooo
o`003oooool2o`0003Wooooo00Go0000ooooooooooooooooo`000013ooooo`05o`000?oooooooooo
ooooool00000:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Kooooo00Go0000
ooooooooooooooooo`00000Iooooo`003oooool2o`0003Wooooo00Go0000ooooooooooooooooo`00
0013ooooo`05o`000?ooooooooooooooool00000:?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03Oooooo00Go0000ooooooooooooooooo`00000Hooooo`003oooool2o`0003Wooooo
00Go0000ooooooooooooooooo`000013ooooo`05o`000?ooooooooooooooool00000:?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo03Kooooo00Go0000ooooooooooooooooo`00000H
ooooo`003oooool2o`0003Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`11oooo
o`05o`000?ooooooooooooooool00000:?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo03Kooooo00Go0000ooooooooooooooooo`00000Hooooo`003oooool2o`0003Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`11ooooo`05o`000?ooooooooooooooool00000:?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Kooooo00Go0000oooooooooooooooo
o`00000Hooooo`003oooool2o`0003Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`11ooooo`05o`000?ooooooooooooooool00000:?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo03Kooooo00Go0000ooooooooooooooooo`00000Hooooo`003oooool2o`0003Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eooooo`003oooool2o`0003Oooooo0ol0
0003ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01Gooooo000?ooooo`;o0000=_ooool5o`0000;ooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool05Oooool000oooooo0_l0000eooooo`Oo000000?oooooo`000?ooool0@_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05Oooool000oo
oooo0_l0000eooooo`Oo000000?oooooo`000?ooool0@oooool01Ol0003ooooooooooooooooo0000
02Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool05Oooool000oooooo0_l0000^oooooa7o0000@oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool000oooooo
0_l0000Xooooo`Ko00002?ooool5o`0000;ooooo00?o0000ooooool000000ol0000oooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`003ooo
ool2o`0002;ooooo1_l0000?ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`Co0000>ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?oo
ool000oooooo0_l0000Kooooo`Oo00005_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo1?l0000gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Dooooo`003oooool2o`0001Gooooo1_l0000Nooooo`05o`000?oooooooooo
ooooool000003Oooool5o`0003;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01Cooooo000?ooooo`?o00003_ooool6o`0002Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0?ooooo`Co0000;_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool000kooooo1Ol00006ooooo`Oo
0000:_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo1?l0000Zooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`00
3Oooool<o`00037ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`Co0000
9_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
4oooool000gooooo8ol0000Jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06ooo
ool4o`0002;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo00_ooooo0ol0000cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04ooo
ool000gooooo1ol0000Looooocoo00000_ooool4o`0001kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00[ooooo1Ol0000booooo`03o`000?oooooo
oooo00?ooooo0ol0000Cooooo`003_ooool5o`0003Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Mooooocoo00004_ooool00ol0003oooooooooo`09ooooo`Oo0000<Oooool00ol0
003oooooooooo`02ooooo`Go00004_ooool000oooooo0ol0000hooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool09oooool4o`0001Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Boooood3o00005_ooool01?l0003oooooooooooooool7o`00017ooooo000?ooooo`03
o`000?oooooo000003Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0[ooooo`Co
00004oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool00_ooool>o`0001[ooooo8_l0000Aooooo`003oooool00ol0003oooooo`00000iooooo`05o`00
0?ooooooooooooooool00000<Oooool4o`0000oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Rooooo`Ko00002?ooool5o`0003;ooooo00Co0000oooooooooooooooo1ol0000Aoooo
o`003oooool00ol0003oooooo`00000iooooo`05o`000?ooooooooooooooool00000=Oooool5o`00
00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Kooooo`Oo000000?oooooo`00
0?ooool03?ooool3o`0003?ooooo00?o0000ooooooooool00_ooool5o`0001;ooooo000?ooooo`03
o`000?oooooo000003Wooooo00Go0000ooooooooooooooooo`00000jooooo`Co00001_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo1_l00008ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`03ooooo`?o00004oooool000oo
oooo00?o0000ooooool00000>Oooool01Ol0003ooooooooooooooooo000003kooooo1?l00002oooo
o`03o`000?oooooooooo00?ooooo0ol0000>ooooo`Oo00003_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Coooo
o`003oooool00ol0003oooooo`00000iooooo`05o`000?ooooooooooooooool00000@_ooool4o`00
00?ooooo1Ol00007ooooo`Ko00005Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`003oooool01?l0003o
ooooooooool0000hooooo`05o`000?ooooooooooooooool00000A?ooool00ol0003oooooo`00000>
o`0001_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool04oooool000oooooo00Co0000oooooooooooo0000>?ooool0
1Ol0003ooooooooooooooooo000004Cooooo00Co0000oooooooooooooooo1ol0000Qooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01?ooooo000?ooooo`04o`000?ooooooooooo`0003Sooooo00Go0000oooooooooooo
ooooo`000014ooooo`04o`000?ooooooooooooooo`Oo00008Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo03;ooooo00Go0000ooooooooooooooooo`00000Fooooo`003oooool01?l0
003oooooooooool0000hooooo`05o`000?ooooooooooooooool00000A?ooool00ol0003ooooooooo
o`02ooooo`Go00008_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03;ooooo00Go
0000ooooooooooooooooo`00000Fooooo`003oooool01?l0003oooooooooool0000iooooo`04o`00
0?ooooooooooo`0004Cooooo00?o0000ooooooooool00oooool3o`0002?ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0booooo`05o`000?ooooooooooooooool000005_ooool000oo
oooo00Co0000oooooooooooo0000>Oooool01?l0003oooooooooool00014ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo03;ooooo00Go0000ooooooooooooooooo`00000Fooooo`003oooool01?l0003oooooooooool0
000iooooo`04o`000?ooooooooooo`0004Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<_ooool01Ol0003ooooo
oooooooooooo000001Kooooo000?ooooo`05o`000?ooooooooooooooool00000>?ooool01Ol0003o
oooooooooooooooo000004Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<_ooool01?l0003oooooooooool0000G
ooooo`003oooool01Ol0003ooooooooooooooooo000003Sooooo00Go0000ooooooooooooooooo`00
0014ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo037ooooo00Co0000oooooooooooo00005oooool000oooooo00Go
0000ooooooooooooooooo`00000hooooo`05o`000?ooooooooooooooool00000A?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0aooooo`04o`000?ooooooooooo`0001Oooooo000?ooooo`05o`000?oooooooooooooo
ool00000>?ooool01Ol0003ooooooooooooooooo000004Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<Oooool0
1?l0003oooooooooool0000Gooooo`003oooool01Ol0003ooooooooooooooooo000003Sooooo00Go
0000ooooooooooooooooo`000014ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo037ooooo00Co0000oooooooooooo
00005oooool000oooooo00Go0000ooooooooooooooooo`00000iooooo`04o`000?ooooooooooo`00
04Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0<Oooool00ol0003oooooo`00000Hooooo`003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo03Kooooo00Co0000oooooooooooo0000A?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0booooo`;o00006?ooool000oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0fooooo`04o`000?ooooooooooo`0004Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<_ooool2o`00
01Sooooo000?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=_ooool01?l0003o
ooooooooool00014ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo03;ooooo0_l0000Hooooo`003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo03Kooooo00Co0000oooooooooooo0000A?ooool01Ol0
003ooooooooooooooooo000002Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo01Oooooo000?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0=_ooool01?l0003oooooooooool00014ooooo`05o`000?ooooooooooooooool000009ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool05ooo
ool000oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0fooooo`04o`000?oooooo
ooooo`0004Cooooo00Go0000ooooooooooooooooo`00000Wooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Gooooo`003oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo03Gooooo00Co0000oooooooooooo0000A?ooool01Ol0003ooooo
oooooooooooo000002Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo01Oooooo000?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
=Oooool01?l0003oooooooooool00015ooooo`04o`000?ooooooooooo`0002Oooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Oooooo000?ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0=_ooool00ol0003oooooo`000015ooooo`04
o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0`oooo
o`;o00006Oooool000oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0fooooo`03
o`000?oooooo000004Gooooo00Co0000oooooooooooo00009oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo033ooooo0_l0000Iooooo`003oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooool00000AOooool01?l0003oooooooooool0000Woooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<?ooool2o`0001Wooooo000?ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0=_ooool00ol0003oooooo`000015ooooo`04
o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0`oooo
o`;o00006Oooool000oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0fooooo`03
o`000?oooooo000004Gooooo00?o0000ooooool00000:?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo033ooooo0_l0000Iooooo`003oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooool00000AOooool00ol0003oooooo`00000Xooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0;oooool00ol0003oooooo`00000Iooooo`003ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Gooooo00Co0000oooooooooooo0000
A?ooool00ol0003oooooo`00000Xooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
;oooool01?l0003oooooooooool0000Hooooo`003oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo03Gooooo00Co0000oooooooooooo0000A?ooool00ol0003oooooo`00000Xooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0;_ooool01?l0003oooooooooool0000Hoooo
o`003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooool0
0000A?ooool00ol0003oooooo`00000Xooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0;_ooool01?l0003oooooooooool0000Hooooo`003oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooool00000A?ooool00ol0003oooooo`00000Xooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0;?ooool3o`0000;ooooo00?o0000oooooooo
ool05_ooool000oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooo000004Cooooo00?o0000ooooool00000:?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo02_ooooo1Ol000000ooooooo0000ooooo`0Gooooo`003oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooool00000A?ooool00ol0003oooooo`00
000Xooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09Oooool=o`0001Sooooo000?
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooo`000015
ooooo`;o0000:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo3ol00004
ooooo`Wo00006?ooool000oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooo000004Gooooo0_l0000Xooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool01_ooool@o`00017ooooo0_l000000ooooooo0000o`000006o`0001Sooooo000?ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooo`000015ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool02?ooool@o`0001oooooo0_l00004ooooo`Go
000000?oooooo`000?ooool05oooool000oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooo000004Gooooo00?o0000ooooooooool08oooool?o`0000Oooooo
00?o0000ooooooooool08_ooool3o`0000Oooooo0ol00002ooooo`03o`000?oooooooooo01Kooooo
000?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooo`00
0015ooooo`03o`000?oooooooooo01?ooooo4?l00004ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool07oooool2o`0000_ooooo00Go0000ooooooooooooooooo`00000Hooooo`003_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Gooooo0_l00015ooooo`03o`000?oo
oooooooo00Cooooo3ol0000Eooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07?oo
ool3o`0000gooooo00Go0000ooooooooooooooooo`00000Hooooo`003_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo03Gooooo0_l0000loooooa3o00009?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01[ooooo0_l0000Aooooo`04o`000?ooooooooooo`0001Sooooo
000>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=Oooool2o`0002cooooo4?l0
0009ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Gooooo`?o00004oooool01?l0003oooooooooool0000Hooooo`003_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo03Gooooo0_l0000Mooooo`oo00006Oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05Oooool2o`0001Kooooo00Go
0000ooooooooooooooooo`00000Gooooo`003_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo03Gooooo0_l0000=oooooa3o0000:?ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool04oooool2o`0001Sooooo00Go0000oooooooooooooooo
o`00000Gooooo`003_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Gooooo3ol0
000hooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0@ooooo`?o00006_ooool01Ol0003ooooooooooooooooo000001Oooooo000>ooooo`03o`000?oo
oooooooo00Kooooo0ol0000Voooooa;o0000A?ooool2o`0002[ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0>ooooo`;o00007Oooool01Ol0003ooooooooooooooooo000001Oooooo
000>ooooo`03o`000?oooooooooo00Gooooo1Ol0000Eoooooa3o00004?ooool2o`0004?ooooo0ol0
000Zooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02oooool3o`0001oooooo00Go
0000ooooooooooooooooo`00000Gooooo`003_ooool00ol0003oooooooooo`04ooooo`Oo00001Ooo
ool?o`00023ooooo0_l00012ooooo`Go0000:Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Wooooo0_l0000Rooooo`05o`000?ooooooooooooooool000005oooool000kooooo00?o
0000ooooooooool01?ooool>o`0002gooooo0ol00010ooooo`Oo0000:?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00Gooooo0ol0000Tooooo`05o`000?ooooooooooooooool00000
5oooool000kooooo00?o0000ooooooooool01?ooool7o`0000Oooooo4ol0000Iooooo`Go0000<Ooo
oolMo`00023ooooo00?o0000ooooooooool03oooool3o`0000Cooooo0_l0000Wooooo`05o`000?oo
ooooooooooooool000005oooool000kooooo00?o0000ooooooooool01Oooool5o`0001_ooooo4ol0
0005ooooo`Oo00003OoooolSo`0000kooooo1ol00008oooooaGo00002oooool00ol0003ooooooooo
o`0>ooooo`Go000000?oooooo`000?l00000:Oooool01Ol0003ooooooooooooooooo000001Oooooo
000>ooooo`03o`000?oooooooooo00Kooooo0ol0000_oooooaWo0000<_ooool5o`0001kooooo5Ol0
0006ooooo`Oo0000:oooool01Ol0003ooooooooooooooooo000001Oooooo000>ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0<oooool7o`00043ooooo1?l0000Yooooo`03o`000?oo
oooooooo00Oooooo3Ol0000[ooooo`05o`000?ooooooooooooooool000005oooool000kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0dooooo`Go0000@_ooool00ol0003oooooo`00
000Yooooo`03o`000?oooooooooo00gooooo1ol0000/ooooo`04o`000?ooooooooooo`0001Oooooo
000>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=Oooool3o`0004?ooooo00?o
0000ooooool00000:Oooool00ol0003oooooooooo`0>ooooo`Go0000;Oooool01?l0003ooooooooo
ool0000Gooooo`003_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Kooooo0_l0
0013ooooo`03o`000?oooooo000002Wooooo00?o0000ooooooooool03oooool3o`0002kooooo00Go
0000ooooooooooooooooo`00000Fooooo`003_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo03Kooooo0_l00013ooooo`03o`000?oooooo000002Wooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0]ooooo`05o`000?ooooooooooooooool000005_ooool000kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0gooooo`;o0000@oooool00ol0003oooooo`00
000Yooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;_ooool01Ol0003ooooooooo
oooooooo000001Kooooo000>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=ooo
ool2o`0004;ooooo00Co0000oooooooooooo0000:Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo02kooooo00Go0000ooooooooooooooooo`00000Fooooo`003_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo03Oooooo0_l00012ooooo`04o`000?ooooooooooo`0002Wo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0^ooooo`05o`000?oooooooooooooo
ool000005_ooool000kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0gooooo`;o
0000@_ooool01?l0003oooooooooool0000Yooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0;_ooool01Ol0003ooooooooooooooooo000001Kooooo000>ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0=oooool2o`0004;ooooo00Go0000ooooooooooooooooo`00000X
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;_ooool01Ol0003ooooooooooooo
oooo000001Kooooo000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`10ooooo`05o`000?ooooooooooooooool00000:?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo02kooooo00Go0000ooooooooooooooooo`00000Fooooo`003_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0@?oo
ool01Ol0003ooooooooooooooooo000002Sooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0^ooooo`05o`000?ooooooooooooooool000005_ooool000kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo043ooooo00Go0000oooooooooooo
ooooo`00000Xooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0;oooool01Ol0003o
oooooooooooooooo000001Kooooo000>ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`10ooooo`05o`000?ooooooooooooooool00000:Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo02oooooo00Go0000ooooooooooooooooo`00000F
ooooo`003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool0@?ooool01Ol0003ooooooooooooooooo000002Wooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0`ooooo`04o`000?ooooooooooo`0001Kooooo000>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`10ooooo`05o`000?oooooo
ooooooooool00000:Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo033ooooo00Co
0000oooooooooooo00005_ooool000kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo043ooooo00Go0000ooooooooooooooooo`00000Yooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0<?ooool01?l0003oooooooooool0000Fooooo`00
3_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03[ooooo0_l00011ooooo`05o`00
0?ooooooooooooooool00000:Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo033o
oooo00Go0000ooooooooooooooooo`00000Eooooo`003_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03[ooooo0_l00011ooooo`05o`000?ooooooooooooooool00000:Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo033ooooo00Go0000ooooooooooooooooo`00000E
ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03[ooooo0_l00011oooo
o`05o`000?ooooooooooooooool00000:Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo037ooooo00Go0000ooooooooooooooooo`00000Eooooo`003_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo03[ooooo0_l00011ooooo`05o`000?ooooooooooooooool00000:Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo037ooooo00Go0000oooooooooooooooo
o`00000Eooooo`003_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03_ooooo0_l0
0010ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo037ooooo00Go0000ooooooooooooooooo`00000Eooooo`003_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03_ooooo0_l00010ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo037ooooo00Go0000ooooooooooooooooo`00000Eooooo`003_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo03_ooooo0_l00010ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo037ooooo00Go
0000ooooooooooooooooo`00000Eooooo`003_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03_ooooo0_l00010ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo037ooooo00Go0000oooooooooooooooo
o`00000Eooooo`003_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03_ooooo0_l0
0010ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo037ooooo00Go0000ooooooooooooooooo`00000Eooooo`003_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03cooooo0_l00010ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo03?ooooo00Co0000oooooooooooo00005Oooool000kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0looooo`;o0000@?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0cooooo`04o`000?oo
ooooooooo`0001Gooooo000>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0??oo
ool2o`00043ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0<oooool01?l0003oooooooooool0000Eooooo`003_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03cooooo0_l00010ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo03?ooooo00Co0000oooooooooooo00005Oooool000kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<ooo
ool01?l0003oooooooooool0000Eooooo`003_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0cooooo`05o`000?oo
ooooooooooooool000005?ooool000kooooo00Go0000ooooooooooooooooo`000010ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0<oooool01Ol0003ooooooooooooooooo000001Co
oooo000>ooooo`05o`000?ooooooooooooooool00000@?ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo03?ooooo00Go0000ooooooooooooooooo`00000Dooooo`003_ooool01Ol0003o
oooooooooooooooo0000043ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0doooo
o`05o`000?ooooooooooooooool000005?ooool000kooooo00Go0000ooooooooooooooooo`000010
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0=?ooool01Ol0003ooooooooooooo
oooo000001Cooooo000>ooooo`05o`000?ooooooooooooooool00000@?ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo03Cooooo00Go0000ooooooooooooooooo`00000Dooooo`003_oo
ool01?l0003oooooooooool00011ooooo`;o0000?_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0dooooo`05o`00
0?ooooooooooooooool000005?ooool000kooooo00Co0000oooooooooooo0000@Oooool2o`0003ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0=?ooool01Ol0003ooooooooooooooooo000001Cooooo000>ooooo`04
o`000?ooooooooooo`00047ooooo0_l0000nooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Gooooo00Co0000oooo
oooooooo00005?ooool000kooooo00Co0000oooooooooooo0000@Oooool2o`0003kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0=Oooool01?l0003oooooooooool0000Dooooo`003_ooool01?l0003oooooooooool0
0011ooooo`;o0000?_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0fooooo`04o`000?ooooooooooo`0001Cooooo
000>ooooo`04o`000?ooooooooooo`00047ooooo0_l0000nooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Kooooo
00Co0000oooooooooooo00005?ooool000kooooo00?o0000ooooool00000@_ooool2o`0003kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0=_ooool01?l0003oooooooooool0000Dooooo`003_ooool00ol0003ooooo
o`000012ooooo`;o0000?_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0fooooo`04o`000?ooooooooooo`0001Co
oooo000>ooooo`03o`000?oooooo000004;ooooo0_l0000nooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Kooooo
00Go0000ooooooooooooooooo`00000Cooooo`003_ooool00ol0003oooooo`000012ooooo`;o0000
?_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0fooooo`05o`000?ooooooooooooooool000004oooool000kooooo
00?o0000ooooool00000@_ooool2o`0003kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=_ooool01Ol0003ooooo
oooooooooooo000001?ooooo000>ooooo`;o0000@oooool2o`0003kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
=oooool01Ol0003ooooooooooooooooo000001?ooooo000>ooooo`;o0000@oooool2o`0003kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo
0ol0000hooooo`05o`000?ooooooooooooooool000004oooool000kooooo0_l00014ooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00Gooooo1Ol0000gooooo`05o`000?ooooooooooooooool000004oooool000kooooo
0_l00014ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00?ooooo2_l0000dooooo`05o`000?ooooooooooooooool0
00004oooool000gooooo0ol00014ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Tooooo`Oo000000?oooooo`000?l000001Ol00002ooooo`[o0000
:oooool01?l0003oooooooooool0000Cooooo`003?ooool5o`0004?ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01cooooo2?l000000ooooooo0000
ooooo`05ooooo`Oo00003?ooool:o`00027ooooo00Co0000oooooooooooo00004oooool000_ooooo
1ol00012ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Eooooo`Oo00002Oooool00ol0003oooooooooo`05ooooo`Go00005oooool9o`0001Oooooo
0ol000000ooooooo0000ooooo`0Booooo`002ooooom3o`0000Kooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo2?l0000@ooooo`03o`000?oo
oooooooo00Kooooo0ol0000Qooooo`[o00003?ooool6o`0001?ooooo000;ooooo`Oo00001_oooolA
o`0002GoooooOOl00003ooooo`03o`000?oooooooooo02[ooooo2_l000000ooooooo0000o`000005
o`0001?ooooo000<ooooo`Go00006?oooolBo`0001Oooooo1?l0000jooooo`Go00001oooool9o`00
01oooooo00?o0000ooooooooool01?oooom2o`0001?ooooo000=ooooo`?o0000:ooooolAo`0000Go
oooo1Ol0000iooooo`ko00009oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Ko
oooo2?l0000Booooo`003_ooool00ol0003oooooooooo`0koooood[o00001_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=oooool5o`000003oooo
ool0003ooooo017ooooo000>ooooo`03o`000?oooooooooo03oooooo1ol0000hooooo`Oo00001_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>?oo
ool3o`0000;ooooo00?o0000ooooooooool04?ooool000kooooo00?o0000ooooooooool0?oooool7
o`0003Wooooo1Ol00008ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0iooooo`05o`000?ooooooooooooooool000004_ooool000kooooo00?o0000
ooooooooool0@?ooool5o`0003_ooooo0ol00009ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0jooooo`04o`000?ooooooooooo`0001;ooooo000>
ooooo`03o`000?oooooooooo047ooooo1?l0000mooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03[ooooo00Co0000
oooooooooooo00004_ooool000kooooo00?o0000ooooooooool0@oooool2o`0003gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0>_ooool01?l0003oooooooooool0000Booooo`003_ooool00ol0003oooooooooo`13
ooooo`;o0000?Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0jooooo`04o`000?ooooooooooo`0001;ooooo000>
ooooo`03o`000?oooooooooo04?ooooo0_l0000nooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03[ooooo00Co0000
oooooooooooo00004_ooool000kooooo00?o0000ooooooooool0@oooool2o`0003kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0>_ooool01?l0003oooooooooool0000Booooo`003Oooool2o`0004Kooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0001;ooooo000=
ooooo`;o0000A_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03_ooooo00Co0000
oooooooooooo00004_ooool000gooooo0_l00016ooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0??ooool00ol0003oooooo`00000Booooo`003Oooool2o`0004Kooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0looooo`03o`000?oooooo000001;ooooo000=ooooo`;o
0000A_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03cooooo00Co0000oooooooo
oooo00004Oooool000gooooo0_l00016ooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0??ooool01?l0003oooooooooool0000Aooooo`003Oooool2o`0004Kooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0looooo`04o`000?ooooooooooo`00017ooooo000=ooooo`;o
0000A_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03cooooo00Co0000oooooooo
oooo00004Oooool000gooooo0_l00016ooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0??ooool01?l0003oooooooooool0000Aooooo`003Oooool2o`0004Kooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo0000017ooooo000=ooooo`;o0000
A_ooool2o`00043ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0?_ooool00ol0003oooooo`00000Aooooo`003Ooo
ool2o`0004Kooooo0_l00010ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03kooooo00?o0000ooooool000004Ooo
ool000gooooo0_l00016ooooo`;o0000@?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
0000017ooooo000=ooooo`;o0000A_ooool2o`00043ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?_ooool00ol0
003oooooo`00000Aooooo`003Oooool00ol0003oooooooooo`15ooooo`;o0000@Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooo0000017ooooo000=ooooo`03o`000?oooooooooo04Gooooo
0_l00011ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo03kooooo00?o0000ooooool000004Oooool000gooooo00?o
0000ooooooooool0A_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03kooooo00?o
0000ooooool000004Oooool000gooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo03oooooo0_l0000Aooooo`003Oooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo043ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?oooool00ol0003oooooo`00000@oooo
o`003Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0?oooool00ol0003oooooo`00000@ooooo`003Oooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0?oooool00ol0003oooooo`00000@ooooo`003Ooo
ool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Tooooo`05o`000?ooooooooooooooool00000@_ooool00ol0003ooooo
o`00000@ooooo`003Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo047ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Tooooo`05o`000?ooooooooooooooool00000
@_ooool00ol0003oooooo`00000@ooooo`003Oooool00ol0003oooooooooo`16ooooo`03o`000?oo
oooooooo047ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Tooooo`05o`000?oo
ooooooooooooool00000@_ooool00ol0003oooooo`00000@ooooo`003Oooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Tooooo`05o`000?ooooooooooooooool00000@_ooool00ol0003oooooo`00000@ooooo`003Ooo
ool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Tooooo`05o`000?ooooooooooooooool00000@oooool2o`00013ooooo
000=ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0@_ooool01Ol0003ooooooooo
oooooooo000002Kooooo00Go0000ooooooooooooooooo`000013ooooo`;o00004?ooool000gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`12ooooo`05o`000?ooooooooooooooool0
00009_ooool01Ol0003ooooooooooooooooo000004?ooooo0_l0000@ooooo`003Oooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo04;ooooo00Go0000ooooooooooooooooo`00000Voooo
o`05o`000?ooooooooooooooool00000@oooool2o`00013ooooo000=ooooo`03o`000?oooooooooo
04Kooooo00?o0000ooooooooool0@_ooool01Ol0003ooooooooooooooooo000002Kooooo00Go0000
ooooooooooooooooo`000013ooooo`;o00004?ooool000gooooo00?o0000ooooooooool0A_ooool2
o`0004Cooooo00Co0000oooooooooooo00009_ooool01Ol0003ooooooooooooooooo000004?ooooo
0_l0000@ooooo`003Oooool00ol0003oooooooooo`16ooooo`;o0000A?ooool01?l0003ooooooooo
ool0000Vooooo`05o`000?ooooooooooooooool00000@oooool00ol0003oooooo`00000?ooooo`00
3Oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo04;ooooo00Go0000oooooooooooo
ooooo`00000Uooooo`04o`000?ooooooooooo`0004Cooooo00?o0000ooooool000003oooool000go
oooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`12ooooo`05o`000?oooooooooooooo
ool000009Oooool01?l0003oooooooooool00015ooooo`;o00003oooool000gooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`13ooooo`04o`000?ooooooooooo`0002Gooooo00Co0000
oooooooooooo0000AOooool2o`0000oooooo000=ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool0@oooool01?l0003oooooooooool0000Uooooo`04o`000?ooooooooooo`0004Gooooo
0_l0000?ooooo`002oooool3o`0004Sooooo0ol00014ooooo`04o`000?ooooooooooo`0002Gooooo
00Co0000oooooooooooo0000AOooool2o`0000oooooo000:ooooo`Go0000A_ooool5o`0004?ooooo
00Co0000oooooooooooo00009Oooool01?l0003oooooooooool00015ooooo`;o00003oooool000Wo
oooo1ol00014ooooo`Oo0000@oooool00ol0003oooooo`00000Uooooo`04o`000?ooooooooooo`00
04Gooooo0_l0000?ooooo`002OoooomBo`0004?ooooo00?o0000ooooool000009Oooool01?l0003o
ooooooooool00015ooooo`;o00003oooool000Wooooo1ol00009oooooaKo00009Oooool=o`0003go
oooo00?o0000ooooool000009Oooool01?l0003oooooooooool00016ooooo`03o`000?oooooooooo
00gooooo000:ooooo`Go00008?oooolEo`00017ooooo1Ol00007ooooo`Ko0000=oooool00ol0003o
ooooo`00000Uooooo`04o`000?ooooooooooo`0004Kooooo00?o0000ooooooooool03Oooool000_o
oooo0ol0000foooooaKo00003Oooool7o`00037ooooo0_l0000Uooooo`03o`000?oooooo000004Oo
oooo00?o0000ooooooooool03Oooool005[ooooo6_l0000[ooooo`;o00009Oooool00ol0003ooooo
o`000017ooooo`03o`000?oooooooooo00gooooo001`oooooaGo00006_ooool2o`0002Gooooo00?o
0000ooooool00000Aoooool00ol0003oooooooooo`0=ooooo`00N_ooool6o`0000Gooooo5_l00004
ooooo`03o`000?oooooo000002Gooooo0_l00017ooooo`;o00003_ooool0083ooooo1_l0000Eoooo
oaKo00005_ooool2o`0004Oooooo0_l0000>ooooo`00Q_ooool6o`0001Cooooo0_l0000?oooooaGo
000000?oooooo`000?l00000Aoooool2o`0000kooooo002<ooooo`Oo00003Oooool3o`0002?ooooo
5_l0000dooooo`?o00003Oooool009?ooooo1_l00006ooooo`Go00008oooool2o`0001?ooooo5_l0
000Mooooo`Go00003?ooool009Wooooo3?l0000Rooooo`;o0000:OoooolEo`0000Oooooo1ol0000;
ooooo`00W_ooool7o`0002;ooooo0_l0000nooooo`ko00002oooool009kooooo3_l0000Kooooo`;o
0000=Oooool=o`0000?ooooo1ol0000;ooooo`00Woooool5o`0000Sooooo1_l0000Eooooo`03o`00
0?oooooooooo02Sooooo3?l0000Aooooo`Go00003?ooool00:3ooooo0ol0000?ooooo`Ko00003_oo
ool3o`0001gooooo3?l0000Nooooo`?o00003Oooool00;Sooooo1ol00006ooooo`Go00003oooool=
o`0003[ooooo002oooooo`co00000_ooool<o`0004Oooooo0034ooooo`Wo0000Doooool00<Cooooo
1ol0001Eooooo`00aOooool5o`0005Kooooo0036ooooo`?o0000Eoooool00?oooooo8Oooool00?oo
oooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oo
oooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0500054, -0.0360684, \
0.00383279, 0.00372661}},
  CellTags->"LocalInteractions:51"]
}, Open  ]],

Cell[TextData[{
  "It is much faster to generate grid graphs using ",
  StyleBox["VonNeumann",
    FontFamily->"Courier"],
  " than ",
  StyleBox["GridGraph.",
    FontFamily->"Courier"]
}], "Text",
  CellTags->"LocalInteractions:51"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\[IndentingNewLine]VonNeumann[100, 
        100]\[IndentingNewLine]]\)], "Input",
  CellLabel->"In[6]:=",
  CellTags->"LocalInteractions:51"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(0.6000000000000001`\ Second\), ",", 
        InterpretationBox[\("\[SkeletonIndicator]Graph:<"\[InvisibleSpace]\
19800\[InvisibleSpace]", "\[InvisibleSpace]10000\[InvisibleSpace]", "\
\[InvisibleSpace]"Undirected"\[InvisibleSpace]">\[SkeletonIndicator]"\),
          SequenceForm[ 
          "\[SkeletonIndicator]Graph:<", 19800, ", ", 10000, ", ", 
            "Undirected", ">\[SkeletonIndicator]"],
          Editable->False]}], "}"}]], "Output",
  CellLabel->"Out[6]=",
  CellTags->"LocalInteractions:51"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\[IndentingNewLine]GridGraph[100, 
        100]\[IndentingNewLine]]\)], "Input",
  CellLabel->"In[7]:=",
  CellTags->"LocalInteractions:51"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(1.7400000000000002`\ Second\), ",", 
        InterpretationBox[\("\[SkeletonIndicator]Graph:<"\[InvisibleSpace]\
19800\[InvisibleSpace]", "\[InvisibleSpace]10000\[InvisibleSpace]", "\
\[InvisibleSpace]"Undirected"\[InvisibleSpace]">\[SkeletonIndicator]"\),
          SequenceForm[ 
          "\[SkeletonIndicator]Graph:<", 19800, ", ", 10000, ", ", 
            "Undirected", ">\[SkeletonIndicator]"],
          Editable->False]}], "}"}]], "Output",
  CellLabel->"Out[7]=",
  CellTags->"LocalInteractions:51"]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 700}},
WindowSize->{520, 578},
WindowMargins->{{290, Automatic}, {17, Automatic}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "LocalInteractions:51"->{
    Cell[1776, 53, 68, 1, 38, "ObjectName",
      CellTags->"LocalInteractions:51"],
    Cell[1847, 56, 406, 17, 32, "Usage",
      CellTags->"LocalInteractions:51"],
    Cell[2256, 75, 319, 9, 37, "Notes",
      CellTags->"LocalInteractions:51"],
    Cell[2600, 88, 70, 1, 38, "ExampleSection",
      CellTags->"LocalInteractions:51"],
    Cell[2673, 91, 121, 3, 26, "Input",
      CellTags->"LocalInteractions:51"],
    Cell[2797, 96, 106, 1, 22, "Text",
      CellTags->"LocalInteractions:51"],
    Cell[2928, 101, 127, 3, 26, "Input",
      CellTags->"LocalInteractions:51"],
    Cell[3058, 106, 39079, 645, 294, 2265, 185, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LocalInteractions:51"],
    Cell[42152, 754, 327, 10, 37, "Text",
      CellTags->"LocalInteractions:51"],
    Cell[42504, 768, 212, 4, 58, "Input",
      CellTags->"LocalInteractions:51"],
    Cell[42719, 774, 49378, 796, 294, 2759, 215, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"LocalInteractions:51"],
    Cell[92112, 1573, 234, 8, 23, "Text",
      CellTags->"LocalInteractions:51"],
    Cell[92371, 1585, 168, 4, 58, "Input",
      CellTags->"LocalInteractions:51"],
    Cell[92542, 1591, 557, 11, 25, "Output",
      CellTags->"LocalInteractions:51"],
    Cell[93136, 1607, 167, 4, 58, "Input",
      CellTags->"LocalInteractions:51"],
    Cell[93306, 1613, 557, 11, 25, "Output",
      CellTags->"LocalInteractions:51"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"LocalInteractions:51", 94540, 1645}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 68, 1, 38, "ObjectName",
  CellTags->"LocalInteractions:51"],
Cell[1847, 56, 406, 17, 32, "Usage",
  CellTags->"LocalInteractions:51"],
Cell[2256, 75, 319, 9, 37, "Notes",
  CellTags->"LocalInteractions:51"],

Cell[CellGroupData[{
Cell[2600, 88, 70, 1, 38, "ExampleSection",
  CellTags->"LocalInteractions:51"],
Cell[2673, 91, 121, 3, 26, "Input",
  CellTags->"LocalInteractions:51"],
Cell[2797, 96, 106, 1, 22, "Text",
  CellTags->"LocalInteractions:51"],

Cell[CellGroupData[{
Cell[2928, 101, 127, 3, 26, "Input",
  CellTags->"LocalInteractions:51"],
Cell[3058, 106, 39079, 645, 294, 2265, 185, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"LocalInteractions:51"]
}, Open  ]],
Cell[42152, 754, 327, 10, 37, "Text",
  CellTags->"LocalInteractions:51"],

Cell[CellGroupData[{
Cell[42504, 768, 212, 4, 58, "Input",
  CellTags->"LocalInteractions:51"],
Cell[42719, 774, 49378, 796, 294, 2759, 215, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"LocalInteractions:51"]
}, Open  ]],
Cell[92112, 1573, 234, 8, 23, "Text",
  CellTags->"LocalInteractions:51"],

Cell[CellGroupData[{
Cell[92371, 1585, 168, 4, 58, "Input",
  CellTags->"LocalInteractions:51"],
Cell[92542, 1591, 557, 11, 25, "Output",
  CellTags->"LocalInteractions:51"]
}, Open  ]],

Cell[CellGroupData[{
Cell[93136, 1607, 167, 4, 58, "Input",
  CellTags->"LocalInteractions:51"],
Cell[93306, 1613, 557, 11, 25, "Output",
  CellTags->"LocalInteractions:51"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

